***********************************************************************************

* File: airpol0507_in_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/* 
Objective:  The objective of this program is to insheet monitor-year raw pollution data from 2005-2007, 
	taken from the CPCB website, and clean it in preparation for merging with the complete air pollution 
	dataset.

Structure:
1. 2005 data
2. 2006 data
3. 2007 data
4. Append 2005, 2006, 2007
5. Assign stationcodes
6. Final cleaning
*/

***********************************************************************************

clear all
set more off
set mem 500m

cd "${mypath}Data/Air Data"

*******************************************************************************
* 1. 2005 data

* Insheet raw SPM data from 2005
insheet using "Raw Data/2005_spm.csv", clear

* Fix state variable
g state = substr(snostateut, 4, 25)
replace state = trim(state)

* Trim extra spaces from city and location strings
replace city = trim(city)
replace location = trim(location)

* Drop, rename, create, order
drop snostateut stddev vio
rename typeofarea type
rename averagegm3 spm_mean
rename n spm_n
rename airquality exc_spm
g year = 2005
order state city type location year

* Assign state and city to all observations without values (Raw data only lists city and state for the first observation of every city-state group)
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* The two Jammu and Kashmir observations have the same state-city-type-location. Have to change this in order to merge. See next line:
replace location = "MA Stadium2" if location == "MA Stadium" & spm_mean == 197
replace location = "RIICO Office, M.I.A." if location == "RIICO Office, M.I. A."
replace city = "Mormugao" if location == "Mormugao Port Trust"
replace city = "Vasco" if location == "On the roof of Fuse Call Office, Elec. Dept."
replace state = "Chhattisgarh" if state == "Chattisgarh"

* Sort and save
so state city type location
save "Intermediate Data/spm_05.dta", replace

*******************
* Insheet raw SO2 data from 2005
insheet using "Raw Data/2005_so2.csv", clear

* Drop, rename, create, order
rename typeofarea type
rename averagegm3 so2_mean
rename n so2_n
rename stateut state
rename airquality exc_so2
drop sno stddev vio v11
g year = 2005
order state city type location year

* Trim extra spaces from string values
replace state = trim(state)
replace city = trim(city)
replace location = trim(location)

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Edit strings for smooth merging
replace state = "Orissa" if state == "Orrisa"
replace state = "Chhattisgarh" if state == "Chattisgarh"
replace city = "Tiruvananthapuram" if city == "Tiruvanantha-puram"
replace state = "Punjab" if state == "Panjab"
replace location = "Regional Office (North), RSPCB, Vidaya Nagar" if location == "Regional Office(North), RSPCB, Vidaya Nagar"
replace location = "Town Hall" if location == "Town hall"

* Sort and save
so state city type location
save "Intermediate Data/so2_05.dta", replace

*****************
* Insheet raw NO2 data from 2005
insheet using "Raw Data/2005_no2.csv", clear

* Fix state variable
g state = substr(snostateut, 4, 25)
replace state = trim(state)

* Trim extra spaces from string variables
replace city = trim(city)
replace location = trim(location)

* Drop, rename, create, order
drop snostateut stddev vio v10-v20
rename typeofarea type
rename averagegm3 no2_mean
rename n no2_n
rename airquality exc_no2
g year = 2005
order state city type location year

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Edit string variables for smooth merging
replace state = "Orissa" if state == "Orrisa"
replace state = "Chhattisgarh" if state == "Chattisgarh"
replace city = "Vasco" if location == "On the roof of Fuse Call Office, Elec. Dept."
replace city = "Mormugao" if location == "Mormugao Port Trust"
replace location = "RIICO Office, M.I.A." if location == "RIICO Office, M.I. A."

* Sort and save
so state city type location
save "Intermediate Data/no2_05.dta", replace

*********************
* Merge all three pollutant datasets together
merge state city type location using "Intermediate Data/so2_05.dta"
rename _merge _merge1
merge state city type location using "Intermediate Data/spm_05.dta", sort
rename _merge _merge2
drop *merge*

* Destring so2_mean and no2_mean; otherwise they will be missing in the data after they get appended
replace no2_mean = "0" if no2_mean == "BDL"
destring no2_mean, replace
replace so2_mean = "0" if so2_mean == "BDL"
destring so2_mean, replace

* Erase individual datasets
erase "Intermediate Data/no2_05.dta"
erase "Intermediate Data/so2_05.dta"
erase "Intermediate Data/spm_05.dta"

* Save combined '05 dataset
sort state city type location
save "Intermediate Data/airpol2005.dta", replace

*******************************************************************
* 2. 2006 data

* Insheet raw SPM data from 2006
insheet using "Raw Data/2006_spm.csv", clear

* Drop, rename, create, order
drop sno stddev vio v11 v12
rename typeofarea type
rename averagegm3 spm_mean
rename n spm_n
rename stateut state
rename airquality exc_spm
g year = 2006
order state city type location year

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Trim extra spaces from string variables
replace state = trim(state)
replace city = trim(city)
replace location = trim(location)

* Edit string values for smoother merging
replace city = "Tiruvananthapuram" if city == "Tiruvanantha -puram"
replace city = "Hubli-Dharwad" if city == "Hubli- Dharwad"
replace city = "Bhubaneshwar" if city == "Bhubanesh-war"
replace location = "Kunnathur Chatram/ Avvai Girls Hr Sec School" if location == "Kunnathur Chatram/Avvai Girls Higher Sr Sec School"
replace location = "Fenner (I) Ltd./Susee Cars & Trucks Ltd." if location == "Fenner (I) Ltd./Susee cars & Trucks Ltd."
replace location = "RIICO/R.O. Office" if city == "Jodhpur" & location == "RICCO/R.O. Office"
replace location = "Sowdeswari College Building" if location == "Sowdeswari Coll Building"
replace location = "Moulali" if location == "Maulali"
replace state = "Chhattisgarh" if state == "Chattisgarh"

* Sort and save
so state city type location
save "Intermediate Data/spm_06.dta", replace

*******************
* Insheet raw SO2 data from 2006
insheet using "Raw Data/2006_so2.csv", clear

* Drop, rename, create, order
drop sno stddev vio v11
rename typeofarea type
rename averagegm3 so2_mean
rename n so2_n
rename stateut state
rename airquality exc_so2
g year = 2006
order state city type location year

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Trim extra spaces from string variables
replace state = trim(state)
replace city = trim(city)
replace location = trim(location)

* Edit string values for smooth merging
replace state = "Orissa" if state == "Orrisa"
replace state = "Chhattisgarh" if state == "Chattisgarh"
replace city = "Bhubaneshwar" if city == "Bhubanesh war"
replace location = "Airoli, TTC" if location == "Airoli TTC"
replace location = "Sowdeswari College Building" if location == "Sowdeswari Coll Building"
replace location = "Punjab Maltex/M/s Gee Kay International" if location == "Punhab Maltex/M/s Gee Kay International"
replace city = "Derabessi" if location == "M/s Punjab Chemicals and Crop Protection Ltd"
replace city = "Derabessi" if location == "M/s Winsome Yarns Ltd."
replace city = "Khana" if location == "Markfed Vanaspati"
replace city = "Khana" if location == "A S School"
replace location = "Vishwakarma Chowk" if location == "Vishwakarma Office Building"
replace city = "Tiruvananthapuram" if city == "Tiruvanantha-puram"
replace state = "Yamunanagar" if state == "Yamuna Nagar"

* Sort and save
so state city type location
save "Intermediate Data/so2_06.dta", replace

******************
* Insheet raw NO2 data from 2006
insheet using "Raw Data/2006_no2.csv", clear

* Drop, rename, create, order
drop sno stddev vio v11
rename typeofarea type
rename averagegm3 no2_mean
rename n no2_n
rename stateut state
rename airquality exc_no2
g year = 2006
order state city type location year

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Trim extra spaces from string variables
replace state = trim(state)
replace city = trim(city)
replace location = trim(location)

* Edit string values for smooth merging
replace state = "Yamunanagar" if state == "Yamuna Nagar"
replace state = "Orissa" if state == "Orrisa"
replace state = "Chhattisgarh" if state == "Chattisgarh"
replace city = "Bhubaneshwar" if city == "Bhubanesh-war"
replace location = "MPCB Central Lab, TTC" if location == "MPCB Central Lab,TTC"
replace location = "Kunnathur Chatram/ Avvai Girls Hr Sec School" if location == "Kunnathur Chatram/Avvai Girls Higher Sr Sec School"
replace city = "Tiruvananthapuram" if city == "Tiruvanantha-puram"

* Sort and save
so state city type location
save "Intermediate Data/no2_06.dta", replace

******************
* Merge all three pollutant datasets together
merge state city type location using "Intermediate Data/so2_06.dta"
rename _merge _merge1
merge state city type location using "Intermediate Data/spm_06.dta", sort
rename _merge _merge2
drop *merge*

* Destring so2_mean and no2_mean; otherwise they will be missing in the data after they get appended
replace no2_mean = "0" if no2_mean == "BDL"
destring no2_mean , replace
replace so2_mean = "0" if so2_mean == "BDL"
destring so2_mean , replace

* Erase individual datasets
erase "Intermediate Data/no2_06.dta"
erase "Intermediate Data/so2_06.dta"
erase "Intermediate Data/spm_06.dta"

* Save combined '06 dataset
sort state city type location
save "Intermediate Data/airpol2006.dta", replace

*******************************************************************
* 3. 2007 Data

* Insheet raw SPM data from 2007
insheet using "Raw Data/2007_spm.csv", clear

* Drop, rename, create, order
drop sno stddev vio v11 v12 v13
rename typeofarea type
rename averagegm3 spm_mean
rename n spm_n
rename stateut state
rename airquality exc_spm
g year = 2007
order state city type location year

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Trim extra spaces from string variables
replace state = trim(state)
replace city = trim(city)
replace location = trim(location)

* Edit string values for smooth merging
replace state = "Chhattisgarh" if state == "Chattisgarh"
replace state = "Jammu & Kashmir" if state == "Jammu& Kashmir"
replace state = "Orissa" if state == "Orrisa"
replace location = "Shivpur/Sigra" if location == "Shivpur/Sira"
replace location = "M/s Punjab Chemicals and Crop Protection Ltd." if location == "M/s Punjab Chemicals and Crop Protection Ltd"
replace location = "Municipal Corporation Bldg" if location == "Municipal Corporation Building"
replace location = "Baikampady Indl. Area" if location == "Baikampady Industrial Area"
replace location = "Chemical Div. Labour Club" if location == "Chemical Division Labour Club"
replace location = "AC Office Building," if location == "AC Office Building"
replace location = "Sowdeswari College Building" if location == "Sowdeswari Coll Building"
replace location = "KSRTC Kozhikode" if location == "Kozhikode City"
replace city = "Howrah" if city == "Howarh"
replace city = "Thiruvananthapuram" if city == "Tiruvanantha-puram"

* Sort and save
so state city type location
save "Intermediate Data/spm_07.dta", replace

*******************
* Insheet raw SO2 data from 2007
insheet using "Raw Data/2007_so2.csv", clear

* Drop, rename, create, order
drop sno stddev vio v11 v12 v13
rename typeofarea type
rename averagegm3 so2_mean
rename n so2_n
rename stateut state
rename airquality exc_so2
g year = 2007
order state city type location year

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Trim extra spaces from string variables
replace state = trim(state)
replace city = trim(city)
replace location = trim(location)

* Edit string values for smooth merging
replace state = "Chhattisgarh" if state == "Chattisgarh"
replace state = "Orissa" if state == "Orrisa"
replace location = "Shivpur/Sigra" if location == "Shivpur/Sira"
replace location = "Bharat Yantra Nigam" if location == "Bharat Yantra Nigam Ltd."
replace city = "Hubli-Dharwad" if city == "Hubli- Dharwad"
replace city = "Thiruvananthapuram" if city == "Tiruvanantha-puram"

* Destring so2_mean
replace so2_mean = "0" if so2_mean == "BDL"
destring so2_mean, replace

* Sort and save
so state city type location
save "Intermediate Data/so2_07.dta", replace

*******************
* Insheet raw NO2 data from 2007
insheet using "Raw Data/2007_no2.csv", clear

* Drop, rename, create, order
drop sno stddev vio v11 v12 v13
rename typeofarea type
rename averagegm3 no2_mean
rename n no2_n
rename stateut state
rename airquality exc_no2
g year = 2007
order state city type location year

* Assign city and state to all observations without values
replace state = state[_n-1] if state == ""
replace city = city[_n-1] if city == ""

* Trim extra spaces from string variables
replace state = trim(state)
replace city = trim(city)
replace location = trim(location)

* Edit string values for smooth merging
replace state = "Chhattisgarh" if state == "Chattisgarh"
replace state = "Orissa" if state == "Orrisa"
replace location = "KSRTC Kozhikode" if location == "KSRTC, Kozikode"
replace location = "Behrampura" if location == "Berhampura"
replace location = "M/s Punjab Chemicals and Crop Protection Ltd." if location == "M/s Punjab Chemicals and Crop Protection Ltd"
replace location = "Shivpur/Sigra" if location == "Shivpur/ Sigra"
replace city = "Thiruvananthapuram" if city == "Tiruvanantha-puram"
replace city = "Hubli-Dharwad" if city == "Hubli- Dharwad"

* Destring no2_mean
replace no2_mean = "0" if no2_mean == "BDL"
destring no2_mean, replace

* Sort and save
so state city type location
save "Intermediate Data/no2_07.dta", replace

******************
* Merge all three pollutant datasets together
merge state city type location using "Intermediate Data/so2_07.dta"
drop _m
merge state city type location using "Intermediate Data/spm_07.dta", sort
drop _m

* Erase individual datasets
erase "Intermediate Data/no2_07.dta"
erase "Intermediate Data/so2_07.dta"
erase "Intermediate Data/spm_07.dta"

* Save combined '07 dataset
sort state city type location
save "Intermediate Data/airpol2007.dta", replace

*******************************************************************
* 4. Append 2005 and 2006 and 2007

* Append 2005 and 2006 and 2007
append using "Intermediate Data/airpol2005.dta"
append using "Intermediate Data/airpol2006.dta"
sort state city type location year

* Erase annual datasets, save combined dataset
erase "Intermediate Data/airpol2005.dta"
erase "Intermediate Data/airpol2006.dta"
erase "Intermediate Data/airpol2007.dta"

* Fix state names for cities in new states
replace state = "Bihar" if state == "Jharkhand"
replace state = "Madhya Pradesh" if state == "Chhattisgarh"
replace state = "Uttar Pradesh" if state == "Uttaranchal"

* Fix city names that still don't match
replace city = "Thiruvananthapuram" if city == "Tiruvananthapuram"
replace city = "Jhansi" if city == "Janshi"
replace city = "Khana" if city == "Khanna"

* Reconcile monitor locations that don't match
replace location = "Borpara Boards Regional Office" if location == "Borpara Boards R.O."
replace location = "Regional Office Bunglow Office Building" if location == "Regional Office Bunglow Office Bldg."
replace location = "Town Hall" if location == "Town hall"
replace location = "Sardhara Industrial Corporation" if location == "Sardhara Ind. Corporation"
replace location = "Lakkamanahalli Industrial Area" if location == "Lakkamanahalli Indl. Area"
replace location = "SEPR Refractories India Ltd. Kanjikode" if location == "SEPR Refractories India Ltd. , Kanjikode"
replace location = "Sasthamangalam" if location == "Sasthamangalam/Pettah"
replace location = "CEPT Govindpura" if location == "Govindpura"
replace city = "Chandrapur" if city == "Chandarpur"
replace city = "Nashik" if city == "Nasik"
replace location = "Bawongkawn" if location == "Bawangkawn, Roof Top of Mr. K. L. Berema's Residence"
replace location = "Laipuitlang" if location == "Laipuitlang, Residence of Er. Dunglena, Chairman, MPCE"
replace location = "Khatla" if location == "Khatla, M.G-Road, Roof Top of Mizoram SPCB"
replace location = "Gaurav Solvex Ltd" if location == "Gaurav Solvex/Vitage Distillers Ltd."
replace location = "Regional Office (North), RSPCB, Vidaya Nagar" if location == "Regional Office(North), RSPCB, Vidaya Nagar"
replace location = "RIICO Office" if location == "RIICO/R.O. Office" & city == "Jodhpur"
replace location = "Municipal Corporation Building" if location == "Municipal Corporation Bldg" & city == "Kota"
replace location = "Fenner (I) Ltd." if location == "Fenner (I) Ltd./Susee Cars & Trucks Ltd."
replace location = "Kunnathur Chatram/ Avvai Girls Hr Sec School" if location == "Kunnathur Chatram/Avvai Girls Higher Sr. Sec. School"
replace location = "Sowdeswari College Building" if location == "Sowdeswari Coll Building"
replace location = "Sharda Nagar" if location == "Dabauli / Sharda Nagar"
replace city = "Mormugao" if city == "Vasco" & location == "Mormugao Port Trust"
replace city = "Bongaigaon" if city == "Bongaigoan"
replace location = "Guru Jambehswar Univ." if location == "Guru jambehswar Univ."
replace city = "Belgaum" if city == "Belgam"
replace location = "Nashik Municipal Council Building" if location == "Nasik Municipal Council Building"
replace city = "Aizawl" if city == "Aizawal" | city == "Aizwal"
replace location = "Shastri Nagar Police Thana" if location == "Shastri Nagar Police Thane"
replace location = "Bamunimaidam" if location == "Bamunimaidam Head Office"
replace location = "M/s Wool Worth (I) Ltd" if location == "M/s Wool Worth (I) Limited"
replace location = "AZL Behrampur" if location == "Behrampura"
replace location = "Kozhikode City" if location == "KSRTC Kozhikode"
replace location = "Chemical Division Labour Club" if location == "Chemical Div. Labour Club"
replace location = "MPCB Central Lab, TTC" if location == "MPCB Central Lab"
replace location = "Airoli, TTC" if location == "Airoli"
replace location = "MESB Power Station, Taloja" if location == "MESB Power Station"
replace location = "Nerul, TTC" if location == "Nerul"
replace location = "Panvel, Taloja" if location == "Panvel"
replace location = "M/s Punjab Chemicals and Crop Protection Ltd" if location == "M/s Punjab Chemicals and Crop Protection Ltd."
replace location = "Punjab Maltex/M/s Gee Kay International" if location == "M/s Gee Kay International"
replace location = "RIICO Office" if location == "R.O. Office"
replace location = "Shivpur" if location == "Shivpur/Sigra"
replace location = "Ghuseri" if location == "Ghuseri Naskarpara"
replace location = "Moulali" if location == "Maulali"

***************************************************************************************
* 5. Assign stationcodes

* Outsheet each location to facilitate matching of stncodes. I am going to go through each unique state-city-type-stncode-location in the greater dataset, 
*	e_airpol_mntrs.dta, and match stationcodes to the observations from the outsheeted 2005-06 list.

preserve
	collapse (sum) year, by(state city type location)
	outsheet using "Raw Data/0507_location_list", replace
restore

* Save dataset
save "Intermediate Data/airpol0507.dta", replace

* Insheet stationcodes list (created from above outsheet)
insheet using "Raw Data/0507_stncodes.csv", clear

* Sort for merging
so state city type location

* Save as temporary dataset
save "Intermediate Data/temp.dta", replace

* Use airpol0507.dta as master set for merging
u "Intermediate Data/airpol0507.dta", clear
sort state city type location

* Merge stncodes with the master data on state-city-type-location
merge state city type location using "Intermediate Data/temp.dta", uniqusing
drop _merge

*****************************************************************************************
* 6. Final cleaning to prep for merging with panel dataset

* Label variables
la var stncode "CPCB station code"
la var type "Type of Area (Residential, Industrial, Sensitive)"
la var city "city full name"
la var state "state full name"
la var so2_mean "Average across SO2 observations in the given time period"
la var so2_n "number of days of SO2 observations in the given time period"
la var no2_mean "Average across NO2 observations in the given time period"
la var no2_n "number of days of NO2 observations in the given time period"
la var spm_mean "Average across SPM observations in the given time period"
la var spm_n "number of days of SPM observations in the given time period"

* Rename each variable to start with e_, which denotes that it is a reading taken from electronic sources (as opposed to taken from a book).
foreach var of varlist no2_mean-spm_n  {
	ren `var' e_`var'
}

* Extrapolating -type- into three different dummy variables
g resid = type == "R" if type ~= ""
g indus = type == "I" if type ~= ""
g sensit = type == "S" if type ~= ""

* (From air_pollution_electronic.do) Count n for industrial/sensitive so we know the share of each city which is of each type. Count it for residential to achieve that goal and also to calculate residential pollution across pollution measurements.
g e_spm_n_r = e_spm_n if resid == 1
g e_no2_n_r = e_no2_n if resid == 1
g e_so2_n_r = e_so2_n if resid == 1
g e_spm_n_i = e_spm_n if indus == 1
g e_no2_n_i = e_no2_n if indus == 1
g e_so2_n_i = e_so2_n if indus == 1
g e_spm_n_s = e_spm_n if sensit == 1
g e_no2_n_s = e_no2_n if sensit == 1
g e_so2_n_s = e_so2_n if sensit == 1

g e_spm_mean_r = e_spm_mean if resid == 1
g e_no2_mean_r = e_no2_mean if resid == 1
g e_so2_mean_r = e_so2_mean if resid == 1

* Define the 1994 National Ambient Air Quality Standards
g spm_naaqs_r = 140 if resid == 1
g spm_naaqs_i = 360 if indus == 1
g no2_naaqs_r = 60 if resid == 1
g no2_naaqs_i = 80 if indus == 1
g so2_naaqs_r = 60 if resid == 1
g so2_naaqs_i = 80 if indus == 1

* Order variables
order stncode type state city year

* Save dataset
save "Intermediate Data/e_ap0507_my.dta", replace

* Erase obsolete/earlier datasets
erase "Intermediate Data/airpol0507.dta"
erase "Intermediate Data/temp.dta"
