***********************************************************************************

* File: ap_clean_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This file creates both city-year and monitor-year databases with air pollution data 
	from 1987-2003, having variables such as mean, max, min for three pollutants: SPM, SO2, and 
	NO2. These data are cleaned in preparation for merging with the complete air pollution dataset.

Structure:
1. Extract and append together the different years of annual data
2. Use the file airstationconstructedfromCPCBfiles_April14.csv to assign city and state codes to 
	monitor IDs. This is the "Phase 1 dictionary" which is built from CPCB dictionary files.
3. Use the file "newcodelist.xls" which CPCB created to change city, state, and monitor ID codes 
	to reflect changes in station locations
4. Create "Phase 2 Station Dictionary", which defines city and state names that require some judgment
5. Cleanup: Variable labels, obs with -1 recoded to missing (.), drop unnecessary variables

Note: This file reads and organizes the electronic air pollution data that the CPCB recorded. The 
	data are annual since the policy data are annual, though there exist monthly files in separate 
	documents which are not coded here to save time. 
Note: Data for 2004-2006 were collected after this dataset was first created, and are added in 
	Step 5 (see below STRUCTURE).
*/

***********************************************************************************

clear all
set more off
set mem 500m
version 9.0

cd "${mypath}Data/Air Data"

capt log close

********************************************************
* 1. Extract and append together the annual data
* An observation in these files is a year-monitor, even though in the first few years the data 
*	lists a specific date for each obs (like Jan 27 1990)

* We use the electronic files for all years except 1995, because the original 1995 file with daily records was corrupted. 
* The file 95anal.dta is therefore from a different source. 
u "Raw Data/95anal.dta", clear
g year = 1995
la var year "CPCB Year from data file"

* Rename this 1995 file to match the other years
ren spmmn SPMMN
ren noxmn NOXMN
ren so2mn SO2MN
ren spmmx SPMMX
ren noxmx NOXMX
ren so2mx SO2MX
ren spmag SPMAG
ren noxag NOXAG
ren so2ag SO2AG
ren spmno SPMNO
ren noxno NOXNO
ren so2no SO2NO
ren month MONTH
ren stncode STNCODE

* There are already obs for Annual air data. If we do not drop these, then the collapse counts 
*	"Annual" data as another month. (Alternatively, we could delete the collapse command below 
*	and use this Annual data)
drop if MONTH == "Annual"

collapse (mean) SPMAG NOXAG SO2AG year (max) SPMMX NOXMX SO2MX (min) SPMMN NOXMN SO2MN (sum) SPMNO NOXNO SO2NO, by(STNCODE)

foreach y in 87 88 89 90 91 92 93 94 96 97 98 99 {
	append using "Raw Data/airannual`y'.dta"
	replace year = 19`y' if year >= .
}
forv y = 2000/2003 {
	append using "Raw Data/airannual`y'.dta"
	replace year = `y' if year >= .
}

* Abby confirms that the data are NO2, not NOX.
foreach a in "MX" "MN" "STD" "AG" "NO" "SD" "VIO" "I" "R" "" {
	ren NOX`a' NO2`a'
}

* Could drop city and state here-they're less reliable than station dictionaries
drop ones PERIOD
ren CITY city
ren STATE state
ren LOCATION location
ren TYPE type
ren AGENCY agency
ren STNCODE stncode

****************************************  ****************
* 2. Create the Phase I dictionary. This section of code identifies city and state names which 
*	have a very clear grounding in a written document from CPCB, so we're more certain that they 
*	are correct.  The original data do have city, state, and station code listed. But it was 
*	explained by phone that the CPCB engineer who oversees these data said that the station IDs 
*	in the original data are reliable while the city and state names associated with those station 
*	IDs are less reliable. But CPCB has dictionaries which Naresh said are reliable and which link 
*	station IDs to cities and states. An RA took four CPCB dictionaries from pre-2003 and copy-pasted 
*	them into one excel file, which she saved as airstationconstructedfromCPCBfiles_April14.csv. 
*	Sometimes those dictionaries disagree about city or state names associated with a station ID. 
*	So now look at when those four dictionaries agree about the state and city associated with a 
*	station ID, and use that definition.  After collapsing, the database has up to four observations 
*	for each station code. They may have different state and city values because the entire city name 
*	is typed instead of its acronym (eg Agra instead of AGR), because a city has been given multiple 
*	names (e.g. Chennai and Madras), because multiple acronyms are used for a single location, or 
*	because a single acronym is used to mean different locations in different station codes. In 
*	each case, an RA checked the station codes, acronyms, and names against the Location variable 
*	in each of the pre-2004 CPCB station dictionary files to verify matching. The code below applies 
*	a single name for each city and state.  Another note: the dictionaries have info on "type of area" 
*	(I/R/S), location, and monitoringagency, but it was found that those information are no more 
*	accurate than the corresponding information in the original data. So for now, drop that info. 
*	Serialno is meaningless, and collapsing by it is just a quick way to see which stationcodes 
*	are the same within each city-state combo.

preserve

	insheet using "Raw Data/airstationconstructedfromCPCBfiles_April14.csv", comma clear
	* The serialno variable is meaningless, but collapse by it as a convenience mechanism.
	collapse (count) serialno, by(stationcode city state)
	ren stationcode stncode
	
	* Show that there are <= 4 obs per station code (actually only up to three):
	bys stncode: g n = _n
	ta n
	drop n
	
	* Show some of the basis for the following corrections. For now don't output the result, but one can 
	*	remove the asterisks later to view the result.
	
	* so stncode state city
	* by stncode: l if state[1] ~= state[_N] | city[1] ~= city[_N]
	
	* Clean city names. These are all based on looking at the station dictionaries: in all of these cases 
	*	the data make it completely obvious that these names apply to these city codes. 
	replace city = "Agra" if city == "AGR"
	replace city = "Ahmedabad" if city == "AMD"
	replace city = "Alwar" if city == "ALW"
	replace city = "Angul" if city == "ANG"
	*replace city = "ANK" if city == "Ankaleshwar"	I'm not sure why this is here -JBP
	replace city = "Ankaleshwar" if city == "ANK"
	replace city = "Anpara" if city == "ANP"
	replace city = "Bangalore" if city == "BAG"
	replace city = "Baroda" if city == "Vadodara"
	replace city = "Baroda" if city == "VAD" | city == "BAR" 
	replace city = "Bhilai" if city == "BHI"
	replace city = "Bhopal" if city == "BHO" | city == "BPL"
	replace city = "Bhubaneshwar" if city == "BHU"
	replace city = "Mumbai" if city == "MUM" | city == "BOM" | city == "Bombay"
	replace city = "Bongaigaon" if city == "BON"
	replace city = "Calcutta" if city == "Kolkatta"
	replace city = "Calcutta" if city == "Kolkata"
	replace city = "Calcutta" if city == "CAL" | city == "KOL"
	replace city = "Chandigarh" if city == "CND"
	replace city = "Chandrapur" if city == "CHR"
	replace city = "Chittorgarh" if city == "CTR"
	replace city = "Cochin" if city == "COH"
	replace city = "Coimbatore" if city == "COM" | city == "CBE"
	replace city = "Chingavanam" if city == "CVM"
	replace city = "Damtal" if city == "DAM"
	replace city = "Dehradoon" if city == "DEH"
	replace city = "Delhi" if city == "DEL"
	replace city = "Dhanbad" if city == "DHN"
	replace city = "Dharuhera" if city == "DRU"
	replace city = "Dimapur" if city == "DMP"
	replace city = "Dombivali" if city == "DBL"
	replace city = "Faridabad" if city == "FRI"
	replace city = "Gajroula" if city == "GAJ"
	replace city = "Guwahati" if city == "GVT"
	replace city = "Haldia" if city == "HAL"
	replace city = "Howrah" if city == "HOW"
	replace city = "Hyderabad" if city == "HYD"
	replace city = "Indore" if city == "IND"
	replace city = "Jabalpur" if city == "JAB" | city == "JBL"
	replace city = "Jaipur" if city == "JAP"
	replace city = "Jalandhar" if city == "JAL"
	replace city = "Jamnagar" if city == "JAM"
	replace city = "Jamshedpur" if city == "JSR" | city == "JSD"
	replace city = "Jaykaypur" if city == "JAY"
	replace city = "Jharia" if city == "JHA"
	replace city = "Jodhpur" if city == "JDH"
	replace city = "Kanpur" if city == "KNP"
	replace city = "Korba" if city == "KOR"
	replace city = "Kota" if city == "KOT"
	replace city = "Kottayam" if city == "KOM"
	replace city = "Kozhikode" if city == "KOZ"
	replace city = "Lucknow" if city == "LUK"
	replace city = "Ludhiana" if city == "LUD"
	replace city = "Mysore" if city == "MYS"
	replace city = "Nagda" if city == "NAG"
	replace city = "Nagpur" if city == "NGP"
	replace city = "Nashik" if city == "NSK"
	replace city = "Noida" if city == "NOI"
	replace city = "Paonta Sahib" if city == "PSB"
	replace city = "Parwanoo" if city == "PAR"
	replace city = "Ponda" if city == "PON"
	replace city = "Pondichery" if city == "PND"
	replace city = "Pune" if city == "PUN"
	replace city = "Rourkela" if city == "ROU"
	replace city = "Salem" if city == "SAL"
	replace city = "Salem" if city == "SLM"
	replace city = "Satna" if city == "SAT"
	replace city = "Shillong" if city == "SHL"
	replace city = "Shimla" if city == "SHI"
	replace city = "Sindri" if city == "SIN"
	replace city = "Surat" if city == "SUR"
	replace city = "Talcher" if city == "TAL"
	replace city = "Trivendrum" if city == "TRV"
	replace city = "Tuticorin" if city == "TUT" | city == "Tuticorin"
	replace city = "Vasco" if city == "VAS"
	replace city = "Vishakhapatnam" if city == "VPN"
	replace city = "Patna" if city == "PAT"
	replace city = "Rajkot" if city == "RJT"
	replace city = "Vapi" if city == "VAP"
	replace city = "Yamunanagar" if city == "YMN"
	replace city = "Palakkad" if city == "PAD"
	replace city = "Solapur" if city == "SPL"
	replace city = "Thane" if city == "THN"
	replace city = "Gobindgarh" if city == "GBD"
	replace city = "Raipur" if city == "RAI"
	replace city = "Udaipur" if city == "UDP"
	replace city = "Rajkot" if city == "RJT"
	replace city = "Ghaziabad" if city == "GZB"
	replace city = "Varanasi" if city == "VNS"
	replace city = "Panjim" if city == "PJM"
	replace city = "Bharuch" if city == "BRC"
	replace city = "Jammu" if city == "JMU"

	* Coding Madras/Chennai is difficult because MAD was used for both Madras and Madurai. Thus, in 
	*	replacing for MAD we exclude the station codes for Madurai: 306, 307, and 308. And in coding 
	*	Madurai we note the specific station codes to deal with the MAD acronym
	replace city = "Chennai" if city == "Madras" | city == "CHE"
	replace city = "Chennai" if city == "MAD" & stncode != 306 & stncode != 307 & stncode != 308 

	replace city = "Madurai" if city == "Madurai" | city == "MDU"
	replace city = "Madurai" if city == "MAD" & stncode == 306
	replace city = "Madurai" if city == "MAD" & stncode == 307
	replace city = "Madurai" if city == "MAD" & stncode == 308

	* For station 228, identified at Rayagada in the Location variable in all pre-2004 CPCB dictionaries, 
	*	the ROU acronym is sometimes used. We correct for this below.
	replace city = "Rayagada" if city == "RAY" | stncode == 228

	* For station 229, identified at Jaykaypur, Orissa in the Location variable in all pre-2004 CPCB dictionaries, 
	*	the ROU and RAY acronyms are used. We correct for this below.
	replace city = "Jaykaypur" if city == "JAY" | stncode == 229

	* Station 231 is identified at NALCO township in Angul, Orissa through all pre-2004 CPCB dictionaries. 
	*	Both Nalco and ANG (for Angul) are written for observations under this station code. We correct for this below.
	replace city = "Angul" if city == "ANG" | stncode == 231 | city == "Nalco"

	* Need to deal with Daman & Diu and Dadar & Nagar Haveli observations. Stations 114, 115, and 116 are 
	*	identified at Silwasa in the Location variable in all pre-2004 CPCB dictionaries. But "Daman Diu & Nag" 
	*	is used to identify the city. Station 235 is identified as Daman in the Location variable in all pre-2004 
	*	CPCB dictionaries. But "Daman Diu & Nag" is used to identify the city. We correct for both of these below as well.
	replace city = "Silwasa" if city == "SLW" | stncode == 114 & stncode == 115 & stncode == 116
	replace city = "Daman" if city == "DMN" | stncode == 235 | city == "DNH"
	replace state = "Daman & Diu and Dadar & Nagar Haveli" if state == "DNH" | state == "Daman Diu & Nag" | state == "Daman Diu & Nagar" | state == "Dadar & Nagar Haveli"

	* States

	replace state = "Andhra Pradesh" if state == "AND" | state == "ANP" | state == "AP"
	replace state = "Assam" if state == "ASM"
	replace state = "Bihar" if state == "BIH" | state == "BHI" | state == "Jharkhand" | state == "JKH" | state == "JKD"
	replace state = "Chattisgarh" if state == "CGH"
	replace state = "Chandigarh" if state == "CND"
	replace state = "Daman & Diu and Dadar & Nagar Haveli" if state == "DAM"
	replace state = "Delhi" if state == "DEL"
	replace state = "Gujarat" if state == "GJT"
	replace state = "Goa" if state == "GOA"
	replace state = "Himachal Pradesh" if state == "HIP"
	replace state = "Haryana" if state == "HRY"
	replace state = "Jammu & Kashmir" if state == "JKS"
	replace state = "Karnataka" if state == "KAR"
	replace state = "Kerala" if state == "KRL" | state == "KER"
	replace state = "Maharashtra" if state == "MAH"
	replace state = "Meghalaya" if state == "MEG"
	replace state = "Madhya Pradesh" if state == "MPH" | state == "Chattisgarh"
	replace state = "Nagaland" if state == "NGL" | state == "NAG"
	replace state = "Orissa" if state == "ORI"
	replace state = "Punjab" if state == "PJB"
	replace state = "Pondichery" if state == "PND"
	replace state = "Rajasthan" if state == "RAJ"
	replace state = "Tamil Nadu" if state == "TND" | state == "TN" | state == "Tamil Nadu" | state == "TNT"
	replace state = "Uttar Pradesh" if state == "UTP" | state == "UP"
	replace state = "West Bengal" if state == "WBL" | state == "WB"
	replace state = "Jammu & Kashmir" if state == "JMK"
	replace state = "Uttarakhand" if state == "Uttaranchal" | state == "Uttarakhand"

	* Some states' names have been changed or have been divided in the 1990s. To be sure that the state name does not change 
	*	mid-analysis and confuse the work, we use the below section to adjust state names and acronyms to the earliest state 
	*	name in the dataset.
	replace state = "Uttar Pradesh" if state == "UTP" | state == "UTL"
	replace state = "Bihar" if state == "BIH" | state == "JKH"
	replace state = "Madhya Pradesh" if state == "MPH" | state  == "CGH"

	* The following obs have conflicting city and/or state info in these data, so replace their city+state info as missing in 
	*	order that their info not be used below when we merge. 
	replace city = "" if stncode == 46 |  stncode == 188 | stncode == 218 | stncode == 245 | stncode == 242 | stncode == 246 | stncode == 247 | stncode == 248
	replace state = "" if stncode == 46 |  stncode == 188 | stncode == 218 | stncode == 245 | stncode == 242 | stncode == 246 | stncode == 247 | stncode == 248
	
	* The following obs variously ID the city as Daman or "Daman Diu & Nagar". Replace as missing for now
	replace city = "" if stncode >= 114 & stncode <= 116
	replace state = "" if stncode >= 114 & stncode <= 116
	
	* Verify that we now have a database where each stncode uniquely IDs a city and state
	so stncode state city
	by stncode: assert state[1] == state[_N] | city[1] == city[_N]

	collapse (count) serialno, by(stncode state city)
	drop serialno
	sort stncode
	
	sa "Intermediate Data/temp.dta", replace
	* At this point, we've created a dictionary of state and cities names associated with station codes, and we've named the
	*	the dictionary "temp.dta".
	
restore

* This merge says that whenever the state and city values in the dictionary file "temp.dta" differ from the state and 
*	city values in the original data files, use the values from the dictionary "temp" file unless they are missing. 
*	_mer == 2 is station codes which have a city+state defn in the dictionary file "temp" but which don't have 
*	pollution data in the original file
sort stncode
merge stncode using "Intermediate Data/temp.dta", uniqusing update replace
ta _mer
drop if _mer == 2 
drop _mer
erase "Intermediate Data/temp.dta"

* The merge update replace command left 10 obs with missing city and state values, because anal95.dta did not contain city and
*	 state identifiers and stncode values with multiple records in the dictionary were recoded as empty. Thus, neither the 
*	master nor using dataset had a value for city and state. But if you look at other years for these same station codes, 
*	it is clear what these obs should be coded as. I am thus applying city, state, and type data to these obs. -- Sam
replace city = "DNH" if stncode == 114 & year == 1995
replace state = "DNH" if stncode == 114 & year == 1995 
replace type = "I" if stncode == 114 & year == 1995

replace city = "GVT" if stncode == 218 & year == 1995
replace state = "ASM" if stncode == 218 & year == 1995 
replace type = "R" if stncode == 218 & year == 1995

replace city = "GVT" if stncode == 242 & year == 1995
replace state = "ASM" if stncode == 242 & year == 1995 
replace type = "R" if stncode == 242 & year == 1995

replace city = "BHI" if stncode == 245 & year == 1995
replace state = "MPH" if stncode == 245 & year == 1995 
replace type = "I" if stncode == 245 & year == 1995

replace city = "NAG" if stncode == 246 & year == 1995
replace state = "MPH" if stncode == 246 & year == 1995 
replace type = "R" if stncode == 246 & year == 1995
 
replace city = "BPL" if stncode == 247 & year == 1995
replace state = "MPH" if stncode == 247 & year == 1995 
replace type = "R" if stncode == 247 & year == 1995 
 
replace city = "JBL" if stncode == 248 & year == 1995
replace state = "MPH" if stncode == 248 & year == 1995 
replace type = "R" if stncode == 248 & year == 1995

* The first two obs below are empty. The third has no city or state identifier either in the master 
*	pollution dataset or the using dictionary. I have no idea what state it could be from so I am dropping it.
drop if stncode == 0
drop if stncode == 286
drop if stncode == 285

***************************************************
* 3: Adjust station codes and city+state names to reflect changes in monitor locations indicated in the file 
*	"newcodelist.xls". The idea is that some monitors changed locations but the basic monitor codes and city+state 
*	locations don't capture the changes, so we adjust the monitor codes and city+state locations.
g float restncode = stncode

replace  restncode = 323 if  restncode == 2 & year == 1996
replace  restncode = 323 if  restncode == 2 & year == 1997
replace  restncode = 323 if  restncode == 2 & year == 1998
replace  restncode = 323 if  restncode == 2 & year == 1999
replace  restncode = 323 if  restncode == 2 & year == 2000
replace  restncode = 323 if  restncode == 2 & year == 2001
replace  restncode = 323 if  restncode == 2 & year == 2002
replace  restncode = 323 if  restncode == 2 & year == 2003
replace  restncode = 324 if  restncode == 3 & year == 1996
replace  restncode = 324 if  restncode == 3 & year == 1997
replace  restncode = 324 if  restncode == 3 & year == 1998
replace  restncode = 324 if  restncode == 3 & year == 1999
replace  restncode = 324 if  restncode == 3 & year == 2000
replace  restncode = 324 if  restncode == 3 & year == 2001
replace  restncode = 324 if  restncode == 3 & year == 2002
replace  restncode = 324 if  restncode == 3 & year == 2003
replace  restncode = 325 if  restncode == 18 & year == 2001
replace  restncode = 325 if  restncode == 18 & year == 2002
replace  restncode = 325 if  restncode == 18 & year == 2003
replace  restncode = 326 if  restncode == 20 & year == 2001
replace  restncode = 326 if  restncode == 20 & year == 2002
replace  restncode = 326 if  restncode == 20 & year == 2003
replace  restncode = 327 if  restncode == 36 & year == 2002
replace  restncode = 327 if  restncode == 36 & year == 2003
replace  restncode = 328 if  restncode == 41 & year == 2002
replace  restncode = 328 if  restncode == 41 & year == 2003
replace  restncode = 329 if  restncode == 42 & year == 2001
replace  restncode = 329 if  restncode == 42 & year == 2002
replace  restncode = 330 if  restncode == 42 & year == 2003
replace  restncode = 331 if  restncode == 43 & year == 2001
replace  restncode = 331 if  restncode == 43 & year == 2002
replace  restncode = 331 if  restncode == 43 & year == 2003
replace  restncode = 332 if  restncode == 45 & year == 1996
replace  restncode = 332 if  restncode == 45 & year == 1997
replace  restncode = 332 if  restncode == 45 & year == 1998
replace  restncode = 332 if  restncode == 45 & year == 1999
replace  restncode = 332 if  restncode == 45 & year == 2000
replace  restncode = 332 if  restncode == 45 & year == 2001
replace  restncode = 332 if  restncode == 45 & year == 2002
replace  restncode = 332 if  restncode == 45 & year == 2003
replace  restncode = 333 if  restncode == 47 & year == 1999
replace  restncode = 333 if  restncode == 47 & year == 2000
replace  restncode = 333 if  restncode == 47 & year == 2001
replace  restncode = 333 if  restncode == 47 & year == 2002
replace  restncode = 333 if  restncode == 47 & year == 2003
replace  restncode = 334 if  restncode == 51 & year == 1999
replace  restncode = 334 if  restncode == 51 & year == 2000
replace  restncode = 334 if  restncode == 51 & year == 2001
replace  restncode = 334 if  restncode == 51 & year == 2002
replace  restncode = 334 if  restncode == 51 & year == 2003
replace  restncode = 335 if  restncode == 62 & year == 2001
replace  restncode = 335 if  restncode == 62 & year == 2002
replace  restncode = 335 if  restncode == 62 & year == 2003
replace  restncode = 336 if  restncode == 92 & year == 2001
replace  restncode = 336 if  restncode == 92 & year == 2002
replace  restncode = 337 if  restncode == 92 & year == 2003
replace  restncode = 338 if  restncode == 105 & year == 2002
replace  restncode = 338 if  restncode == 105 & year == 2003
replace  restncode = 339 if  restncode == 119 & year == 2001
replace  restncode = 339 if  restncode == 119 & year == 2002
replace  restncode = 339 if  restncode == 119 & year == 2003
replace  restncode = 340 if  restncode == 121 & year == 2001
replace  restncode = 340 if  restncode == 121 & year == 2002
replace  restncode = 340 if  restncode == 121 & year == 2003
replace  restncode = 341 if  restncode == 129 & year == 1996
replace  restncode = 341 if  restncode == 129 & year == 1997
replace  restncode = 341 if  restncode == 129 & year == 1998
replace  restncode = 341 if  restncode == 129 & year == 1999
replace  restncode = 341 if  restncode == 129 & year == 2000
replace  restncode = 341 if  restncode == 129 & year == 2001
replace  restncode = 342 if  restncode == 129 & year == 2002
replace  restncode = 342 if  restncode == 129 & year == 2003
replace  restncode = 343 if  restncode == 130 & year == 2003
replace  restncode = 344 if  restncode == 142 & year == 1997
replace  restncode = 344 if  restncode == 142 & year == 1998
replace  restncode = 344 if  restncode == 142 & year == 1999
replace  restncode = 344 if  restncode == 142 & year == 2000
replace  restncode = 344 if  restncode == 142 & year == 2001
replace  restncode = 344 if  restncode == 142 & year == 2002
replace  restncode = 344 if  restncode == 142 & year == 2003
replace  restncode = 345 if  restncode == 145 & year == 2003
replace  restncode = 346 if  restncode == 148 & year == 1996
replace  restncode = 346 if  restncode == 148 & year == 1997
replace  restncode = 346 if  restncode == 148 & year == 1998
replace  restncode = 346 if  restncode == 148 & year == 1999
replace  restncode = 346 if  restncode == 148 & year == 2000
replace  restncode = 346 if  restncode == 148 & year == 2001
replace  restncode = 346 if  restncode == 148 & year == 2002
replace  restncode = 346 if  restncode == 148 & year == 2003
replace  restncode = 347 if  restncode == 153 & year == 2002
replace  restncode = 347 if  restncode == 153 & year == 2003
replace  restncode = 348 if  restncode == 164 & year == 1996
replace  restncode = 348 if  restncode == 164 & year == 1997
replace  restncode = 348 if  restncode == 164 & year == 1998
replace  restncode = 348 if  restncode == 164 & year == 1999
replace  restncode = 348 if  restncode == 164 & year == 2000
replace  restncode = 348 if  restncode == 164 & year == 2001
replace  restncode = 348 if  restncode == 164 & year == 2002
replace  restncode = 348 if  restncode == 164 & year == 2003
replace  restncode = 349 if  restncode == 168 & year == 2002
replace  restncode = 349 if  restncode == 168 & year == 2003
replace  restncode = 350 if  restncode == 172 & year == 1995
replace  restncode = 350 if  restncode == 172 & year == 1996
replace  restncode = 350 if  restncode == 172 & year == 1997
replace  restncode = 350 if  restncode == 172 & year == 1998
replace  restncode = 350 if  restncode == 172 & year == 1999
replace  restncode = 350 if  restncode == 172 & year == 2000
replace  restncode = 350 if  restncode == 172 & year == 2001
replace  restncode = 350 if  restncode == 172 & year == 2002
replace  restncode = 351 if  restncode == 172 & year == 2003
replace  restncode = 352 if  restncode == 174 & year == 1997
replace  restncode = 352 if  restncode == 174 & year == 1998
replace  restncode = 352 if  restncode == 174 & year == 1999
replace  restncode = 352 if  restncode == 174 & year == 2000
replace  restncode = 352 if  restncode == 174 & year == 2001
replace  restncode = 352 if  restncode == 174 & year == 2002
replace  restncode = 353 if  restncode == 177 & year == 1996
replace  restncode = 353 if  restncode == 177 & year == 1997
replace  restncode = 353 if  restncode == 177 & year == 1998
replace  restncode = 353 if  restncode == 177 & year == 1999
replace  restncode = 353 if  restncode == 177 & year == 2000
replace  restncode = 353 if  restncode == 177 & year == 2001
replace  restncode = 353 if  restncode == 177 & year == 2002
replace  restncode = 353 if  restncode == 177 & year == 2003
replace  restncode = 354 if  restncode == 178 & year == 1996
replace  restncode = 354 if  restncode == 178 & year == 1997
replace  restncode = 354 if  restncode == 178 & year == 1998
replace  restncode = 354 if  restncode == 178 & year == 1999
replace  restncode = 354 if  restncode == 178 & year == 2000
replace  restncode = 355 if  restncode == 178 & year == 2001
replace  restncode = 355 if  restncode == 178 & year == 2002
replace  restncode = 355 if  restncode == 178 & year == 2003
replace  restncode = 356 if  restncode == 180 & year == 1996
replace  restncode = 356 if  restncode == 180 & year == 1997
replace  restncode = 356 if  restncode == 180 & year == 1998
replace  restncode = 356 if  restncode == 180 & year == 1999
replace  restncode = 356 if  restncode == 180 & year == 2000
replace  restncode = 357 if  restncode == 180 & year == 2001
replace  restncode = 357 if  restncode == 180 & year == 2002
replace  restncode = 357 if  restncode == 180 & year == 2003
replace  restncode = 358 if  restncode == 182 & year == 2003
replace  restncode = 359 if  restncode == 185 & year == 2003
replace  restncode = 360 if  restncode == 186 & year == 2003
replace  restncode = 361 if  restncode == 188 & year == 2003
replace  restncode = 362 if  restncode == 192 & year == 1998
replace  restncode = 362 if  restncode == 192 & year == 1999
replace  restncode = 362 if  restncode == 192 & year == 2000
replace  restncode = 362 if  restncode == 192 & year == 2001
replace  restncode = 362 if  restncode == 192 & year == 2002
replace  restncode = 362 if  restncode == 192 & year == 2003
replace  restncode = 363 if  restncode == 199 & year == 1996
replace  restncode = 363 if  restncode == 199 & year == 1997
replace  restncode = 363 if  restncode == 199 & year == 1998
replace  restncode = 363 if  restncode == 199 & year == 1999
replace  restncode = 363 if  restncode == 199 & year == 2000
replace  restncode = 363 if  restncode == 199 & year == 2001
replace  restncode = 363 if  restncode == 199 & year == 2002
replace  restncode = 363 if  restncode == 199 & year == 2003
replace  restncode = 364 if  restncode == 201 & year == 2003
replace  restncode = 365 if  restncode == 202 & year == 2001
replace  restncode = 365 if  restncode == 202 & year == 2002
replace  restncode = 365 if  restncode == 202 & year == 2003
replace  restncode = 366 if  restncode == 206 & year == 1996
replace  restncode = 366 if  restncode == 206 & year == 1997
replace  restncode = 366 if  restncode == 206 & year == 1998
replace  restncode = 366 if  restncode == 206 & year == 1999
replace  restncode = 366 if  restncode == 206 & year == 2000
replace  restncode = 366 if  restncode == 206 & year == 2001
replace  restncode = 366 if  restncode == 206 & year == 2002
replace  restncode = 366 if  restncode == 206 & year == 2003
replace  restncode = 367 if  restncode == 220 & year == 1996
replace  restncode = 367 if  restncode == 220 & year == 1997
replace  restncode = 367 if  restncode == 220 & year == 1998
replace  restncode = 367 if  restncode == 220 & year == 1999
replace  restncode = 367 if  restncode == 220 & year == 2000
replace  restncode = 367 if  restncode == 220 & year == 2001
replace  restncode = 367 if  restncode == 220 & year == 2002
replace  restncode = 367 if  restncode == 220 & year == 2003
replace  restncode = 368 if  restncode == 222 & year == 2001
replace  restncode = 368 if  restncode == 222 & year == 2002
replace  restncode = 368 if  restncode == 222 & year == 2003
replace  restncode = 369 if  restncode == 225 & year == 1999
replace  restncode = 369 if  restncode == 225 & year == 2000
replace  restncode = 369 if  restncode == 225 & year == 2001
replace  restncode = 369 if  restncode == 225 & year == 2002
replace  restncode = 369 if  restncode == 225 & year == 2003
replace  restncode = 370 if  restncode == 226 & year == 2002
replace  restncode = 370 if  restncode == 226 & year == 2003
replace  restncode = 371 if  restncode == 232 & year == 1996
replace  restncode = 371 if  restncode == 232 & year == 1997
replace  restncode = 371 if  restncode == 232 & year == 1998
replace  restncode = 371 if  restncode == 232 & year == 1999
replace  restncode = 371 if  restncode == 232 & year == 2000
replace  restncode = 371 if  restncode == 232 & year == 2001
replace  restncode = 371 if  restncode == 232 & year == 2002
replace  restncode = 371 if  restncode == 232 & year == 2003
replace  restncode = 372 if  restncode == 243 & year == 1995
replace  restncode = 372 if  restncode == 243 & year == 1996
replace  restncode = 372 if  restncode == 243 & year == 1997
replace  restncode = 372 if  restncode == 243 & year == 1998
replace  restncode = 372 if  restncode == 243 & year == 1999
replace  restncode = 372 if  restncode == 243 & year == 2000
replace  restncode = 372 if  restncode == 243 & year == 2001
replace  restncode = 372 if  restncode == 243 & year == 2002
replace  restncode = 372 if  restncode == 243 & year == 2003
replace  restncode = 373 if  restncode == 250 & year == 1995
replace  restncode = 373 if  restncode == 250 & year == 1996
replace  restncode = 373 if  restncode == 250 & year == 1997
replace  restncode = 373 if  restncode == 250 & year == 1998
replace  restncode = 373 if  restncode == 250 & year == 1999
replace  restncode = 373 if  restncode == 250 & year == 2000
replace  restncode = 373 if  restncode == 250 & year == 2001
replace  restncode = 373 if  restncode == 250 & year == 2002
replace  restncode = 373 if  restncode == 250 & year == 2003
replace  restncode = 374 if  restncode == 256 & year == 1996
replace  restncode = 374 if  restncode == 256 & year == 1997
replace  restncode = 374 if  restncode == 256 & year == 1998
replace  restncode = 374 if  restncode == 256 & year == 1999
replace  restncode = 374 if  restncode == 256 & year == 2000
replace  restncode = 374 if  restncode == 256 & year == 2001
replace  restncode = 374 if  restncode == 256 & year == 2002
replace  restncode = 374 if  restncode == 256 & year == 2003
replace  restncode = 375 if  restncode == 260 & year == 2003
replace  restncode = 376 if  restncode == 272 & year == 2003
replace  restncode = 377 if  restncode == 276 & year == 1997
replace  restncode = 377 if  restncode == 276 & year == 1998
replace  restncode = 377 if  restncode == 276 & year == 1999
replace  restncode = 377 if  restncode == 276 & year == 2000
replace  restncode = 377 if  restncode == 276 & year == 2001
replace  restncode = 377 if  restncode == 276 & year == 2002
replace  restncode = 377 if  restncode == 276 & year == 2003
replace  restncode = 378 if  restncode == 278 & year == 2002
replace  restncode = 378 if  restncode == 278 & year == 2003
replace  restncode = 379 if  restncode == 290 & year == 2002
replace  restncode = 379 if  restncode == 290 & year == 2003
replace  restncode = 380 if  restncode == 302 & year == 2001
replace  restncode = 380 if  restncode == 302 & year == 2002
replace  restncode = 380 if  restncode == 302 & year == 2003
replace  restncode = 381 if  restncode == 313 & year == 2002
replace  restncode = 381 if  restncode == 313 & year == 2003
replace  restncode = 253 if  restncode == 247 & year == 1993
replace  restncode = 244 if  restncode == 245 & year == 1993
replace  restncode = 133 if  restncode == 288 & year == 1996
replace  restncode = 133 if  restncode == 288 & year == 1997
replace  restncode = 133 if  restncode == 288 & year == 1998
replace  restncode = 133 if  restncode == 288 & year == 1999
replace  restncode = 133 if  restncode == 288 & year == 2000
replace  restncode = 133 if  restncode == 288 & year == 2001
replace  restncode = 133 if  restncode == 288 & year == 2002
replace  restncode = 133 if  restncode == 288 & year == 2003

* Almost all of these monitors changed locations within a city. But since some of them could have changed cities also, 
*	follow the original CPCB document in replacing all of the city and state values to their new values.  
replace city = "Agra" if restncode == 323
replace state = "Uttar Pradesh" if restncode == 323
replace city = "Agra" if restncode == 324
replace state = "Uttar Pradesh" if restncode == 324
replace city = "Kota" if restncode == 325
replace state = "Rajasthan" if restncode == 325
replace city = "Kota" if restncode == 326
replace state = "Rajasthan" if restncode == 326
replace city = "Panaji" if restncode == 327
replace state = "Goa" if restncode == 327
replace city = "Mysore" if restncode == 328
replace state = "Karnataka" if restncode == 328
replace city = "Faridabad" if restncode == 329
replace state = "Haryana" if restncode == 329
replace city = "Faridabad" if restncode == 330
replace state = "Haryana" if restncode == 330
replace city = "Faridabad" if restncode == 331
replace state = "Haryana" if restncode == 331
replace city = "Jharia" if restncode == 332
replace state = "Bihar" if restncode == 332
replace city = "Jharia" if restncode == 333
replace city = "Baroda" if restncode == 333
replace state = "Gujarat" if restncode == 333
replace city = "Vadodara" if restncode == 334
replace state = "Gujarat" if restncode == 334
replace city = "Baroda" if restncode == 334
replace city = "Ludhiana" if restncode == 335
replace state = "Punjab" if restncode == 335
replace city = "Pondichery" if restncode == 336
replace state = "Pondichery" if restncode == 336
replace city = "Pondichery" if restncode == 337
replace state = "Pondichery" if restncode == 337
replace city = "Cochin" if restncode == 338
replace state = "Kerala" if restncode == 338
replace city = "Parwanoo" if restncode == 339
replace state = "Himachal Pradesh" if restncode == 339
replace city = "Shillong" if restncode == 340
replace state = "Meghalaya" if restncode == 340
replace city = "Satna" if restncode == 341
replace state = "Madhya Pradesh" if restncode == 341
replace city = "Satna" if restncode == 342
replace state = "Madhya Pradesh" if restncode == 342
replace city = "Satna" if restncode == 343
replace state = "Madhya Pradesh" if restncode == 343
replace city = "Kanpur" if restncode == 344
replace state = "Uttar Pradesh" if restncode == 344
replace city = "Delhi" if restncode == 345
replace state = "Delhi" if restncode == 345
replace city = "Cochin" if restncode == 346
replace state = "Kerala" if restncode == 346
replace city = "Ahmedabad" if restncode == 347
replace state = "Gujarat" if restncode == 347
replace city = "Calcutta" if restncode == 348
replace state = "West Bengal" if restncode == 348
replace city = "Mumbai" if restncode == 349
replace state = "Maharashtra" if restncode == 349
replace city = "Jamshedpur" if restncode == 350
replace state = "Bihar" if restncode == 350
replace city = "Jamshedpur" if restncode == 351
replace state = "Bihar" if restncode == 351
replace city = "Jamshedpur" if restncode == 352
replace state = "Bihar" if restncode == 352
replace city = "Jalandhar" if restncode == 353
replace state = "Punjab" if restncode == 353
replace city = "Jalandhar" if restncode == 354
replace state = "Punjab" if restncode == 354
replace city = "Jalandhar" if restncode == 355
replace state = "Punjab" if restncode == 355
replace city = "Thiruvannanthapuram" if restncode == 356
replace state = "Kerala" if restncode == 356
replace city = "Thiruvannanthapuram" if restncode == 357
replace state = "Kerala" if restncode == 357
replace city = "Thiruvannanthapuram" if restncode == 358
replace state = "Kerala" if restncode == 358
replace city = "Kozhikode" if restncode == 359
replace state = "Kerala" if restncode == 359
replace city = "Kozhikode" if restncode == 360
replace state = "Kerala" if restncode == 360
replace city = "Vadavathoor" if restncode == 361
replace state = "Kerala" if restncode == 361
replace city = "Kottayam" if restncode == 361
replace city = "Varanasi" if restncode == 362
replace state = "Uttar Pradesh" if restncode == 362
replace city = "Jabalpur" if restncode == 363
replace state = "Madhya Pradesh" if restncode == 363
replace city = "Korba" if restncode == 364
replace state = "Madhya Pradesh" if restncode == 364
replace city = "Hyderabad" if restncode == 365
replace state = "Andhra Pradesh" if restncode == 365
replace city = "Tuticorin" if restncode == 366
replace state = "TamilNadu" if restncode == 366
replace city = "Vapi" if restncode == 367
replace state = "Gujarat" if restncode == 367
replace city = "Raipur" if restncode == 368
replace state = "Madhya Pradesh" if restncode == 368
replace city = "Ghaziabad" if restncode == 369
replace state = "Uttar Pradesh" if restncode == 369
replace city = "Rourkela" if restncode == 370
replace state = "Orissa" if restncode == 370
replace city = "Vishakhapatnam" if restncode == 371
replace state = "Andhra Pradesh" if restncode == 371
replace city = "Alwar" if restncode == 372
replace state = "Rajasthan" if restncode == 372
replace city = "Alwar" if restncode == 373
replace state = "Rajasthan" if restncode == 373
replace city = "Rajkot" if restncode == 374
replace state = "Gujarat" if restncode == 374
replace city = "Coimbatore" if restncode == 375
replace state = "TamilNadu" if restncode == 375
replace city = "Jodhpur" if restncode == 376
replace state = "Rajasthan" if restncode == 376
replace city = "Lucknow" if restncode == 377
replace state = "Uttar Pradesh" if restncode == 377
replace city = "Noida" if restncode == 378
replace state = "Uttar Pradesh" if restncode == 378
replace city = "Pune" if restncode == 379
replace state = "Maharashtra" if restncode == 379
replace city = "Gobindgarh" if restncode == 380
replace state = "Punjab" if restncode == 380
replace city = "Pune" if restncode == 381
replace state = "Maharashtra" if restncode == 381
replace city = "Ankaleshwar" if restncode == 253
replace state = "Gujarat" if restncode == 253
replace city = "Patiala" if restncode == 244
replace state = "Punjab" if restncode == 244
replace city = "Nagpur" if restncode == 133
replace state = "Maharashtra" if restncode == 133
replace city = "Jamshedpur" if restncode == 382
replace state = "Bihar" if restncode == 382

*****************************************************************************
* 4. Create "Phase 2 Station Dictionary", which defines city and state names that require some judgment.

* Fix obs where city was coded in state var & state in city var
replace city = "Damtal" if state == "DAM"
replace state = "Himachal Pradesh" if state == "DAM"

* Fix obs where city and state were blank in data but were noted in later CPCB dictionaries and in Location 
*	variable in annual data.
replace city = "Jalandhar" if restncode == 392
replace state = "Punjab" if restncode == 392

* Fix cities with no definition in CPCB dictionaries or data for AGD, Maharashtra. 
replace city = "Jodhpur" if city == "JDH"
replace city = "Guwahati" if city == "GVT"
replace city = "Dhanbad" if city == "DHN"
replace city = "Lucknow" if city == "LUK"
replace city = "Nagda" if city == "NAG"
replace city = "Noida" if city == "NOI"
replace city = "Nashik" if city == "NSK"
replace city = "Alwar" if city == "ALW"
replace city = "Bhilai" if city == "BHI"
replace city = "Sindri" if city == "SIN"
replace city = "Jabalpur" if city == "JAB" | city == "Jabalpur" | city == "JBL"
replace city = "Chingavanam" if city == "CVM"
replace city = "Kottayam" if city == "KOM"
replace city = "Coimbatore" if city == "COM" | city == "CBE"
replace city = "Bhopal" if city == "BHO" | city == "BPL"
replace city = "Jamshedpur" if city == "JSR" | city == "JSD"
replace city = "Tuticorin" if city == "TUT" | city == "Tuticorin" | city == "TTN" | city == "TRC"

* Fix states
replace state = "Assam" if state == "ASM"
replace state = "Andhra Pradesh" if state == "AND" | state == "ANP" 
replace state = "Bihar" if state == "BIH"
replace state = "Chandigarh" if state == "CGH"
replace state = "Delhi" if state == "DEL"
replace state = "Goa" if state == "GOA"
replace state = "Gujarat" if state == "GJT"
replace state = "Haryana" if state == "HRY"
replace state = "Himachal Pradesh" if state == "HIP"
replace state = "Karnataka" if state == "KAR"
replace state = "Kerala" if state == "KRL"
replace state = "Madhya Pradesh" if state == "MPH"
replace state = "Maharashtra" if state == "MAH"
replace state = "Meghalaya" if state == "MEG"
replace state = "Orissa" if state == "ORI"
replace state = "Pondichery" if state == "PND"
replace state = "Punjab" if state == "PJB"
replace state = "Rajasthan" if state == "RAJ"
replace state = "Tamil Nadu" if state == "TND" | state == "TamilNadu" | state == "TN"
replace state = "West Bengal" if state == "WBL" | state == "WB"

* Some states' names have been changed or have been divided in the 1990s. To be sure that the state name 
*	does not change mid-analysis and confuse the work, we use the below section to adjust state names and 
*	acronyms to the earliest state name in the dataset.
replace state = "Uttar Pradesh" if state == "UTP"
replace state = "Bihar" if state == "BIH" | state == "JKH"
replace state = "Madhya Pradesh" if state == "MPH" | state == "CGH"
replace state = "Dadra & Nagar Haveli" if state == "DNH"

* In these data this city is listed as Chandigarh, but in other data sets of this project (and in google maps 
*	and most webpages) it's listed as Chhattisgarh, which was renamed to Mandhya Pradesh.
replace state = "Madhya Pradesh" if state == "Chandigarh" & city == "Bhilai"

/* Addressing Station 46:
The location code for station 46, when entered, indicates the same location whether the city listed is Dhanbad 
or Sindri: "Near Police Station (FCI Main Hospital)." 
Sindri is located in Dhanbad district and, of the 17 entries for station 46, only two say Dhanbad.
Thus it seems clear that station 46 refers to Sindri, Bihar within Dhanbad district of Bihar.
Thus the proper city coding is Sindri (SIN). */

replace city = "Sindri" if city == "SIN" | restncode == 46

/* Addressing Station 188: 
Chingavanam is located in Kottayam district and, of the 12 entries for station 188, only one indicates Kottayam.
Also, one Location variable writes: "Chingavanam\ Vadavathor, Kottayam." 
Thus it seems clear that station 188 refers to Chingavanam, Kerala within Kottayam district.
Thus the proper city coding is Chingavanam (CVM). */
replace city = "Chingavanam" if city == "CVM" | restncode == 188

* We still have city values AGD and DNH as acronyms. I judge the second to be Dadra & Nagar Haveli. I judge the 
*	first to be Aurangabad since we have no Aurangabad obs in this data but do in Rema's air pollution data; and 
*	because Aurangabad is a large Maharashtra city which roughly matches the acronym AGD. There's no location 
*	info for either place.
replace city = "Dadra & Nagar Haveli" if city == "DNH"
replace city = "Aurangabad" if city == "AGD"
replace city = "Pune" if city == "Pune Corp"

****************************************
* 5: Cleanup

/* We drop the following variables as they are unnecessary and redundant.
More specifically:
DATE and MONTH are in an annual dataset that already has year variables.
CONFIR and INDEX were internal measures created for the computer processes at the CPCB. 
SO2 NO2 SPM l the pollutant names in a manner that is confusing and not useful. */

* Drop unneeded or redundant variables 
bys year: ta DATE
assert MONTH == "Annual" | MONTH == ""
drop DATE MONTH CONFIR INDEX SO2 NO2 SPM

* Change -1 to missing
foreach var of varlist SO2MX SO2MN SO2AG SO2NO NO2MX NO2MN NO2AG NO2NO SPMMX SPMMN SPMAG SPMNO SO2SD NO2SD SPMSD SO2AT NO2AT SPMAT SO2VIO NO2VIO SPMVIO {
	recode `var' -1 = .
}

* Rename variables to match Rema's
ren SO2MX so2_max
ren SO2MN so2_min
ren SO2AG so2_mean
ren SO2NO so2_n	

ren NO2MX no2_max
ren NO2MN no2_min
ren NO2AG no2_mean
ren NO2NO no2_n	

ren SPMMX spm_max
ren SPMMN spm_min
ren SPMAG spm_mean
ren SPMNO spm_n	

ren SO2I offexced_so2_i
ren NO2I offexced_no2_i
ren SPMI offexced_spm_i

ren SO2R offexced_so2_r
ren NO2R offexced_no2_r
ren SPMR offexced_spm_r

* Variable labels
la var stncode "original CPCB data station code"
la var type "Type of Area (Residential, Industrial)"
la var city "original CPCB data city"
la var state "original CPCB data state"
la var agency "monitoring agency"
la var location "Location listed in data"
la var so2_max "Maximum observed SO2 in that year"
la var so2_min "Minimum observed SO2 in that year"
la var so2_mean "Average across SO2 observations in that year"
la var so2_n "Number of days of SO2 observations in that year"
la var no2_max "Maximum observed NO2 in that year"
la var no2_min "Minimum observed NO2 in that year"
la var no2_mean "Average across NO2 observations in that year"
la var no2_n "Number of days of NO2 observations in that year"
la var spm_max "Maximum observed SPM in that year"
la var spm_min "Minimum observed SPM in that year"
la var spm_mean "Average across SPM observations in that year"
la var spm_n "Number of days of SPM observations in that year"
la var offexced_so2_i "Official designation: exceedance factors for SO2 industrial areas - 1996 on"
la var offexced_no2_i "Official designation: exceedance factors for NO2 industrial areas - 1996 on"
la var offexced_spm_i "Official designation: exceedance factors for SPM industrial areas - 1996 on"
la var offexced_so2_r "Official designation: exceedance factors for SO2 residential areas - 1996 on"
la var offexced_no2_r "Official designation: exceedance factors for NO2 residential areas - 1996 on"
la var offexced_spm_r "Official designation: exceedance factors for SPM residential areas - 1996 on"
la var city "city full name"
la var state "state full name"
la var restncode "corrected station code "
la var year "data year from CPCB data files' labels"

drop SPMSTD NO2STD SO2STD
ren SO2SD so2_sd
ren NO2SD no2_sd
ren SPMSD spm_sd
la var so2_sd "Standard Deviation among SO2 observations in this year"
la var no2_sd "Standard Deviation among NO2 observations in this year"
la var spm_sd "Standard Deviation among SPM observations in this year"

ren SO2VIO so2_vio
ren NO2VIO no2_vio
ren SPMVIO spm_vio
la var so2_vio "number of days SO2 violated the 24 hourly standard"
la var no2_vio "number of days NO2 violated the 24 hourly standard"
la var spm_vio "number of days SPM violated the 24 hourly standard"

/* Use two variables for percent of days violating the 24-hr standard: for 92-94 use the VIO variables, and for 
	other years use the AT variables.  The AT variables are missing in 92-94. Also, according to the CPCB engineer 
	who oversees these data ("Naresh"), the VIO variables are actually the codes used for the AT variables in 1992 
	through 1994. */
ren SO2AT so2_pctv
ren NO2AT no2_pctv
ren SPMAT spm_pctv
replace so2_pctv = SVIO if year >= 1992 & year <= 1994
replace no2_pctv = NVIO if year >= 1992 & year <= 1994
replace spm_pctv = PVIO if year >= 1992 & year <= 1994
la var so2_pctv "the percentage of monitored days in which SO2 violated the 24 hourly standard"
la var no2_pctv "the percentage of monitored days in which NO2 violated the 24 hourly standard"
la var spm_pctv "the percentage of monitored days in which SPM violated 24 hourly standard"
drop SVIO PVIO NVIO

/* Drop confusing variables that should not be used: */

drop stncode 
ren restncode stncode

* Make state/city/location names comparable to other files. This is most important for the locations.
do "${mypath}Do Files/Data Cleaning/clean_names_01102014.do"

* Rename each variable to start with e_, which denotes that it is an electronic reading.
foreach var of varlist spm_mean no2_mean so2_mean spm_max-so2_n so2_sd-offexced_spm_r {
	ren `var' e_`var'
}

* Fix values that are clearly errors
replace e_so2_min = . if e_so2_min < 0
replace e_no2_min = . if e_no2_min < 0
l if e_spm_max > 14000 & e_spm_max < .
l if city == "Kochi" & state == "Kerala" & type == "I"
l if city == "Alwar" & state == "Rajasthan" & type == "I"
replace e_spm_max = . if e_spm_max>14000 & e_spm_max<.

* There are 18 duplicate stationcode-years, all are non-missing. Arbitrarily sorting according to size to choose which to drop. This selection is robust.
gsort state city stncode year -e_spm_mean -e_no2_mean -e_so2_mean -e_spm_max -e_no2_max -e_so2_max -e_spm_min -e_no2_min -e_so2_min -e_spm_n -e_no2_n -e_so2_n 
by state city stncode year: keep if _n == 1

preserve
	drop if type == ""
	so stncode type year
	by stncode: g temp = type[1] ~= type[_N]
	ta temp
	so stncode year type
	l stncode year type location if temp == 1
restore

* To deal with monitors changing type (industrial/residential), my solution is to replace missing values 
*	with the surrounding values when the surrounding values are the same. When the surrounding values are 
*	not the same, choose the type which is mode for the monitor. A few station codes are missing for all the 
*	station's years, leading to 18 obs still missing after this imputation.
g Ftype = ""
g Ltype = ""
so stncode year
forv n = 1/10 {
	by stncode: replace Ftype = type[_n + `n'] if Ftype == ""
	by stncode: replace Ltype = type[_n - `n'] if Ltype == ""
}

replace type = Ftype if Ftype == Ltype & type == "" & Ftype ~= ""
egen temp = mode(type), by(stncode) maxmode /* when there are multiple modes, take the highest letter. arbitrary choice. */
replace type = temp if type == ""
drop temp

* Note that resid includes residential and all other types.
g resid = type == "R" | type == "A" | type == "B" | type == "C" if type ~= ""
g indus = type == "I" if type ~= ""
g sensit = type == "S" if type ~= ""

* Count n for industrial/sensitive so we know the share of each city which is of each type. Count it for residential 
*	to achieve that goal and also to calculate residential pollution across pollution measurements.
g e_spm_n_r = e_spm_n if resid == 1
g e_no2_n_r = e_no2_n if resid == 1
g e_so2_n_r = e_so2_n if resid == 1
g e_spm_n_i = e_spm_n if indus == 1
g e_no2_n_i = e_no2_n if indus == 1
g e_so2_n_i = e_so2_n if indus == 1
g e_spm_n_s = e_spm_n if sensit == 1
g e_no2_n_s = e_no2_n if sensit == 1
g e_so2_n_s = e_so2_n if sensit == 1

g e_spm_mean_r = e_spm_mean if resid == 1
g e_no2_mean_r = e_no2_mean if resid == 1
g e_so2_mean_r = e_so2_mean if resid == 1
g e_spm_min_r = e_spm_min if resid == 1
g e_no2_min_r = e_no2_min if resid == 1
g e_so2_min_r = e_so2_min if resid == 1
g e_spm_max_r = e_spm_max if resid == 1
g e_no2_max_r = e_no2_max if resid == 1
g e_so2_max_r = e_so2_max if resid == 1

* Define the 1994 National Ambient Air Quality Standards
g spm_naaqs_r = 140 if resid == 1
g spm_naaqs_i = 360 if indus == 1
g no2_naaqs_r = 60 if resid == 1
g no2_naaqs_i = 80 if indus == 1
g so2_naaqs_r = 60 if resid == 1
g so2_naaqs_i = 80 if indus == 1

*****************
* Append 2004-2007 data

* Append (and erase old datasets)
append using "Intermediate Data/e_ap04_my.dta"
append using "Intermediate Data/e_ap0507_my.dta"

* -Type- is sometimes coded as Critical and sometimes as Sensitive. These are the same; I am recoding Critical as Sensitive.
replace type = "S" if type == "C"

* Some monitors change type. Following code in air_pollution_electronic.do, I am keeping type consistent, and thus taking 
*	the mode of type in all cases where the type changes.
egen temp = mode(type), by(stncode) maxmode
replace type = temp
drop temp

so state city stncode year
order stncode type state city year

* Fixing more city names
ta city
replace city = "Yamunanagar" if city == "Yamuna Nagar"
replace city = "Ankaleshwar" if city == "Ankleshwar"
replace city = "Kozhikode" if city == "Calicut (Kozhikode)"
replace city = "Dehradun" if city == "Dehradoon"
replace city = "Gajraula" if city == "Gajroula"
replace city = "Pondicherry" if city == "Pondichery"
replace city = "Rajpur" if city == "Raipur"
replace city = "Shillong" if city == "Shilong"
replace city = "Solapur" if city == "Solapur Corp"
replace city = "Thane" if city == "Thane Corp."
replace city = "Thiruvananthapuram" if city == "Trivendrum"
replace city = "Thiruvananthapuram" if city == "Tiruvananthapuram"
replace city = "Kochi" if city == "Cochin"
replace city = "Palghat" if city == "Palakkad"
replace city = "Bhilai" if city == "Durg-Bhilai Nagar"
replace city = "Pune" if city == "Pune Corp"
replace city = "Kolkata" if city == "Calcutta"
replace city = "Panaji" if city == "Panjim"
replace city = "Vadodara" if city == "Baroda"
replace city = "Hubli-Dharwad" if city == "Hubballi"
replace city = "Silvassa" if city == "Dadra & Nagar Haveli" 
* D & N Haveli is not a city, its a state/territory. I am choosing the capital as the proper city where pollution is monitored.

* Fix state name
replace state = "Dadra & Nagar Haveli" if state == "Daman & Diu + Dadra & Nagar Haveli" & city == "Silvassa"
replace state = "Daman & Diu" if state == "Daman & Diu + Dadra & Nagar Haveli" & city == "Daman"

sa "Intermediate Data/ap_mntrs.dta", replace

*********************************************
* Add district population weights to the ap_mntrs dataset (saves new e_airpol_mntrs.dta)

do "${mypath}Do Files/Data Cleaning/census_in_01102014.do"

*********************************************
* Now collapse this to a city-year file, so get values across monitors within each city-year.

* This gives us the totals by monitor-year.
gen e_spm_mult = e_spm_mean * e_spm_n
gen e_no2_mult = e_no2_mean * e_no2_n
gen e_so2_mult = e_so2_mean * e_so2_n

* This gives us the residential totals by monitor-year.
gen e_spm_mult_r = e_spm_mean_r * e_spm_n_r
gen e_no2_mult_r = e_no2_mean_r * e_no2_n_r
gen e_so2_mult_r = e_so2_mean_r * e_so2_n_r
	
* This sums the monitor-year totals across an entire city, then collapses to the city-year dataset.
collapse (sum) e_so2_mult e_no2_mult e_spm_mult e_so2_mult_r e_no2_mult_r e_spm_mult_r e_so2_n e_no2_n e_spm_n e_so2_n_r e_no2_n_r e_spm_n_r e_so2_n_i e_no2_n_i e_spm_n_i e_so2_n_s e_no2_n_s e_spm_n_s (max) pop* lit* e_so2_max e_no2_max e_spm_max e_so2_max_r e_no2_max_r e_spm_max_r (min) e_so2_min e_no2_min e_spm_min e_so2_min_r e_no2_min_r e_spm_min_r, by(state district city year)

* The collapse is creating zeros where there used to be missing values.  I am replacing zeros with missings to fix this.
foreach x of varlist e_so2_mult e_no2_mult e_spm_mult e_so2_mult_r e_no2_mult_r e_spm_mult_r {
	replace `x' = . if `x' == 0
}

* This creates new city-wide mean pollution readings.  
gen e_spm_mean = e_spm_mult / e_spm_n
gen e_no2_mean = e_no2_mult / e_no2_n
gen e_so2_mean = e_so2_mult / e_so2_n
gen e_spm_mean_r = e_spm_mult_r / e_spm_n_r
gen e_no2_mean_r = e_no2_mult_r / e_no2_n_r
gen e_so2_mean_r = e_so2_mult_r / e_so2_n_r

la var e_so2_max "Maximum so2 in this city-year"
la var e_no2_max "Maximum no2 in this city-year"
la var e_spm_max "Maximum spm in this city-year"
la var e_so2_min "Minimum so2 in this city-year"
la var e_no2_min "Minimum no2 in this city-year"
la var e_spm_min "Minimum spm in this city-year"
la var e_so2_mean "Mean so2 in this city-year across pollution observations"
la var e_no2_mean "Mean no2 in this city-year across pollution observations"
la var e_spm_mean "Mean spm in this city-year across pollution observations"
la var e_so2_mean_r "Mean so2 in this city-year FOR RESIDENTIAL AREAS across pollution observations"
la var e_no2_mean_r "Mean no2 in this city-year FOR RESIDENTIAL AREAS across pollution observations"
la var e_spm_mean_r "Mean spm in this city-year FOR RESIDENTIAL AREAS across pollution observations"
la var e_so2_n "# so2 obs in this city-year"
la var e_no2_n "# no2 obs in this city-year"
la var e_spm_n "# spm obs in this city-year"
la var district "district full name"

g e_airpoldata = 1
order state district city year pop_total pop_urban lit_total lit_urban e_spm_mean e_so2_mean e_no2_mean e_spm_max e_so2_max e_no2_max e_spm_min e_so2_min e_no2_min e_spm_mean_r e_so2_mean_r e_no2_mean_r e_spm_max_r e_so2_max_r e_no2_max_r e_spm_min_r e_so2_min_r e_no2_min_r
drop *mult*
so state city year
save "Intermediate Data/e_airpol_city.dta", replace

cd "${mypath}Data/Air Data"
