***********************************************************************************

* File: census_in_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This file merges the University of Maryland's Indian District Database, which contains census data from 
	1981 and 1991, with the 2001 Census. These census data are later used as controls in the regression analysis.

Structure:
1. UMD Database - 1981, 1991
2. Census - 2001
3. Append and clean names
4. Clean district names in master air dataset
*/	

***********************************************************************************

clear all
set more off
set mem 500m


************************************************************************
* 1. UMD Database - 1981 and 1991

* Change directory to the Census2001 folder (most files will come from there, making the loop code easier)
cd "${mypath}Data/Controls/Census/Raw Data/2001"

* Use the UMD dataset (downloaded from Internet)
u "../UMD/panel91.dta", clear 

* Keep relevant variables: Population and Literacy and ID info, total and urban, years 1981 and 1991
keep dlabel pop8 pop9 lit8 lit9 litr8 litr9 urban8 urban9 stateid

* Reshape so each observation is a district-year
reshape long pop lit litr urban, i(dlabel stateid) j(year)

* Clean, create, fix, rename variables
replace year = 1981 if year == 8
replace year = 1991 if year == 9
g lit_urban = lit - litr
rename lit lit_total
rename pop pop_total
rename urban pop_urban
drop litr

* Use recognizable district names to decode stateid variable into state name
g state = ""
replace state = "Andaman & Nicobar Islands" if stateid == "01"
replace state = "Andhra Pradesh" if stateid == "02"
replace state = "Arunachal Pradesh" if stateid == "03"
replace state = "Assam" if stateid == "04"
replace state = "Bihar" if stateid == "05"
replace state = "Chandigarh" if stateid == "06"
replace state = "Dadra & Nagar Haveli" if stateid == "07"
replace state = "Delhi" if stateid == "08"
replace state = "Goa, Daman & Diu" if stateid == "09"
replace state = "Gujarat" if stateid == "10"
replace state = "Haryana" if stateid == "11"
replace state = "Himachal Pradesh" if stateid == "12"
replace state = "Jammu & Kashmir" if stateid == "13"
replace state = "Kerala" if stateid == "14"
replace state = "Lakshadweep" if stateid == "15"
replace state = "Madhya Pradesh" if stateid == "16"
replace state = "Maharashtra" if stateid == "17"
replace state = "Manipur" if stateid == "18"
replace state = "Meghalaya" if stateid == "19"
replace state = "Karnataka" if stateid == "20"
replace state = "Nagaland" if stateid == "21"
replace state = "Orissa" if stateid == "22"
replace state = "Pondicherry" if stateid == "23"
replace state = "Punjab" if stateid == "24"
replace state = "Rajasthan" if stateid == "25"
replace state = "Tamil Nadu" if stateid == "26"
replace state = "Tripura" if stateid == "27"
replace state = "Uttar Pradesh" if stateid == "28"
replace state = "West Bengal" if stateid == "29"
replace state = "Sikkim" if stateid == "30"
replace state = "Mizoram" if stateid == "31"
drop stateid

* Sort and save
sort dlabel state
save "../../Intermediate Data/pop_lit8191.dta", replace

*********************************************************************
* 2. Census - 2001

* Create a local variable to make insheeting forloop easier
local states "andaman andhra arunachal assam bihar chandigarh chhattisgarh dadranagarhaveli damandiu delhi goa gujarat haryana himachal jammu jharkhand karnataka kerala lakshadweep madhya maharashtra manipur meghalaya mizoram nagaland orissa pondicherry punjab rajasthan sikkim tamilnadu tripura uttaranchal uttarpradesh westbengal"

* Insheet each state csv file (exported from Census CD), create a state variable
foreach y of local states {
	insheet using "`y'.csv", clear
	g state = "`y'"
	save "`y'.dta", replace
}

* Append the files to each other to make one dataset
foreach y in andaman andhra arunachal assam bihar chandigarh chhattisgarh dadranagarhaveli damandiu delhi goa gujarat haryana himachal jammu jharkhand karnataka kerala lakshadweep madhya maharashtra manipur meghalaya mizoram nagaland orissa pondicherry punjab rajasthan sikkim tamilnadu tripura uttaranchal uttarpradesh {
	append using `y'.dta
	desc
	erase `y'.dta
}

* Reshape so each observation is a district-year (as opposed to district-type-year) ((type being "rural", "urban", or "total")
reshape wide totalpopulation totalliterates, i(name state) j(tru) string

* Keep, create, rename variables
drop totalpopulationRural totalliteratesRural
g year = 2001
rename name dlabel
rename totalpopulationTotal pop_total
rename totalpopulationUrban pop_urban
rename totalliteratesTotal lit_total
rename totalliteratesUrban lit_urban

* Clean state names
replace state = proper(state)
replace state = "Andhra Pradesh" if state == "Andhra"
replace state = "Uttar Pradesh" if state == "Uttarpradesh"
replace state = "Jammu & Kashmir" if state == "Jammu"
replace state = "Andaman & Nicobar Islands" if state == "Andaman"
replace state = "Madhya Pradesh" if state == "Madhya"
replace state = "West Bengal" if state == "Westbengal"
replace state = "Himachal Pradesh" if state == "Himachal"
replace state = "Tamil Nadu" if state == "Tamilnadu"
replace state = "Dadra & Nagar Haveli" if state == "Dadranagarhaveli"
replace state = "Arunachal Pradesh" if state == "Arunachal"
replace state = "Daman & Diu" if state == "Damandiu"

* Clean district names - many of them contain asterisks in the string. I am removing them
* Still leaves Senapati* instead of Senapati, but that is OK
g ast = strpos(dlabel, "*")
replace dlabel = subinstr(dlabel,"*","",1) if ast  != 0
replace dlabel = rtrim(dlabel)
drop ast

* Sort and save
sort dlabel state
save "../../Intermediate Data/pop_lit01.dta", replace

*************************************************************************
* 3. Append and clean

* Append UMD dataset to Census dataset
append using "../../Intermediate Data/pop_lit8191.dta"

* Re-order variables
order state dlabel year pop_total pop_urban lit_total lit_urban
rename dlabel district

* Sort
so state district year

* I notice a few zeros, nonsensical for variables like population and literacy. I am changing them to missing.
replace pop_urban = . if pop_urban == 0
replace lit_urban = . if lit_urban == 0

* Run clean_districts (specifically created for this population dataset but usable for others as well - this do-file changes district names to 1981 borders)
do "${mypath}Do Files/Data Cleaning/clean_districts_01102014.do"

* Fix Goa, Daman & Diu (The UMD database combines them into one district)
replace pop_total = 113989 + 44215 + 758573 + 589095 if district == "Goa, Daman & Diu" & year == 2001
replace pop_urban = 35770 + 21578 + 341749 + 328828 if district == "Goa, Daman & Diu" & year == 2001
replace lit_total = 81433 + 26167 + 566668 + 418894 if district == "Goa, Daman & Diu" & year == 2001
replace lit_urban = 25887 + 15272 + 260507 + 242440 if district == "Goa, Daman & Diu" & year == 2001
expand 2 if district == "Goa, Daman & Diu" & year == 1991
expand 2 if district == "Goa, Daman & Diu" & year == 1981
sort state
* Choosing _n == 1 below is arbitrary: observations are identical, just want to keep 1
bys state district year: drop if _n == 1 & (state == "Daman & Diu" | state == "Goa") & year == 2001
bys state district year: replace state = "Goa" if _n == 1 & state == "Goa, Daman & Diu"
replace state = "Daman & Diu" if state == "Goa, Daman & Diu"

* Sort
so state district year

* Collapse into means (many districts in 2001 now have multiple obs).  The premise here is that the 
*	multiple observations reflect sub-district totals, so we have to sum them together to achieve
*	the district totals.
collapse (sum) pop_total pop_urban lit_total lit_urban, by(state district year)

* Check for duplicates
duplicates tag state district year, g(dups)
ta dups
drop dups

* Change zeros to missings (Zero literacy is nonsensical)
replace pop_total = . if pop_total == 0
replace pop_urban = . if pop_urban == 0
replace lit_total = . if lit_total == 0
replace lit_urban = . if lit_urban == 0

* Create duplicate obs for interpolation
expand 21 if year == 1981
so state district year

* Fix year variable
bys state district: replace year = 1985 if _n == 2
bys state district: replace year = 1986 if _n == 3
bys state district: replace year = 1987 if _n == 4
bys state district: replace year = 1988 if _n == 5
bys state district: replace year = 1989 if _n == 6
bys state district: replace year = 1990 if _n == 7
bys state district: replace year = 1992 if _n == 8
bys state district: replace year = 1993 if _n == 9
bys state district: replace year = 1994 if _n == 10
bys state district: replace year = 1995 if _n == 11
bys state district: replace year = 1996 if _n == 12
bys state district: replace year = 1997 if _n == 13
bys state district: replace year = 1998 if _n == 14
bys state district: replace year = 1999 if _n == 15
bys state district: replace year = 2000 if _n == 16
bys state district: replace year = 2002 if _n == 17
bys state district: replace year = 2003 if _n == 18
bys state district: replace year = 2004 if _n == 19
bys state district: replace year = 2005 if _n == 20
bys state district: replace year = 2006 if _n == 21

* Erase copied pop and lit data
replace pop_total =. if year != 2001 & year != 1991 & year != 1981
replace pop_urban =. if year != 2001 & year != 1991 & year != 1981
replace lit_total =. if year != 2001 & year != 1991 & year != 1981
replace lit_urban =. if year != 2001 & year != 1991 & year != 1981

* Interpolate population and literacy variables
bys district: ipolate pop_total year, generate(pop_total1) epolate
bys district: ipolate pop_urban year, generate(pop_urban1) epolate
bys district: ipolate lit_total year, generate(lit_total1) epolate
bys district: ipolate lit_urban year, generate(lit_urban1) epolate

* Replace pop_total with pop_total1
replace pop_total = pop_total1
replace pop_urban = pop_urban1
replace lit_total = lit_total1
replace lit_urban = lit_urban1
drop pop_total1 pop_urban1 lit_total1 lit_urban1

* Drop 1981
drop if year == 1981

* Scale down variables
replace pop_total = pop_total / 1000
replace pop_urban = pop_urban / 1000
replace lit_total = lit_total / 1000
replace lit_urban = lit_urban / 1000

* Save
sort state district year
save "../../Final Data/pop_lit.dta", replace
erase "../../Intermediate Data/pop_lit01.dta"
erase "../../Intermediate Data/pop_lit8191.dta"

****************************************
* 4. Clean district names of master air dataset

* Use airpol monitors dataset, which has district variable (the airpol_city dataset at the moment leaves out district)
use "${mypath}Data/Air Data/Intermediate Data/ap_mntrs.dta", clear

* For cities that have some district info, apply the mode among all observations by city to empty district obs
bys state city: egen districtnew = mode(district)
replace district = districtnew
drop districtnew

* Assign districts to the remaining cities with no district info (these cities are new to the air pollution dataset in >=2004)
replace district = "Aizawl" if city == "Aizawl"
replace district = "Amritsar" if city == "Amritsar"
replace district = "Bardhaman" if city == "Asansol"
replace district = "Solan" if city == "Baddi"
replace district = "Vadodara" if city == "Baroda"
replace district = "Bathinda" if city == "Bathinda"
replace district = "Ganjam" if city == "Behrampur"
replace district = "Belgaum" if city == "Belgaum"
replace district = "Durg" if city == "Bhilai"
replace district = "Khurda" if city == "Bhubaneshwar"
replace district = "Bongaigaon" if city == "Bongaigaon"
replace district = "Kottayam" if city == "Chingavanam"
replace district = "Chittorgarh" if city == "Chittorgarh"
replace district = "Cuttack" if city == "Cuttack"
replace district = "Dadra & Nagar Haveli" if city == "Silvassa"
replace district = "Saharanpur " if city == "Deoband"
replace district = "Mohali" if city == "Derabessi"
replace district = "Dewas" if city == "Dewas"
replace district = "Rewari" if city == "Dharuhera"
replace district = "Dharwad" if city == "Dharwad"
replace district = "Dibrugarh" if city == "Dibrugarh"
replace district = "Bardhaman" if city == "Durgapur"
replace district = "Firozabad" if city == "Firozabad"
replace district = "Golaghat" if city == "Golaghat"
replace district = "Gulbarga" if city == "Gulbarga"
replace district = "Gwalior" if city == "Gwalior"
replace district = "Hailakandi" if city == "Hailakandi"
replace district = "Hassan" if city == "Hassan"
replace district = "Hissar" if city == "Hissar"
replace district = "Dharwad" if city == "Hubballi"
replace district = "Dharwad" if city == "Hubli-Dharwad"
replace district = "Jammu" if city == "Jammu"
replace district = "Jhansi" if city == "Janshi"
replace district = "Sirmaur" if city == "Kala Amb"
replace district = "Ludhiana" if city == "Khana"
replace district = "Kolhapur" if city == "Kolhapur"
replace district = "Kurnool" if city == "Kurnool"
replace district = "Ratnagiri" if city == "Lote"
replace district = "Dakshina Kannada" if city == "Mangalore"
replace district = "South Goa" if city == "Mormugao"
replace district = "Thane" if city == "Navi Mumbai"
replace district = "Rupnagar" if city == "Naya Nangal"
replace district = "Palakkad" if city == "Palghat"
replace district = "North Goa" if city == "Panjim"
replace district = "Medak" if city == "Patancheru"
replace district = "Barwani" if city == "Rajpur"
replace district = "Ranchi" if city == "Ranchi"
replace district = "Sagar" if city == "Sagar"
replace district = "Sambalpur" if city == "Sambalpur"
replace district = "Singrauli" if city == "Singrauli"
replace district = "Sibsagar" if city == "Sivasagar"
replace district = "Thane" if city == "Tarapur"
replace district = "Sonitpur" if city == "Tezpur"
replace district = "Chittoor" if city == "Tirupati"
replace district = "Ujjain" if city == "Ujjain"
replace district = "Krishna" if city == "Vijaywada"
replace district = "Yamunanagar" if city == "Yamunanagar"
replace district = "Shimla" if city == "Shimla"
replace district = "Karimnagar" if city == "Ramagundam"
replace district = "Amravati" if city == "Amravati"
replace district = "Baleshwar (Balasore)" if city == "Balasore"
replace district = "Ludhiana" if city == "Khanna"
replace district = "Allahabad" if city == "Allahabad"
replace district = "Bulandshahr" if city == "Khurja"
replace district = "Meerut + Ghaziabad" if city == "Meerut"
replace district = "Jhansi + Lalitpur" if city == "Jhansi"

* Run clean_districts to change districts to reflect 1981-1991 borders
do "${mypath}Do Files/Data Cleaning/clean_districts_01102014.do"

******************************************
* 5. Merge population data into master air dataset

* Sort master data
so state district year

* Merge to find discrepancies in district names between master and using dataset
preserve
	cap drop _merge
	merge state district year using "../../Final Data/pop_lit.dta", uniqusing
	keep if year == 1991 | year == 2001
	keep state district city year pop_total _merge
	so state district
restore

* Clean district names 
replace state = "Dadra & Nagar Haveli" if state == "Daman & Diu + Dadra & Nagar Haveli" & city == "Dadra & Nagar Haveli"
replace state = "Daman & Diu" if state == "Daman & Diu + Dadra & Nagar Haveli" & city == "Daman"
replace district = "Hyderabad+Rangareddi" if district == "Hyderabad and Rangareddi"
replace district = "Goa, Daman & Diu" if district == "Goa" | district == "Daman & Diu"
replace district = "Bangalore" if district == "Bangalore (R+U)"
replace district = "Haora" if district == "Howrah"
replace district = "Hisar + Sirsa" if district == "Hissar"
replace district = "Sidhi" if district == "Singrauli"
replace district = "Greater Bombay" if district == "Mumbai (Suburban) and Mumbai"
replace district = "Puri" if district == "Khurda"
replace district = "Patiala" if district == "Mohali"
replace district = "Chittaurgarh" if district == "Chittorgarh"
replace district = "Meerut + Ghaziabad" if district == "Gautambudhnagar"
replace district = "Saharanpur" if district == "Saharanpur "
replace district = "Barddhaman (Burdwan)" if district == "Bardhaman"
sort state district year

**********
* This code balances the city-year panel so that control data can be added to all city-years, especially those which have missing airpol data but non-missing IM data
egen city_id = group(state city)
fillin city_id year
bys city_id: egen citytemp = mode(city)
replace city = citytemp
drop citytemp
bys city_id: egen statetemp = mode(state)
replace state = statetemp
drop statetemp
bys city_id: egen districttemp = mode(district)
replace district = districttemp
drop districttemp
so state district year
***********

* Merge 
cap drop _merge
merge state district year using "../../Final Data/pop_lit.dta", uniqusing
drop _merge

* Interpolate population and literacy variables
bys district: ipolate pop_total year, generate(pop_total1) epolate
bys district: ipolate pop_urban year, generate(pop_urban1) epolate
bys district: ipolate lit_total year, generate(lit_total1) epolate
bys district: ipolate lit_urban year, generate(lit_urban1) epolate

* Replace pop_total with pop_total1
replace pop_total = pop_total1
replace pop_urban = pop_urban1
replace lit_total = lit_total1
replace lit_urban = lit_urban1
drop pop_total1 pop_urban1 lit_total1 lit_urban1

* Drop obs without city data (these are obs from the population dataset that had nothing to merge with
drop if city == ""

* Drop unidentifiable obs
drop if city == "JAJ"
drop if city == "REN"

* Rename the "Goa, Daman & Diu" district according to each state (even though the population estimates are the same 
*	regardless of state; this uniquely id's districts)
replace district = "Goa" if state == "Goa"
replace district = "Daman & Diu" if state == "Daman & Diu"

* Move district variable to front of the dataset
order stncode type state district city year pop_total pop_urban lit_total lit_urban

* Save
save "${mypath}Data/Air Data/Intermediate Data/e_airpol_mntrs.dta", replace

cd "${mypath}Data/Air Data/"
