***********************************************************************************

* File: clean_waternames_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This file cleans & reconciles conflicting river names and corrects misspelt city and river names.

Structure:
1. Reconcile -river- and -waterbodyname- discrepancies
2. Clean city names
3. Clean river names
*/

***********************************************************************************

* 1. Reconcile -river- and -waterbodyname-

replace waterbodyname = proper(waterbodyname)

* Using "Environmental Atlas of India" for reconciling "river" and "waterbody" names

foreach y in river waterbodyname {
	replace `y' = "Achankoil" if `y' == "Achenkoil"
	replace `y' = "Brahmaputra" if `y' == "Brahmputra"
	replace `y' = "Brahmani" if `y' == "Brahmini"
	replace `y' = "Ghaggar" if `y' == "Ghagger"
}

ta river waterbodyname if river != waterbodyname
ta stncode if river != waterbodyname

* br if stncode == 1312
* The Bhima and Godavari rivers do not touch. The two locations are hundreds of miles away. The confluence of the Bhima and Nira Rivers is in Karnataka. Since all obs at stncode 1312 are listed as Jayakwadi Dam, Paithan Town, Maharashtra, I think waterbody correctly IDs the river in question.
replace river = "Godavari" if stncode == 1312

* br if stncode == 1300
* The Ib River is hard to locate, but I believe it is north of the Hirakud Dam. Raj Nagar is also north of said dam. I am coding this as "Ib River"
replace river = "Ib" if stncode == 1300

* br if stncode == 1315
* The two rivers coded for this monitor are the Nira and Godavari. But the town of Pulgaon is well documented and is on the Wardha River.
replace river = "Wardha" if stncode == 1315

/* The following observations include waterbodyname or river values that are not rivers and are therefore impossible to locate.
br if stncode == 1848
br if stncode == 1869
br if stncode == 1870
br if stncode == 1871
*/

* Empty obs. I'm dropping it.
drop if stncode == 1848 | stncode == 1869 | stncode == 1870 | stncode == 1871
drop if stncode == 2069

* br if stncode == 1884
* I think Kala Amb is the town, and Markanda is the river.
replace river = "Markanda" if stncode == 1884

* br if stncode == 1893
* The Kaveri (Cauvery) river flows much further south than Hassan. The Yagachi Dam (River?) is much closer.
replace river = "Yagachi" if stncode == 1893

* br if stncode == 1905
* Should be Panchaganga, not Chanchaganga
replace river = "Panchaganga" if stncode == 1905

**************************************************************
* Clean city names

* Stncode 49 has city = Jamshedpur (Tata Nagar), which is very much within the city boundaries of Jamshedpur. I am recoding city to match the 
*	other observation in Jamshedpur. 
replace city = "Jamshedpur" if stncode == 49
replace nrcp = 1 if city == "Jamshedpur" & year > 1995

* Stncode 1246 has city = Kachigaon D/S (Daman). It matches up with another monitor having city = Kachigaon. I am recoding stncode 1246.
replace city = "Kachigaon" if stncode == 1246

* Nashik is coded as "Nasik" in two stncodes. I am recoding to the proper city name.
replace city = "Nashik" if stncode == 1211 | stncode == 1095
replace nrcp = 1 if city == "Nashik" & year > 1995

* Tiruchirappalli is coded as "Trichy" sometimes. I am recoding in these instances.
replace city = "Tiruchirappalli" if stncode == 1203
replace nrcp = 1 if city == "Tiruchirappalli" & year > 1995

* Stncodes 1046 and 1049 are mis-identified. They are areas/points within the city of Allahabad
replace city = "Allahabad" if stncode == 1046 | stncode == 1049

* Stncode 44 is identified as Sethanighat, which is in Hoshangabad
replace city = "Hoshangabad" if stncode == 44
replace nrcp = 1 if city == "Hoshangabad" & year > 1995

* Clean state names: Madhopur is given to be in Himachal Pradesh. On Google Maps, it appears to be in Jammu & Kashmir. On Wikipedia (and many 
*	other sites), it is listed as in Punjab
replace state = "Punjab" if city == "Madhopur"
replace state = "Madhya Pradesh" if state == "Chhattisgarh"
replace state = "Bihar" if state == "Jharkhand"
replace state = "Himachal Pradesh" if city == "Kala Amb"
replace state = "Rajasthan" if city == "Dholpur"

******************************************************************
* Clean river names

replace river = "Amravati" if river == "Amaravati"
replace river = "Ghaggar" if river == "Gaggar" | river == "Ghagara"
replace river = "Cauvery" if river == "Kaveri"
replace river = "Manjeera" if river == "Manjera"
replace river = "Subarnarekha" if river == "Subararekha"

* Stncode 1072 is errantly coded as Varanasi at Gomti River. This is nonsensical - the Gomti River is north of Varanasi, and the coordinates given are south. I cannot identify this as the Ganga River for sure, so I suggest dropping it.
drop if stncode == 1072

******************************************************************
* Fixing assignments of action plans

* Dakshineshwar is in Howrah, and Garden Reach is part of Kolkata, both of which were treated under GAP1
replace gap1 = 1 if city == "Dakshineshwar" & year >= 1986
replace gap1 = 1 if city == "Garden Reach" & year >= 1986

* Allahabad-Ganga was part of GAP1 and GAP2. Code as such.
replace gap1 = 1 if city == "Allahabad" & river == "Ganga"
replace gap2 = 1 if city=="Allahabad" & river == "Ganga" & year >= 1993
replace gap2 = 0 if city == "Allahabad" & river == "Ganga" & year < 1993
* Allahabad-Yamuna is not covered anywhere (most specifically GAP-2 or YAP-1)
replace gap2 = 0 if city == "Allahabad" & river == "Yamuna"

* Nagda was a part of of NRCP. Code as such.
replace nrcp = 1 if city == "Nagda" & year >= 1995

* Create action variable for aggregate of all river action plans
cap drop action
g action = (yap1 == 1 | gap1 == 1 | gap2 == 1 | nrcp == 1 | dap == 1 | gomtiap1 == 1)
