***********************************************************************************

* File: im_city_data_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: 
 This file creates a 1987-2004 month-by-city database of mortality variables including birth, death, 
 	infantdeath, maternaldeath, and stillborn. As underlying data sources it uses 1995-2004 data Rema 
 	and RAs collected from each state of India; and from several year-specific files obtained from 
 	books in the Berkeley library (the years are 87, 89, 90, 92, 94, 95). 

Structure:
1. Input the 95-04 database which contains manually collected data, and do basic cleaning on it. Each obs is a city-year.
2a to 2f. Input the separate 1987, 1989, 1990, 1992, 1994, 1995 data which were obtained from books in Berkeley library. 
	Do basic cleaning on each file. Again each obs is a city-year.
3a. Combine the constituent data files cleaned in steps 1 and 2a-f.
3b. Fix state and city names
3c. Keep one year of data per city, then save the resulting file, which has one obs per city-year.
4. Save as cityIMdata.dta

Notes: 
1. I made organizing changes to all the files. I removed semicolon delimiters and used cd to organize project directories. I'm spacing things more widely and adding spaces around relations and assignment operators (==, =, >, etc.) so language-recognizing text editors (editplus, notepad++, etc.) can parse the command. I erase the temporary files created in the process of executing the code. I wrote loops to simplify some repeated commands. I used >= . rather than == . and similar for nonmissing since is (rarely) important in stata versions 8ish or higher. I added parentheses to ensure that logical operators are correct (for example, X & Y | Z I replaced with X & (Y | Z)). I use the shortest possible state abbreviation for commands--usually I left the original code as it was but when I wrote code I use these abbreviations (e.g., g for generate, su for summarize, ta for tabulate, cap for capture, sa for save, so for sort, bys for bysort, pr de for program define, la de for label define, la val for label values, u for use, etc.)
*/

***********************************************************************************

set more off
clear all
set memory 500m
version 9.0

cd "${mypath}Data/Infant Mortality/IM City"

* 1. Input 1995-04 data

* This step inputs the city-level infant mortality data for 1995-2004. 
insheet using "Raw Data/City 95 04.csv", clear

* ID the data source
gen source = "IM COLLECTED"
la var source "Source of this infant mortality observation"

* This file has a bunch of "v" variables which are all meaningless. Show that they're meaningless then drop them.
foreach var of varlist v9-v41 {
	assert `var' >= .
	drop `var'
}

replace infantdeath = "2" if infantdeath == "2"
foreach var of varlist birth death infantdeath {
	replace `var' = "" if `var' == "-"
}

* Note: the only remaining non-numeric character in the "death" variable is something like `- ', but this code and the original code don't quite get 
*	it with replace, so use replace force for the death variable.
destring birth infantdeath, replace
destring death, replace force

* All variables have many duplicates, so keep one copy of each pair.
duplicates tag , g(dups)
so state city year dups
by state city year: g n = _n
ta n
assert n == 1 | n == 2
drop if n == 2
drop dups n

save "Intermediate Data/city95_04.dta", replace

* 2a. BOOK 1987

insheet using "Raw Data/City 87.csv", name clear

ren birth1987 birth
ren death1987 death
ren infantdeath1987 infantdeath
ren maternaldeath1987 maternaldeath

foreach var of varlist birth death infantdeath maternaldeath {
	replace `var' = "" if `var' == "-" | `var' == "N.A." | `var' == "Na"
}
replace birth = "2665" if birth == "2'665"
replace birth = "4190" if birth == "4,190"
destring birth death infantdeath maternaldeath, replace

gen year = 1987
gen source="BOOK 1987"
save "Intermediate Data/temp87.dta", replace

* 2b. BOOKS 1989

insheet using "Raw Data/City 89.csv", name clear
reshape long birth death infantdeath maternaldeath, i(state city) j(year)

foreach var of varlist birth death infantdeath maternaldeath {
	replace `var' = "" if `var' == "-" | `var' == "N.A." | `var' == "Na" | `var' == "N.R."
}
destring birth death infantdeath maternaldeath, replace

gen source = "BOOK 1989"
save "Intermediate Data/temp89.dta", replace

* 2c. BOOKS 1990

insheet using "Raw Data/City 90.csv", name clear
reshape long birth death infantdeath maternaldeath, i(state city) j(year)

foreach var of varlist birth death infantdeath maternaldeath {
	replace `var' = "" if `var' == "-" | `var' == "N.A." | `var' == "Na" | `var' == "N.R." | `var' == "N.A" | `var' == "*" | `var' == "@"
}
replace birth = "1960" if birth == "1960'"
destring birth death infantdeath maternaldeath, replace 

gen source = "BOOK 1990"
save "Intermediate Data/temp90.dta", replace

* 2d. BOOKS 1992

insheet using "Raw Data/City 92.csv", name clear
reshape long birth death infantdeath maternaldeath, i(state city) j(year)

foreach var of varlist birth death infantdeath maternaldeath {
	replace `var' = "" if `var' == "-" | `var' == "N.A." | `var' == "Na" | `var' == "N.R." | `var' == "N.A" | `var' == "*" | `var' == "@"
}
destring birth death infantdeath maternaldeath, replace

gen source = "BOOK 1992"
save "Intermediate Data/temp92.dta", replace

* 2e. BOOKS 1994

insheet using "Raw Data/City 94.csv", name clear
reshape long birth death infantdeath maternaldeath, i(state city) j(year)

foreach var of varlist birth death infantdeath maternaldeath {
	replace `var' = "" if `var' == "-" | `var' == "N.A." | `var' == "Na" | `var' == "N.R." | `var' == "N.A" | `var' == "*" | `var' == "@"
}
destring birth death infantdeath maternaldeath, replace

gen source = "BOOK 1994"
save "Intermediate Data/temp94.dta", replace

* 2f. BOOKS 1995

insheet using "Raw Data/City 95.csv", name clear
reshape long birth death infantdeath maternaldeath, i(state city) j(year)

foreach var of varlist birth death infantdeath maternaldeath {
	replace `var' = "" if `var' == "-" | `var' == "N.A." | `var' == "Na" | `var' == "N.R." | `var' == "N.A" | `var' == "*" | `var' == "@"
}
destring birth death infantdeath maternaldeath, replace

gen source = "BOOK 1995"
save "Intermediate Data/temp95.dta", replace

* 3a. STACK DATA

* Many city-state-year cells appear in several of these separate data sets. The goal of appending rather than merging is to preserve the different 
*	observations, then to use the actual data from the copy which is most informative. We can use the variable "source" to see in which underlying 
*	data an observation in the final data set originated.
use "Intermediate Data/city95_04.dta", clear
append using "Intermediate Data/temp87.dta"
append using "Intermediate Data/temp89.dta"
append using "Intermediate Data/temp90.dta"
append using "Intermediate Data/temp92.dta"
append using "Intermediate Data/temp94.dta"
append using "Intermediate Data/temp95.dta"
erase "Intermediate Data/temp87.dta"
erase "Intermediate Data/temp89.dta"
erase "Intermediate Data/temp90.dta"
erase "Intermediate Data/temp92.dta"
erase "Intermediate Data/temp94.dta"
erase "Intermediate Data/temp95.dta"

* 3b.CLEANING STATES AND CITY NAMES

* The following program contains all state fixes that were previously in this the various parts of code associated with this project
do "${mypath}Do Files/Data Cleaning/clean_names_01102014.do"
drop if state == "West Bengal" & city == "All Towns"
drop district /* The clean_names file assigns districts to some cities, but here we don't need them */

* Check that the geographic location cleaning leaves no remaining duplicates, no obvious errors, etc.
assert state ~= "" & city ~= "" & year < .
ta state
bys state: ta city
so city state
by city: g temp = state[1] ~= state[_N]
ta state city if temp == 1
drop temp

* 3c. KEEPING ONE YEAR OF DATA PER CITY

* Some manual corrections. These are inferred from seeing the result of the "list" command a few lines below and then listing all obs on the 
*	repeated cities. These are cities which were miswritten as another city in a particular year and so produced duplicates.
replace city = "Mumbai" if city == "Miraj" & state == "Maharashtra" & year == 2000 /* mumbai and miraj are distinct cities but in this one obs, mumbai was named as miraj. */
replace city = "Chalisgaon" if city == "Bhalisgaon" & state == "Maharashtra" & year == 1987 /* these are distinct cities but in this one obs, bhalisgaon was named as chalisgaon */
replace city = "Raniganj" if city == "Raiganj" & state == "West Bengal" & year == 1990
replace city = "Kharagpur" if city == "Kancharapara" & state == "West Bengal" & year == 1987 & infantdeath == 25
replace city = "Kancharapara" if city == "Kharagpur" & state == "West Bengal" & year == 1987 & death == 165
replace city = "Ratangarh" if city == "Sardarshahar" & state == "Rajasthan" & year == 1987 
replace city = "Sambhal" if city == "Sahajahanpur" & state == "Uttar Pradesh" & year == 1994 & birth == 1414
replace city = "Sahajahanpur" if city == "Saharanpur" & state == "Uttar Pradesh" & year == 1994 & birth == 3326
replace city = "Sambhal" if city == "Sahajahanpur" & state == "Uttar Pradesh" & year == 1993 & infantdeath == 13
replace city = "Sahajahanpur" if city == "Saharanpur" & state == "Uttar Pradesh" & year == 1993 & infantdeath == 85
replace city = "Saharanpur" if city == "Sambhal" & state == "Uttar Pradesh" & year == 1993 & infantdeath == 240

* Drop obs which are complete duplicates.
sort state city year birth death infantdeath maternaldeath stillborn source distcode statecode 
drop if state == state[_n-1] & city == city[_n-1] & year == year[_n-1] & birth == birth[_n-1] & death == death[_n-1] & infantdeath == infantdeath[_n-1] & maternaldeath == maternaldeath[_n-1] & stillborn == stillborn[_n-1]

* Among remaining obs, keep the one with the largest (this drops the missing values)
egen temp1 = rownonmiss(birth death infantdeath maternaldeath stillborn)
gsort state city year -temp1 -birth -death  -infantdeath -maternaldeath -stillborn 
drop if state == state[_n-1] & city == city[_n-1] & year == year[_n-1]
drop temp1

* Fixing cities that won't match up with air pol data
replace city = proper(city)
replace city = "Ankaleshwar" if city == "Ankleshwar"
replace city = "Yamunanagar" if city == "Yamuna Nagar"
replace city = "Vijaywada" if city == "Vijayawada"
replace city = "Tirupati" if city == "Tirupathi"
replace city = "Thane1" if city == "Thane"
replace city = "Thane" if city == "Thane Corp."
replace city = "Solapur1" if city == "Solapur"
replace city = "Solapur" if city == "Solapur Corp"
replace city = "Bhubaneshwar" if city == "Bhubaneswar"
replace city = "Behrampur" if city == "Beharampur"
replace city = "Chittor" if city == "Chittorgarh"
replace city = "Kozhikode" if city == "Calicut (Kozhikode)"
replace city = "Faridabad" if city == "Faribadad Complex Admn."
replace city = "Navi Mumbai" if city == "Navi Mum Corp."
replace city = "Silvassa" if city == "Dadra & Nagar Haveli"

*****************************************************************************************************
* Rename then construct some useful variables
foreach var of varlist birth death infantdeath maternaldeath stillborn source {
	ren `var' c_`var'
}

g c_IM = ( c_infantdeath / c_birth ) * 1000 
la var c_IM "Infant deaths per thousand births, city level"

* Zeros should be missing
replace c_IM = . if c_IM == 0

* Define log of IMR
g lnc_IM = ln(c_IM)
la var lnc_IM "Natural log of infant mortality rate"

******************************************************************************************************
* 4. Save data as cityIMdata.dta
g c_imdata = 1
sort state city year
save "Intermediate Data/cityIMdata.dta", replace
erase "Intermediate Data/city95_04.dta"

cd "${mypath}Data/Air Data"
