***********************************************************************************

* File: industry_compliance_prep_01102014.do
* Date: August 3, 2012
* Contact: Jon Petkun - petkunj@nber.org

/*
Objective: 
 This program's objective is to prepare data representing industrial compliance, 
	in Indian states, and to merge those new data with the existing India Pollution 
	datasets.

Structure:
0. Set-up
1. Insheet, reshape, and append together raw industry compliance data
2. Basic cleaning and formatting
3. Summary tables and graphs
4. Clean-up

Note: 

*/

***********************************************************************************

***********************************************************************************
* Section 0: Set-up
***********************************************************************************
cap log close 

clear all
set more off
set mem 500m
version 11.0

log using "${mypath}Log/industry_compliance_prep_01102014.txt", replace t

***********************************************************************************
* Section 1: Insheet and reshape raw industry compliance data
***********************************************************************************

* Insheet industry compliance data
insheet using "${mypath}Data/Controls/Industry Compliance/Raw Data/SPCB_industry_compliance.csv", clear names
drop stateid // stateid is superfluous for our needs
drop total_* // we'll generate our our state-year totals

* Reshape industry compliance data
reshape long closed_ compliers_ defaulters_, i(state) j(year)
rename closed_ closed
rename compliers_ compliers
rename defaulters_ defaulters

***********************************************************************************
* Section 2: Basic cleaning and reformatting
***********************************************************************************
* Clean state names so that they match the air/water data
replace state = "Pondicherry" if state == "UT-Pondicherry"
replace state = "Delhi" if state == "UT- Delhi"
replace state = "Chandigarh" if state == "UT- Chandigarh"

* Generate state-year industry totals
rename closed closed_industries
gen total_industries = closed_industries + compliers + defaulters

* Generate compliance ratios and top complier dummies
gen compliance_ratio = compliers / (total_industries - closed_industries)
bys year: egen compliance_median = pctile(compliance_ratio), p(50)
bys year: egen compliance_25pctile = pctile(compliance_ratio), p(75)
gen compliance_top50 = 1 if compliance_ratio >= compliance_median & compliance_ratio != .
replace compliance_top50 = 0 if compliance_top50 == .
gen compliance_top25 = 1 if compliance_ratio >= compliance_25pctile & compliance_ratio != .
replace compliance_top25 = 0 if compliance_top25 == .

* Save the full indust. compliance dataset (just in case we want to use it later)
save "${mypath}Data/Controls/Industry Compliance/Intermediate Data/industry_compliance_stateyear_full.dta", replace

* Drop states that aren't present in the air/water data
drop if state == "Arunachal Pradesh" | state == "Chattisgarh" | state == "Jharkhand" | state == "Sikkim" | ///
	state == "Uttaranchal" | strpos(state, "UT-") > 0

* Recalculate the compliance variables (using the more limited dataset)
drop compliance_*
* Generate compliance ratios and top complier dummies
gen compliance_ratio = compliers / (total_industries - closed_industries)
bys year: egen compliance_median = pctile(compliance_ratio), p(50)
bys year: egen compliance_25pctile = pctile(compliance_ratio), p(75)
gen compliance_top50 = 1 if compliance_ratio >= compliance_median & compliance_ratio != .
replace compliance_top50 = 0 if compliance_top50 == .
gen compliance_top25 = 1 if compliance_ratio >= compliance_25pctile & compliance_ratio != .
replace compliance_top25 = 0 if compliance_top25 == .
	
* Save state-year dataset
save "${mypath}Data/Controls/Industry Compliance/Intermediate Data/industry_compliance_stateyear.dta", replace

***********************************************************************************
* Section 3: Summary tables and graphs
***********************************************************************************
/*
preserve 
	
	* Collapse into nationwide time series
	collapse (mean) compliance_ratio compliance_25pctile compliance_median, by(year)
	
	* Create summary tables
	tablemat compliance_ratio compliance_25pctile compliance_median, st(mean) by(year) name(table1)
	mat2txt, matrix(table1) saving("${mypath}Output/IndustCompliance_SummaryTable.csv") replace
	
	* Plot average annual compliance ratio, annual 25th percentile ratios, and average median ratios
	#delimit ;
	twoway (connected compliance_ratio year, msymbol(T) mcolor(dkgreen) lcolor(dkgreen)),
		xsc(r(1995 2004)) xlabel(1995(1)2004) 
		ysc(r(0 1)) ylabel(0(.2)1) 
		xtitle("Year") ytitle("Avg. Compliance Ratio") 
		title("Avg. State Compliance Ratio, 1995-2004") legend(off) 
		saving("${mypath}Output/AvgIndustryCompliance.gph", replace);
		graph export "${mypath}Output/AvgIndustryCompliance.eps", replace;
		
	twoway (connected compliance_25pctile year, msymbol(T) mcolor(dkgreen) lcolor(dkgreen)),
		xsc(r(1995 2004)) xlabel(1995(1)2004) 
		ysc(r(0 1)) ylabel(0(.2)1) 
		xtitle("Year") ytitle("Avg. Compliance Ratio") 
		title("25th Percentile of State Compliance Ratios, 1995-2004") legend(off) 
		saving("${mypath}Output/Top25IndustryCompliance.gph", replace);	
		graph export "${mypath}Output/Top25IndustryCompliance.eps", replace;
		
	twoway (connected compliance_median year, msymbol(T) mcolor(dkgreen) lcolor(dkgreen)),
		xsc(r(1995 2004)) xlabel(1995(1)2004) 
		ysc(r(0 1)) ylabel(0(.2)1) 
		xtitle("Year") ytitle("Avg. Compliance Ratio") 
		title("Median State Compliance Ratio, 1995-2004") legend(off) 
		saving("${mypath}Output/MedianIndustryCompliance.gph", replace);
		graph export "${mypath}Output/MedianIndustryCompliance.eps", replace;
		
	#delimit cr
restore

***********************************************************************************
* Section 4: Clean-up
***********************************************************************************

log close
