***********************************************************************************

* File: policy_clean_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This program cleans the policy dataset in preparation for merging it with
	the raw pollution and infant mortality data.

Structure:
1. Load airpolicydata.dta
2. Run clean_names_01102014.do and fix other name issues
3. Add cities from '04-'07
4. Make final changes to currently-used variables
5. Save

Notes:
1. All the catalytic converter city-year variation is in 1995-1997
*/

***********************************************************************************

clear all
set mem 500m
set more off
version 9.0

cd "${mypath}Data/Policies"

capt log close
log using "${mypath}Log/policies_cleaned.txt", replace t

********************************************
* 1. Add airpolicydata

* add Abby's policy data. State-city-year uniquely identifies an observation.
u "Raw Data/airpolicydata.dta", clear
drop city_ac state_ac
ren city_full city
ren state_full state

********************************************
* 2. Clean names

* Run clean names program
do "${mypath}Do Files/Data Cleaning/clean_names_01102014.do"

* Drop one copy of tuticorin in Tamil Nadu. My emailing with Abby suggested that it's the same as tuticorin in Tamil Nadu. Also, drop one copy of Rayagada in Orissa since it's all duplicates too.
bys state city year: g temp = _n == 2
assert city == "Tuticorin" | city == "Rayagada" if temp == 1
drop if temp == 1
drop temp
	
* Fix city names
replace city = "Kozhikode" if city == "Calicut (Kozhikode)"
replace city = "Chittor" if city == "Chittorgarh"
replace city = "Ankaleshwar" if city == "Ankleshwar"
replace city = "Bhilai" if city == "Durg-Bhilai Nagar"
replace city = "Pune" if city == "Pune Corp"
replace city = "Solapur" if city == "Solapur Corp"
replace city = "Thane" if city == "Thane Corp."
replace city = "Shillong" if city == "Shilong"
replace city = "Chittorgarh" if city == "Chittor"

* Fix state name
replace state = "Dadra & Nagar Haveli" if city == "Silvassa"
replace state = "Daman & Diu" if city == "Daman"
	
* Save temporary file
tempfile policy_temp
save `policy_temp'

********************************************
* 3. Add new cities from 2004-2007

* Open air pollution datafile and isolate id variables
cd "${mypath}"
u "Data/Air Data/Intermediate Data/e_airpol_city.dta", clear
keep state district city year

* Save as temporary dataset
tempfile ap_temp
save `ap_temp'

* Open policy dataset and run clean districts
u `policy_temp', clear
do "${mypath}Do Files/Data Cleaning/clean_districts_01102014.do"

* This "Goa" business needs to be cleaned up...
replace district = "Goa" if state == "Goa"

* Merge ap_temp in, reorder variables
so state city year
merge state city year using `ap_temp', sort update replace
rename _merge merge
order state district city year

* Balance the panel
fillin city year
drop _fillin

* Fill in id variables that were coded as missing in the panel-balancing
rename state state_old
bys city: egen state = mode(state_old)
rename district district_old
bys city: egen district = mode(district_old)
drop state_old district_old
order state district city year

* Add policy indicators for new city-years
ta city if merge == 2
local newcities "Aizawl Allahabad Amravati Amritsar Asansol Baddi Balasore Bathinda Behrampur Belgaum Bhubaneshwar Bongaigaon Cuttack Deoband Derabessi Dewas Dibrugarh Durgapur Firozabad Golaghat Gulbarga Gwalior Hailakandi Hassan Hissar Hubli-Dharwad Imphal Jammu Jhansi "Kala Amb" Khana Khurja Kolhapur Kurnool Lote Mangalore Meerut Mormugao "Navi Mumbai" "Naya Nangal" Patancheru Ramagundam Ranchi Sagar Sambalpur Singrauli Sivasagar Tarapur Tezpur Tirupati Ujjain Vijaywada" 
foreach y of local newcities {
	replace naaqs = year >= 1994 if city == "`y'"
	replace comvehicles20 = year >= 1998 if city == "`y'"
	replace comvehicles17 = year >= 1998 if city == "`y'"
	replace comvehicles15 = 0 if city == "`y'"
	replace goodsvehicles = 0 if city == "`y'"
	replace benzene5 = 0 if city == "`y'"
	replace beneficiatedcoal = year >= 2002 if city == "`y'"
	replace hazindclosed = 0 if city == "`y'"
	replace hazindrelocate = 0 if city == "`y'"
	replace hotmixclosed = 0 if city == "`y'"
	replace brickkiln = 0 if city == "`y'"
	replace arcinduction = 0 if city == "`y'"
	replace massem_petrol = year >= 1991 if city == "`y'"
	replace massem_diesel = year >= 1992 if city == "`y'"
	replace coldstart = year >= 1998 if city == "`y'"
	replace massem_cng = year >= 2000 if city == "`y'"
	replace ammonia_naqqs = year >= 1998 if city == "`y'"
	replace fourstroke2wheel = year >= 1998 if city == "`y'"
	replace india2000 = year >= 2000 if city == "`y'"
	replace leadedg15 = year >= 1997 if city == "`y'"
	replace benzene3 = year >= 2005 if city == "`y'"
	replace loose2tbanned = 0 if city == "`y'"
	replace bharat2_com = year >= 2005 if city == "`y'"
	replace bharat2_ncom = year >= 2005 if city == "`y'"
	replace bharat3 = 0 if city == "`y'"
	replace sulph50 = 0 if city == "`y'"
	replace sulph25 = year >= 2000 if city == "`y'"
	replace sulph05_privveh = year >= 2005 if city == "`y'"
	replace sulph05_all = year >= 2005 if city == "`y'"
	replace benzene1 = 0 if city == "`y'"
	replace mrts_metro = 0 if city == "`y'"
	replace mrts_metro10 = 0 if city == "`y'"
	replace twowheelpremix_2t = 0 if city == "`y'"
	replace lowsmoke2t = year >= 1999 if city == "`y'"
	replace leadedg013 = year >= 2000 if city == "`y'"
	replace nonattain_cpcb = 0 if city == "`y'"
	replace delhiap = 0 if city == "`y'"
	replace april02sc = 0 if city == "`y'"
	replace may02sc = 0 if city == "`y'"
	replace aug03sc = 0 if city == "`y'"
	replace scap_allbutdelhi = 0 if city == "`y'"
	replace leadedg15_013 = 0 if city == "`y'"
	replace catconverter = 0 if city == "`y'"
}

* Apply by-state policies to new cities
rename spcb spcb_old
bys state year: egen spcb = mode(spcb_old), maxmode
replace spcb = 1 if state == "Jammu & Kashmir"
replace spcb = year >= 1989 if state == "Mizoram"
replace spcb = year >= 1992 if state == "Daman & Diu"

rename apca apca_old
bys state year: egen apca = mode(apca_old), maxmode
replace apca = year >= 1989 if state == "Mizoram"
/* Jammu & Kashmir and Daman & Diu unknown apca declaration - leave as missing */

rename statecpcbpwr statecpcbpwr_old
bys state year: egen statecpcbpwr = mode(statecpcbpwr_old), maxmode
replace statecpcbpwr = 0 if state == "Jammu & Kashmir"
replace statecpcbpwr = 0 if state == "Pondicherry"
replace statecpcbpwr = 0 if state == "Daman & Diu"
replace statecpcbpwr = 0 if state == "Delhi"
replace statecpcbpwr = 0 if state == "Chandigarh"
replace statecpcbpwr = 0 if state == "Mizoram"
drop *_old

* Merge in problem areas data
so state city year
merge state city year using "Data/Policies/Intermediate Data/probareas_ap.dta", sort
replace paap_ap = 0 if _merge == 1
replace paap_spm = 0 if _merge == 1
replace paap_no2 = 0 if _merge == 1
replace paap_so2 = 0 if _merge == 1
drop if _merge == 2
drop _merge merge year_citysortid yrcitysortid statecode distcode
	
********************************************
* 4. Last changes to policy variables

* Add 1-year lag to all court-ordered action plan variables. Court orders did not yield action plans until up to a year later in Delhi's case.
/* Court orders */
replace delhiap = 0 if city == "Delhi" & year < 1997
replace april02sc = 0 if year < 2003
replace may02sc = 0 if year < 2003
replace aug03sc = 0 if year < 2004

/* Sulph25 */
replace sulph25 = 0 if year < 1998
replace sulph25 = 0 if year == 1998 & (city == "Mumbai" | city == "Chennai" | city == "Kolkata")
replace sulph25 = 0 if year == 2000 & (city != "Delhi" & city != "Mumbai" & city != "Agra" & city != "Kolkata" & city!= "Chennai")

* Aggregate Supreme Court action plan mandates into 1 variable
egen actionplan_sc = rowmax(delhiap april02sc may02sc aug03sc)
	
* Delhi was never assigned a Problem Area Action Plan for some reason (see airpolicydictionary_may13.doc)
replace probareas = 1 if city == "Delhi" & year > 1990

* Agra apparently had .05% sulfur-in-diesel as of 2003 (p28 in ___________ from our CPCB library)
replace sulph05_privveh = 1 if year >= 2003 & city == "Agra"
replace sulph05_all = 1 if year >= 2003 & city == "Agra"

g policydata = 1

*********************************************
* 5. Save

* Save
cd "${mypath}Data/Policies"
sa "Final Data/policies_cleaned.dta", replace
