***********************************************************************************

* File: policy_merge_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This program cleans the income dataset and prepares it for merging with the pollution 
	data. The income data are used as a control in the regression analysis.

STRUCTURE
Section 1: Load poverty measures dataset
Section 2: Interpolate/extrapolate missing years
Section 3: Clean district names
Section 4: Clean-up

Notes:
1. There are multiple district breakdowns in this project. Urban population and literacy are broken down by 1981 district borders. This dataset 
	of income/poverty measures is originally divided by 1961 district name. The file clean_districts.do attempts to switch everything to 1981 
	borders. But in doing so, certain by-district data must be aggregated imprecisely (e.g. averaging two per capita expenditures together into 
	one district aggregate). This is done in the collapse command towards the end of this file. Additionally, Greater Bombay and Calcutta Districts 
	did not exist in 1961, so there is no precise income data for those districts. I take the next "closest" observation in these cases.
*/

***********************************************************************************

clear all
set more off
set mem 500m

********************************************************
*Section 1: Load poverty measures dataset
********************************************************

* Open poverty measures dataset, clean district names, interpolate values, sort, save
cd "${mypath}Data/Controls/Income"
u "Raw Data/india_pov_c81_updown_doc.dta", clear

* Keep only Year, District, State identifiers, and control variables to be used
keep year state_name _1981disname mean povgap

* Rename variables
rename state_name state
rename _1981disname district
replace district = proper(district)

* Drop pre-1983 values (We will use 1983 values for interpolating)
drop if year < 1983

* Andaman & Nicobar Islands have a duplicate 1983 observation with an alternate district name. I am dropping it.	
drop if district == "Andamans"	

********************************************************
*Section 2: Interpolate/Extrapolate missing years
********************************************************

* Creating a balanced panel for interpolation
* Sort
so state district year

* Introduce years 2000 - 2006 so that the -fillin- command creates observations for those years (this dataset comes with empty obs for all 
*	years in which no survey was conducted. I can change the year of a few of these empty obs because the -fillin- command is going to 
*	re-create them anyways.
replace year = 2000 if _n == 1
replace year = 2001 if _n == 2
replace year = 2002 if _n == 3
replace year = 2003 if _n == 4
replace year = 2005 if _n == 5
replace year = 2006 if _n == 6

* Concatenate state and district so that the -fillin- command creates new observations with all the necessary information ("fillin year state 
*	district" would not work)
egen statedist = concat(state district), punct(,)

* Create a balanced panel using the -fillin- command; this creates otherwise empty observations for all possible combinations of all year values 
*	and statedist values which appear in the dataset
fillin year statedist

* Split the concatenated variable to yield separate state and district variables
split statedist, p(,)

* Clean/drop/rename
drop state district statedist statedist3
rename statedist1 state
rename statedist2 district

* The "Goa, Daman and Diu" observation was messed up because of the extra comma in the state name
replace state = "Daman & Diu" if state == "Goa"
replace district = "Daman" if district == "Daman and Diu"

* Fix state names
replace state = "Dadra & Nagar Haveli" if state == "Dadra &Nagar Haveli"
replace state = "Jammu & Kashmir" if state == "Jammu &Kashmir"

* Drop empty artifacts of original dataset
drop if state == ""
drop if district == ""

* Interpolate/Extrapolate mean and povgap across all years
bys district: ipolate mean year, generate(newmean) epolate
bys district: ipolate povgap year, generate(newpovgap) epolate

* Reorder variables
drop _fillin mean povgap
order year state district newmean newpovgap
rename newmean mean
rename newpovgap povgap

* Drop years outside the scope of the pollution dataset
drop if year < 1985

********************************************************
*Section 3: Clean distric names
********************************************************

* Run clean districts
* NOTE: This will create duplicate state-district-years, because districts that are agglomerated in the other datasets are not so here. 
do "${mypath}Do Files/Data Cleaning/clean_districts_01102014.do"

* Collapse into district averages (not ideal but the best method at this juncture)
collapse (mean) mean povgap, by(state district year)

* Greater Bombay does not have an observation in this controls dataset. It used to be part of Thane District. I am making a copy of the latter 
*	and renaming it.
expand 2 if district == "Thane"
bys state district year: replace district = "Greater Bombay" if district == "Thane" & _n == 2

* Calcutta does not have an observation in this controls dataset. Howrah is its twin city and probably the most alike sociodemographically. I am 
*	making a copy of the latter and renaming it.
expand 2 if district == "Haora"
bys state district year: replace district = "Calcutta" if district == "Haora" & _n == 2

********************************************************
*Section 3: Clean-up
********************************************************

* Sort for merging
sort state district year

la var mean "average per capita expenditure - interpolated/extrapolated across years"
la var povgap "poverty gap/normalized aggregate shortfall of poor people's consumption - interpolated/extrapolated across years"
la var state "state"
la var district "district"

* Save dataset
save "Intermediate Data/pov.dta", replace
