***********************************************************************************

* File: probareas_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: 
 This file insheets a table of Problem Area Action Plan location and year of declaration, 
 	and then adds specific information about pollutant focus in each Problem Area. 

Notes:
1. Of the 3 water pollutants we are focusing on for our analysis (BOD, DO, FColi), BOD is the only one mentioned in the Environmental Atlas, 
	so I am going to create two indicators: one for general focus on water pollution, and one for those PAAPs which cite BOD in particular as 
	a pollutant. For air, on the other hand, I am creating four indicators: one for general focus on air pollution, and one for each specific 
	air pollutant focus (PM, SO2, NO2).
2. probareas.csv is a file containing the list of Problem Areas found in Abby's file (noted above).
3. Specific pollutant foci are taken from the 'Environmental Atlas of India.'
*/

***********************************************************************************

clear all
set more off

cd "${mypath}Data/Policies"

**********************
* Insheet raw table
insheet using "Raw Data/probareas.csv", clear

* Drop non-obs and compress
drop if year == .
compress
rename yeardeclaredproblemarea probarea_year
rename statename state
g city = problemarea

* Fix names
replace state = "Madhya Pradesh" if state == "Chattisgarh" | state == "Madhya Pradeh"
replace state = "Andhra Pradesh" if state == "A.P."
replace state = "Uttar Pradesh" if state == "U.P."
replace state = "Tamil Nadu" if state == "Tamilnadu" | state == "Tamil nadu"
replace state = "Delhi" if state == "--[1]"
replace city = "Talcher" if problemarea == "Angul  Talcher*"
replace city = "Bhadravathi" if problemarea == "Bhadravathi *"
expand 2 if problemarea == "Bollaram-Patancheru *"
bys problemarea: replace city = "Patancheru" if problemarea == "Bollaram-Patancheru *" & _n == 1
bys problemarea: replace city = "Bollaram" if problemarea == "Bollaram-Patancheru *" & _n == 2
replace city = "Dhanbad" if problemarea == "Dhanbad *"
replace city = "Digboi" if problemarea == "Digboi *"
replace city = "Durgapur" if problemarea == "Durgapur *"
replace city = "Kochi" if problemarea == "Greater Cochin *"
replace city = "Howrah" if problemarea == "Howrah *"
replace city = "Manali" if problemarea == "Manali *"
replace city = "Vellore" if problemarea == "Vellore (North Arcot) *"
replace city = "Visakhapatnam" if problemarea == "Visakapatnam *"
expand 2 if problemarea == "Mandi - Gobindgarh"
bys problemarea: replace city = "Mandi" if problemarea == "Mandi - Gobindgarh" & _n==1
bys problemarea: replace city = "Gobindgarh" if problemarea == "Mandi - Gobindgarh" & _n==2
replace city = "Nagda" if problemarea == "Nagda-Ratlam"
replace city = "Delhi" if problemarea == "Najafgarh Drain BasinArea"

* Singrauli is actually in Madhya Pradesh, not U.P.
replace state = "Madhya Pradesh" if city == "Singrauli"

* Create variables
g paap_wp = 1
replace paap_wp = 0 if city == "Kala Amb" | city == "Korba"
g paap_bod = 1
replace paap_bod = 0 if city == "Kala Amb" | city == "Bhadravathi" | city == "Korba" | city == "Dhanbad" | city == "Jodhpur" | city == "Singrauli" | city == "Durgapur" | city == "Talcher" /* The Atlas sometimes cites 'domestic sewage' or 'industrial sewage' as pollutants; I consider these equivalent to a BOD citation, since BOD is a general measure of pollution. Effectively, this variable removes cities that only appear to focus on toxic/heavy metals, etc. */
g paap_ap = 1
replace paap_ap = 0 if city == "Digboi" | city == "Bhadravathi" | city == "Pali" | city == "Manali" | city == "North Arcot"
g paap_spm = 1
replace paap_spm = 0 if city == "Kochi" | city == "Chembur" | city == "Digboi" | city == "Bhadravathi" | city == "Pali" | city == "Manali" | city == "North Arcot"
g paap_no2 = 1 
replace paap_no2 = 0 if city == "Dhanbad" | city == "Vapi" | city == "Parwanoo" | city == "Kala Amb" | city == "Kochi" | city == "Chembur" | city == "Korba" | city == "Nagda" | city == "Mandi" | city == "Gobindgarh" | city == "Jodhpur" | city == "Singrauli" | city == "Howrah" | city == "Talcher" | city == "Digboi" | city == "Bhadravathi" | city == "Pali" | city == "Manali" | city == "North Arcot"
g paap_so2 = 1
replace paap_so2 = 0 if city == "Dhanbad" | city == "Vapi" | city == "Parwanoo" | city == "Kala Amb" | city == "Nagda" | city == "Mandi" | city == "Gobindgarh" | city == "Jodhpur" | city == "Digboi" | city == "Bhadravathi" | city == "Pali" | city == "Manali" | city == "North Arcot"

* Save
sort state city
tempfile temp
save `temp'

/*
* Practice-merge to see what names may not match
preserve
	use "${mypath}Water Data\Datasets\india_waters_cityyear.dta", clear
	sort state city
	merge state city using `temp', uniqusing
	ta _mer
	so city _mer
	* ed city _mer
restore
*/

* More name changes
replace city = "Anklesh" if city == "Ankleshwar"
replace city = "Velore" if city == "Vellore"

* Expand and fill in to get a balanced panel
expand 23
so probarea_year state city

g year = .
bys state city: replace year = _n + 1984

foreach x of varlist paap_ap paap_wp paap_bod paap_spm paap_no2 paap_so2 {
	replace `x' = 0 if year <= probarea_year
}

order state city year

* Air cities are different from water cities (spellings too). Change city name(s) and save as a separate air dataset
preserve
	replace city = "Ankaleshwar" if city == "Anklesh"
	drop paap_wp paap_bod
	drop if year < 1987
	sort state city
	save "Intermediate Data/probareas_ap.dta", replace
restore

* Save water dataset
drop paap_ap paap_spm paap_no2 paap_so2
sort state city year
save "Intermediate Data/probareas_wp.dta", replace
