***********************************************************************************

* File: waterclean-apr09_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: The objective of this program is to compile and clean the raw water pollution
	data, and to prepare them for merging with control variables.

Structure:
1. Combine data and policy files, including necessary cleaning
2. Detailed cleaning
3. Save different versions of the database
*/

***********************************************************************************

version 8.2
clear
set mem 500m
set matsize 800
set more off
version

* cap ssc install estout

cd "${mypath}Data/Water Data"
capt log close
log using "${mypath}Log/waterclean-apr09_01102014.txt", replace t

* Focus on pollutants: bod, cod, cond, fcoli, totcoli, turb. policies includes all policies, defined as treated if city-river-year has the 
*	policy. policiesb includes all policies, defined as treated if any river in a city-year is treated. r_policies includes all policies which 
*	have a usable number of obs in the data, similarly for r_policiesb.
gl poll "bod cod do cond fcoli ph totcoli tds turb class"
gl policies "gap1 gap2 yap1 dap gomtiap1 nrcp paap_wp paap_bod action"
gl policiesb "gap1b gap2b yap1b dapb gomtiap1b gomtiap2b nrcpb paap_wpb paap_bodb"
gl r_policies "gap1 gap2 yap1 nrcp paap_wp paap_bod"
gl r_policiesb "gap1b gap2b yap1b nrcpb paap_wp paap_bod"
gl chars "class type freq discha velocity"
gl all_poll "alkal ammonitro arsenic bod boron cadmium calc chlor chromium cod cond copper cyanide do entercocci fammonia fcoli fluoride hardness iron lead magne mercury nickel nitrate nitrite nitrogen no2n palak ph phosphate potassium sodium strepcocci sulph tds temp tfds tkn totcoli tpcount tss turb zinc class"
gl all_poll_noclass "alkal ammonitro arsenic bod boron cadmium calc chlor chromium cod cond copper cyanide do entercocci fammonia fcoli fluoride hardness iron lead magne mercury nickel nitrate nitrite nitrogen no2n palak ph phosphate potassium sodium strepcocci sulph tds temp tfds tkn totcoli tpcount tss turb zinc"
gl chars "lit liturb pce povgap miss_dist"

*****************************
* 1. Combine data and policy files, including necessary cleaning.
u "Raw Data/WATmerge.dta", clear

* Note: in the original raw files received from India (like WAT86.xls), there are many duplicates of every variable. Count them here then drop them.
bys *: g n = _n
ta n
drop if n > 1
drop n

* Define date. Some dates write the year as like 1903. After looking at the year variable, I conclude that "year" is the year part of the "date" variable, 
*	but with the century corrected. Different dates having slightly different string format so define month and day carefully.
g length = length(sdate)
forv n = 1/8 {
	g char`n' = substr(sdate,`n',1)
}
g month = substr(sdate,1,1) if char2 == "/"
replace month = substr(sdate,1,2) if char3 == "/"
g day = substr(sdate,3,1) if char2 == "/" & char4 == "/"
replace day = substr(sdate,4,1) if char3 == "/" & char5 == "/"
replace day = substr(sdate,3,2) if char2 == "/" & char5 == "/"
replace day = substr(sdate,4,2) if char3 == "/" & char6 == "/"
destring month day, replace
ren Year year
drop char*
assert ((day >= 1 & day <= 31) | day >= .) & ((month >= 1 & month <= 12) | month >= .)

* For remaining duplicates, take the copy which seems to have the most data
global list = subinstr("$poll","class","",.)
egen temp0 = anycount(${list}), values(-1)
egen temp1 = rownonmiss(${list})
g tempq = temp0 - temp1
gsort stncode year month day tempq $list
by stncode year month : keep if _n == 1

drop temp0 temp1 tempq
so stncode year month day $poll
global list = ""


* Now add a file which has more monitor-level info. The variable "city_lat" is the only variable with city names here, although there are other vars with city info.
drop type* name* state*

preserve
	u "Raw Data/WatCity_Abby_Aug22.dta", clear
	ren city_lat city
	so stncode
	sa "Intermediate Data/temp.dta", replace
restore

merge stncode using "Intermediate Data/temp.dta", uniqusing update
ta _mer
drop _mer

ren state_latlon state
replace city = proper(city)
bys state: ta city

* When river is missing for some obs of a stncode but always the same for other, fill in the missing.

preserve
	drop if river == ""
	so stncode river
	by stncode: g river1 = river[1]
	by stncode: g riverN = river[_N]
	keep if river1 == riverN
	by stncode river: keep if _n == 1
	keep stncode river
	sort stncode
	sa "Intermediate Data/temp.dta", replace
restore

sort stncode
merge stncode using "Intermediate Data/temp.dta", uniqusing update
ta _mer
drop if _mer == 2
drop _mer

* Run program to define policies. First do some rennames to they apply correctly.
replace river = proper(river)
replace river = "" if river == "*"
replace river = "Alkananda" if river == "Alkannanda"
replace river = "Brahmini" if river == "Brahmani"
replace river = "Bibinagar Tank" if river == "Bidinagar Tank"
replace river = "Gobindsagar Lake" if river == "Gobindsagar Lak"
replace river = "Achankoil" if river == "Achenkoil" | river == "Achenkoli" | river == "Achankoli"
replace river = "Brahmaputra" if river == "Brahmputra"
replace river = "Ghaggar" if river == "Ghagger"
replace city = "Gurgaon" if city == "Gurgaon Canal, Gc-1,(Near Badarpur Border), Haryana"
replace city = "Pallipalayam" if city == "Pallippalayam, Tamil Nadu"
replace city = "Bahrampore" if city == "Baharampore"
replace city = "Kannauj" if city == "Kannauj (Rajghat)"

egen test = mode(river), by(city) maxmode
replace river = test if river == ""

* Add 2005 data. Do this here, before running "WaterPolicyDataset_july21.do", so 2005 gets the policy vars defined.
/* Save a dataset now for the purpose of matching location descriptions in 2005 raw data to city-rivers */
save "Intermediate Data/05_matching.dta", replace

preserve
	do "${mypath}Do Files/Data Cleaning/waterpol_2005_01102014.do"
	assert year == 2005
	keep stncode state city river location year temp do ph cond cod bod nitrate nitrite ammonitro fcoli totcoli calc magne sodium potassium chlor sulph alkal hardness phosphate turb tds tfds tss boron fluoride basin
	sa "Intermediate Data/temp.dta", replace
restore

append using "Intermediate Data/temp.dta"

/* A few cities are not coded as being on the right river */
replace river = "Ganga" if city == "Chapra" & river == "Ghaghara"          // 5.27.09: recoding Chapra as being on Ganga (it is at the confluence of Ganga and Ghagara, and covered by GAP1)
replace river = "Cauvery" if city == "Bhavani" & river == "Bhavani"     // 5.27.09: recoding Bhavani as being on Cauvery (it is at the confluence of Cauvery and Bhavani, and Google Maps identifies a Water Treatment Plant on the Cauvery)
replace river = "Vennar" if city == "Thanjavur" & river == "Cauvery"    // 5.27.09: Thanjavur is not on the Cauvery, and NRCP covers "Thanjavur-Vennar River"

qui do "${mypath}Do Files/Data Cleaning/waterpolicy_sam_01102014.do"

*****************************************
* 2. Detailed cleaning

* type and type_latlon are identical except that sometimes one is missing
ren type1032 type
foreach var of varlist type type_latlon {
	replace `var' = "" if `var' == "0" | `var' == "2" | `var' == "9" | `var' == "B" | `var' == "E" | `var' == "G" | `var' == "N"
	replace `var' = proper(`var')
	replace `var' = "1" if `var' == "Canal" | `var' == "C"
	replace `var' = "2" if `var' == "Creek" | `var' == "K"
	replace `var' = "3" if `var' == "Drain" | `var' == "D"
	replace `var' = "4" if `var' == "Lake" | `var' == "L"
	replace `var' = "5" if `var' == "Pond" | `var' == "P"
	replace `var' = "6" if `var' == "River" | `var' == "R"
	replace `var' = "7" if `var' == "Tank" | `var' == "T"
	replace `var' = "8" if `var' == "Well" | `var' == "W"
	destring `var', replace
	cap la drop type
	la de type 1 "Canal" 2 "Creek" 3 "Drain" 4 "Lake" 5 "Pond" 6 "River" 7 "Tank" 8 "Well"
	la val `var' type
}
assert type == type_latlon if type < . & type_latlon < .
replace type = type_latlon if type >= . & type_latlon < .
replace type_latlon = type if type_latlon >= . & type < .
drop type_latlon

* KEEP ONLY RIVERS. They are 90% of obs. Another option is to also include the others (canal, creek, etc.)
keep if type == 6 | year == 2005

* Frequency is harder to clean
la de freq 1 "Half yearly" 2 "Monthly" 3 "Quarterly" 4 "Yearly"
foreach var of varlist monitoringfreq870 monitoringfreq1032 monitoringfreqWQLISTT monitoringfreq_latlon {
	replace `var' = "1" if `var' == "H" | `var' == "HALF YEARLY" | `var' == "Half Yearly"
	replace `var' = "2" if `var' == "M" | `var' == "MONTHLY" | `var' == "Monthly"
	replace `var' = "3" if `var' == "Q" | `var' == "QUARTERLY"
	replace `var' = "4" if `var' == "Y" | `var' == "YEARLY"
	destring `var', replace
	la val `var' freq
}

ren monitoringfreq_latlon freq
g prob = (monitoringfreq1032 ~= monitoringfreq870 & monitoringfreq1032 < . & monitoringfreq870 < .) | (monitoringfreq870 ~= monitoringfreqWQLISTT & monitoringfreq870 < . & monitoringfreqWQLISTT < .) | (monitoringfreqWQLISTT ~= freq & monitoringfreqWQLISTT < . & freq < .)
bys stncode year: g N = _N
ta N freq
ta prob
* Note: In less than half a percent of cases are there disagreeing definitions (prob=1). So just replace with mode definition, and when there's no mode (evenly split), 
*	choose the one which best coheres with N.
egen max = rowmax(monitoringfreq1032 monitoringfreq870 monitoringfreqWQLISTT)
replace freq = max if freq >= .
ta N if  monitoringfreq1032 == 1 & freq == 2
* Note: most are monthly, but freq is already, so leave it as is.
drop monitoringfreq1032 monitoringfreq870 monitoringfreqWQLISTT

* Class and class_latlon usually match. when class is missing or meaningless, replace it with class_latlon. Finally, make it numeric.
ta class class_latlon
replace class = "" if class ~= "A" & class ~= "B" & class ~= "C" & class ~= "D" & class ~= "E"
replace class_latlon = "" if class_latlon ~= "A" & class_latlon ~= "B" & class_latlon ~= "C" & class_latlon ~= "D" & class_latlon ~= "E"
replace class = class_latlon if class == ""
drop class_latlon

replace class = "1" if class == "A"
replace class = "2" if class == "B"
replace class = "3" if class == "C"
replace class = "4" if class == "D"
replace class = "5" if class == "E"
destring class, replace
cap la drop class
la de class 1 "A" 2 "B" 3 "C" 4 "D" 5 "E"
la val class class

* Labels
la var stncode "Station code"
la var type "Location type"
la var waterbodyname "Waterbody name: code"
la var state "State code"
la var class "Abby documentation says: sampling ranking by CPCB classification"
la var agency "Pollution monitoring agency"
la var sdate "Sampling date"
la var position "R or L. Abby/CPCB didn't know if it's up or down stream"
la var temp "Temperature in C"
la var year "Year"
la var river "River/water source name"
la var location "Station location (02-04)"
la var div_index "Diversity index"
la var soprobic "parameter based on organisms present and what's known about how they tolerate pollution levels in water"
la var pr_ratio "Photosynthesis to Respiration Rate Ratio"
la var abhc "Alpha BHC"
la var gbhc "Gamma BHC"
la var ppdde "Para Para DDE (pesticide)"
la var opddd "ortho para DDT (pesticide)"
la var ppddt "Para Para DDE (pesticide)"
la var ppddd "Para Para DDD (pesticide)"
la var endo1 "alpha endosulphan (pesticide)"
la var endo2 "beta endosuulphan (pesticide)"
la var malathion "malathian (pesticide)"
la var chloropyri "(pesticide)"
drop moisture

drop tds1 mf v11 v14 v20

******************************************************************
* table 0. number of monitoring stations, with unknown city and river names
egen groups = group(stncode)
egen groups2 = group(stncode) if river ~= ""
egen groups3 = group(stncode) if city ~= ""
egen groups4 = group(stncode) if river ~= "" & city ~= ""
su groups
su groups2
su groups3
su groups4
drop groups groups2 groups3 groups4
drop if city == "" | river == ""

* The vars stncode and sdate should uniquely ID an obs, but 6 obs are duplicates of these two vars, though they are not duplicates of all vars. Not clear why. Drop 
*	those duplicates.
bys stncode sdate: g n = _n if sdate != ""
ta n
drop if n == 2
drop n

* Need to create a pre-existing dataset from which to compile state-cities for the district matching
preserve
	collapse (mean) nitrite, by(state city river)
	drop nitrite
	sort state city
	save "Intermediate Data/state-city.dta", replace
restore

preserve
	collapse (mean) nitrite, by(state city river year)
	drop if year < 1990
	g ones = 1
	bys state city river: egen obs = sum(ones)
	ta obs
	drop if obs < 15
	drop ones obs
	collapse (mean) nitrite, by(state city river)
	drop nitrite
	sort state city
	save "Intermediate Data/state-city_bp.dta", replace
restore
	
*******************************
qui do "${mypath}Do Files/Data Cleaning/clean_waternames_01102014.do"

* Define city and district names. This only defines them for a balanced panel.
preserve
	u "Raw Data/district_names.dta", clear
	so state city
	sa "Intermediate Data/temp.dta", replace
restore

so state city
merge state city using "Intermediate Data/temp.dta", uniqusing
assert _mer ~= 2
ta _mer
replace city = city_new if city_new != ""
drop _mer city_new

* Add air temperature and precipitation controls
so state district year month
merge state district year month using "Intermediate Data/airtemp_prcp_water.dta", uniqusing
drop if _merge == 2
drop _merge

* Add literacy, poverty, and per cap expenditure controls at district level. I can only add for cities that are in a balanced panel.
preserve
	u "${mypath}Data/Controls/Census/Final Data/pop_lit.dta", clear
	bys state district year: assert _n == 1
	g lit = lit_total / pop_total
	g liturb = lit_urban / pop_urban
	sa "Intermediate Data/temp.dta", replace

	u "${mypath}Data/Controls/Income/Intermediate Data/pov.dta", clear
	bys state district year: assert _n == 1
	ren mean pce
	merge state district year using "Intermediate Data/temp.dta", sort
	ta _mer
	drop _mer
	sort state district year
	sa "Intermediate Data/temp.dta", replace
restore
sort state district year	
merge state district year using "Intermediate Data/temp.dta", uniqusing
keep if _mer ~= 2
drop _mer
erase "Intermediate Data/temp.dta"

g miss_dist = lit >= . | pce >= .

* Create copies of control variables with missings recoded to universal mean
foreach x of varlist pop_urban lit_urban pce {
	g `x'2 = `x'
	su `x'2
	replace `x'2 = r(mean) if `x'2 >= .
}

* Add problem areas as another policy
so state city year
merge state city year using "${mypath}Data/Policies/Intermediate Data/probareas_wp.dta", uniqusing
keep if _mer~= 2
drop _mer
g paap_wpb = paap_wp
g paap_bodb = paap_bod
foreach var of varlist paap* {
	replace `var' = 0 if `var' >= .
}

******************************
* 3. Save different versions of the database

* This version is before dropping outliers and negative values.
sa "Intermediate Data/india_waters_werrors.dta", replace

* Recode neg and zero to missing. Then recode >99th percentile to missing.
foreach var of varlist $all_poll temp discha velocity {
	replace `var' = . if `var' <= 0
}
foreach var of varlist $all_poll temp discha velocity {
	qui su `var', d
	replace `var' = . if `var' > r(p99)
}
* Missing temperature values to zero, with indicators
g miss_temp = temp >= .
replace temp = 0 if temp >= .

* When there are disagreements of the class, type, or frequency, take the average and round it.
foreach var of varlist class type freq {
	egen meanvar = mean(`var'), by(city river)
	replace `var' = round(meanvar)
	drop meanvar
}
drop if bod >= . & cod >= . & do >= . & cond >= . & fcoli >= . & ph >= . & tds >= . & totcoli >= . & turb >= .

g lnfcoli = ln( fcoli )
g lntotcoli = ln( totcoli )
su lnfcoli
g n_lnfcoli = r(N)
su lntotcoli
g n_lntotcoli = r(N)

* This file has the underlying pollution measurements. stncode-sdate uniquely IDs an observation.
sa "Final Data/india_waters.dta", replace

* Prep for collapses: count n; info on what share of obs are fromm each month.
foreach var of varlist $poll temp discha velocity {
	g n_`var' = 1 if `var' < .
	la var n_`var' "# underlying station-day obs on `var'"
}
ta month, g(month_)

* Collapse to a monitor-year database, though count n for each variable along the way.
preserve
	collapse (mean) $all_poll_noclass $policies discha velocity month_* lnfcoli lntotcoli pce pce2 lit_urban lit_urban2 pop_urban pop_urban2 lit liturb povgap airtemp totprcp (median) class type freq (count) n_*, by(state district city river stncode year)

	* 2005 doesn't have correct reading counts, so take rounded mean of 2002-2004 and read it onto 2005.
	foreach var of varlist n_* {
		su `var' if year >= 2002 & year <= 2004
		replace `var' = round(r(mean)) if year == 2005
	}
	sa "Final Data/india_waters_stncodeyear.dta", replace
restore

* Collapse to a city-year database, though count n for each variable along the way.
* For cases when median of class/type/freq gets a decimal number, just round it.
collapse (mean) $all_poll_noclass $policies discha velocity month_* lnfcoli lntotcoli pce pce2 lit_urban lit_urban2 pop_urban pop_urban2 lit liturb povgap airtemp totprcp (median) class type freq (count) n_*, by(state district city river year)

* 2005 doesn't have correct reading counts, so take rounded mean of 2002-2004 and read it onto 2005.
foreach var of varlist n_* {
	su `var' if year >= 2002 & year <= 2004
	replace `var' = round(r(mean)) if year == 2005
}
* Verify that the type, freq, and class are integral.
assert (type == 1 | type == 2 | type == 3 | type == 4 | type == 5 | type == 6 | type == 7 | type == 8 | type >= .) & (freq == 1 | freq == 2 | freq == 3 | freq == 4 | freq >= .) & (class == 1 | class == 2 | class == 3 | class == 4 | class == 5 | class >= .)

sa "Final Data/india_waters_cityyear.dta", replace
