***********************************************************************************
* File: AppTable4_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Author: Samuel Stolper
* Modified by Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Appendix Table 4 in the paper. 
	Appendix Table 4 provides a robustness check on the two-stage regression analysis
	by varying the range of event years used in both regression stages.

Structure:
0. Set-up
1. Prep air data (all pollutants, narrow and wide tau range)
2a. CAT regressions, narrow 
2b. SCAP regressions, narrow
3a. CAT regressions, wide
3b. SCAP regressions, wide
4. Prep water data (all pollutants, narrow and wide tau range)
5a. NRCP regressions, narrow
5b. NRCP regressions, wide
6. Clean-up

*/

***********************************************************************************
* 0. Set-up
***********************************************************************************

clear all
set more off
set mem 500m

* Establish log
cap log close
log using "${mypath}Log/AppTable4_01102014.txt", replace t

***********************************************************************************
* 1. Data prep: Generate policy event-years on air dataset
***********************************************************************************

* Supreme Court Action Plan and Catalytic Converter policies *
foreach pollutant in spm so2 no2 { 
	use "${mypath}Data/Air Data/Final Data/combined.dta", clear
	egen city_id = group(city)
	bys state city: egen count = count(e_`pollutant'_mean)

	* Generate Supreme Court Action Plan taus
	cap drop temp*
	g temp = year if actionplan_sc == 1
	egen temp2 = min(temp), by(city_id) 
	egen temp3 = min(year), by(city_id) 
	g tauSC = year - temp2 if temp2 > temp3 & e_`pollutant'_mean<.
	g neveradoptSC = temp2 >= .
	replace tauSC = 0 if neveradoptSC == 1 & e_`pollutant'_mean < . // We code the non-adopting cities so that they are always in event year 0
	g tempx = 1 if actionplan_sc==1 & e_`pollutant'_mean<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
	egen tempy = min(tempx) if temp2<., by(city_id)
	ta tempy if temp2<., missing		// no cities fit this description, so no more changes need be made

	g temp4 = tauSC >= 3 & tauSC < .
	g temp5 = tauSC <= -3 & tauSC < .
	egen Mtemp4 = max(temp4), by(city_id) 
	egen Mtemp5 = max(temp5), by(city_id) 
	g useSC = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptSC == 1 & count > 1)

	* Generate Catalytic Converter Policy taus
	cap drop Mtemp* temp*
	g temp = year if catconverter == 1
	egen temp2 = min(temp), by(city_id) 
	egen temp3 = min(year), by(city_id) 
	g tauCAT = year - temp2 if temp2 > temp3 & e_`pollutant'_mean<.
	g neveradoptCAT = temp2 >= .
	replace tauCAT = 0 if neveradoptCAT == 1 & e_`pollutant'_mean < . // We code the non-adopting cities so that they are always in event year 0
	g tempx = 1 if catconverter==1 & e_`pollutant'_mean<.
	egen tempy = min(tempx) if temp2<., by(city_id)
	ta tempy if temp2<., missing
	replace neveradoptCAT = 1 if tempy>=. & temp2<.
	replace tauCAT = . if tempy>=. & temp2<.

	* The following lines restrict the sample to only those cities with at an observation at least three years prior to and after
	*	policy adoption. We also want to estimate Eqns (1) and (2) with an unrestricted sample. For this reason, we'll save restricted
	*	and unrestricted versions of the dataset.
	g temp4 = tauCAT >= 3 & tauCAT < .
	g temp5 = tauCAT <= -3 & tauCAT < .
	egen Mtemp4 = max(temp4), by(city_id) 
	egen Mtemp5 = max(temp5), by(city_id)
	g useCAT = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptCAT == 1 & count > 1)

	drop if useSC==0 | useCAT==0
	drop if e_`pollutant'_mean >= .
	ta tauSC
	ta tauCAT
	g one = 1

	preserve
		forv tau = 4(-1)1 {
			g tauSCm`tau' = tauSC == -`tau'
			la var tauSCm`tau' "This obs is `tau' years before action plan began"
		}
		forv tau = 0/4 {
			g tauSC`tau' = tauSC == `tau'
			la var tauSC`tau' "This obs is `tau' years after action plan began"
		}
		g tauSCL = tauSC<-4
		g tauSCR = tauSC>4 & tauSC<.
		forv tau = 5(-1)1 {
			g tauCATm`tau' = tauCAT == -`tau'
			la var tauCATm`tau' "This obs is `tau' years before catalytic converters made mandatory"
		}
		forv tau = 0/5 {
			g tauCAT`tau' = tauCAT == `tau'
			la var tauCAT`tau' "This obs is `tau' years after catalytic converters made mandatory"
		}
		g tauCATL = tauCAT<-5
		g tauCATR = tauCAT>5 & tauCAT<.
		save "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_narrow.dta", replace
	restore
	
	preserve
		forv tau = 14(-1)1 {
			g tauSCm`tau' = tauSC == -`tau'
			la var tauSCm`tau' "This obs is `tau' years before action plan began"
		}
		forv tau = 0/4 {
			g tauSC`tau' = tauSC == `tau'
			la var tauSC`tau' "This obs is `tau' years after action plan began"
		}
		g tauSCL = tauSC<-14
		g tauSCR = tauSC>4 & tauSC<.
		forv tau = 9(-1)1 {
			g tauCATm`tau' = tauCAT == -`tau'
			la var tauCATm`tau' "This obs is `tau' years before catalytic converters made mandatory"
		}
		forv tau = 0/9 {
			g tauCAT`tau' = tauCAT == `tau'
			la var tauCAT`tau' "This obs is `tau' years after catalytic converters made mandatory"
		}
		g tauCATL = tauCAT<-9
		g tauCATR = tauCAT>9 & tauCAT<.
		save "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_wide.dta", replace
	restore	
}


***********************************************************************************
* 2a. Two-stage regression analysis, Catalytic Converter policy, Narrow Taus
***********************************************************************************
* Narrow event year range
* Catalytic Converter policy *
local placeholder replace // we use this to control the outreg command
foreach pollutant in spm so2 no2 {
	
	use "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_narrow.dta", clear

		
* Two-Stage Regressions:
	* Recall that, for the purposes of the single-stage regressions, control cities were coded as event year 0. Revert them to 
	*	event year missing.
	replace tauCAT = . if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC = . if neveradoptSC == 1 & e_`pollutant'_mean < .
	replace tauCAT0 = 0 if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC0 = 0 if neveradoptSC == 1 & e_`pollutant'_mean < .
	
	
* First stage (Event study)
	qui xi: reg e_`pollutant'_mean tauSCm4-tauSCm1 tauSC0-tauSC4 tauSCL tauSCR tauCATm5-tauCATm1 tauCAT0-tauCAT5 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]

	
* Prepare sigmat-hats
	g taub = .
	g tause = .
	collapse (mean) taub tause tauCATm5-tauCAT5, by(tauCAT)
	drop if tauCAT>5 | tauCAT<-5
	foreach k of varlist tauCATm5-tauCATm1 tauCAT0-tauCAT5 {			
		replace taub = _b[`k'] if `k' == 1
		replace tause = _se[`k'] if `k' == 1
	}
	drop tauCATm5-tauCAT5
	g catconv = (tauCAT>=0)
	g tau_trend = tauCAT + 6
	g catconv_trend = catconv*tauCAT
	replace catconv_trend = catconv_trend + 1 if tauCAT>=0	

	/* Regress tau on policy dummy */
	
*	Second stage (mean shift and trendbreak regressions)	
	* Trendbreak regressions - Eqn (2a)
	display "Outcome: `pollutant'; Policy: Catalytic Converters; Narrow Tau Range"
	regress taub catconv [aw = 1/tause]

	* Trendbreak regressions - Eqn (2b)
	reg taub tauCAT catconv [aw=1/tause]
	
	* Trendbreak regressions - Eqn (2c)
	reg taub tauCAT catconv catconv_trend [aw=1/tause]
		lincom catconv + 5*catconv_trend
			local coef = r(estimate)
			local coef = round(`coef', .01)
			local coef = "`coef'"
			if length("`coef'") < 3 {
				local coef = "`coef'" + "0"
			}
			local coef = substr("`coef'", 1, 6)
			local tstat = r(estimate)/r(se)
			local pval = tprob(r(df), abs(`tstat'))
			local pval = round(`pval', .01)
			if `pval' <= .01 {
				local coef = "`coef'" + "***"
			}
			if `pval' > .01 & `pval' <= .05 {
				local coef = "`coef'" + "**"
			}
			if `pval' > .05 & `pval' <= .1 {
				local coef = "`coef'" + "*"
			}
			if length("`pval'") < 3 {
				local pval = "`pval'" + "0"
			}
			outreg2 using "${mypath}Output/AT4/AT4-CAT.xls", dec(2) se par ctitle("`pollutant'") aster(coef) ///
				addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") drop(catconv tauCAT catconv_trend) nocons nor2 `placeholder'
	local placeholder "append" 
}

***********************************************************************************
* 2b. Two-stage regression analysis, SCAP policy, Narrow Taus
***********************************************************************************
* SCAP policy *
local placeholder "replace" // we use this to control the outreg command
foreach pollutant in spm so2 no2 {
		use "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_narrow.dta", clear
		
* Two-Stage Regressions:
	* Recall that, for the purposes of the single-stage regressions, control cities were coded as event year 0. Revert them to 
	*	event year missing.
	replace tauCAT = . if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC = . if neveradoptSC == 1 & e_`pollutant'_mean < .
	replace tauCAT0 = 0 if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC0 = 0 if neveradoptSC == 1 & e_`pollutant'_mean < .	
	
* First stage (Event study)
	qui xi: reg e_`pollutant'_mean tauSCm4-tauSCm1 tauSC0-tauSC4 tauSCL tauSCR tauCATm5-tauCATm1 tauCAT0-tauCAT5 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]

	g taub = .
	g tause = .
	collapse (mean) taub tause tauSCm4-tauSC4, by(tauSC)
	drop if tauSC>4 | tauSC<-4
	foreach k of varlist tauSCm4-tauSCm1 tauSC0-tauSC4 {			
		replace taub = _b[`k'] if `k' == 1
		replace tause = _se[`k'] if `k' == 1
	}
	drop tauSCm4-tauSC4
	g scap = (tauSC>=0)
	g tau_trend = tauSC + 5
	g scap_trend = scap*tauSC
	replace scap_trend = scap_trend + 1 if tauSC>=0	

	
*	Second stage (mean shift and trendbreak regressions)	
	* Trendbreak regressions - Eqn (2a)
	display "Outcome: `pollutant'; Policy: SCAP; Sample: all city*years"
	regress taub scap [aw = 1/tause] 

	* Trendbreak regressions - Eqn (2b)
	reg taub tauSC scap [aw=1/tause]
	
	* Trendbreak regressions - Eqn (2c)
	reg taub tauSC scap scap_trend [aw=1/tause]
		lincom scap + 5*scap_trend
			local coef = r(estimate)
			local coef = round(`coef', .01)
			local coef = "`coef'"
			if length("`coef'") < 3 {
				local coef = "`coef'" + "0"
			}
			local coef = substr("`coef'", 1, 6)
			local tstat = r(estimate)/r(se)
			local pval = tprob(r(df), abs(`tstat'))
			local pval = round(`pval', .01)
			if `pval' <= .01 {
				local coef = "`coef'" + "***"
			}
			if `pval' > .01 & `pval' <= .05 {
				local coef = "`coef'" + "**"
			}
			if `pval' > .05 & `pval' <= .1 {
				local coef = "`coef'" + "*"
			}
			if length("`pval'") < 3 {
				local pval = "`pval'" + "0"
			}
			outreg2 using "${mypath}Output/AT4/AT4-SCAP.xls", dec(2) se par ctitle("`pollutant'") aster(coef) ///
				addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") drop(scap tauSC scap_trend) nocons nor2 `placeholder'
	local placeholder "append"
}

***********************************************************************************
* 3a. Two-stage regression analysis, Catalyic Converter policy, Wide Taus
***********************************************************************************
* Wide event year range
local placeholder "replace"
foreach pollutant in spm so2 no2 {
	
* Catalytic Converters
	use "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_wide.dta", clear

		
* Two-Stage Regressions:
	* Recall that, for the purposes of the single-stage regressions, control cities were coded as event year 0. Revert them to 
	*	event year missing.
	replace tauCAT = . if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC = . if neveradoptSC == 1 & e_`pollutant'_mean < .
	replace tauCAT0 = 0 if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC0 = 0 if neveradoptSC == 1 & e_`pollutant'_mean < .
	
	
* First stage (Event study)
	qui xi: reg e_`pollutant'_mean tauSCm14-tauSCm1 tauSC0-tauSC4 tauSCL tauSCR tauCATm9-tauCATm1 tauCAT0-tauCAT9 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]

	
* Prepare sigmat-hats
g taub = .
	g tause = .
	collapse (mean) taub tause tauCATm9-tauCAT9, by(tauCAT)
	drop if tauCAT>9 | tauCAT<-9
	foreach k of varlist tauCATm9-tauCATm1 tauCAT0-tauCAT9 {			
		replace taub = _b[`k'] if `k' == 1
		replace tause = _se[`k'] if `k' == 1
	}
	drop tauCATm9-tauCAT9
	g catconv = (tauCAT>=0)
	g tau_trend = tauCAT + 10
	g catconv_trend = catconv*tauCAT
	replace catconv_trend = catconv_trend + 1 if tauCAT>=0	
	
	
	/* Regress tau on policy dummy */
	
*	Second stage (mean shift and trendbreak regressions)	
	* Trendbreak regressions - Eqn (2a)
	display "Outcome: `pollutant'; Policy: Catalytic Converters; Narrow Tau Range"
	regress taub catconv [aw = 1/tause]

	* Trendbreak regressions - Eqn (2b)
	reg taub tauCAT catconv [aw=1/tause]
	
	* Trendbreak regressions - Eqn (2c)
	reg taub tauCAT catconv catconv_trend [aw=1/tause]
		lincom catconv + 5*catconv_trend
			local coef = r(estimate)
			local coef = round(`coef', .01)
			local coef = "`coef'"
			if length("`coef'") < 3 {
				local coef = "`coef'" + "0"
			}
			local coef = substr("`coef'", 1, 6)
			local tstat = r(estimate)/r(se)
			local pval = tprob(r(df), abs(`tstat'))
			local pval = round(`pval', .01)
			if `pval' <= .01 {
				local coef = "`coef'" + "***"
			}
			if `pval' > .01 & `pval' <= .05 {
				local coef = "`coef'" + "**"
			}
			if `pval' > .05 & `pval' <= .1 {
				local coef = "`coef'" + "*"
			}
			if length("`pval'") < 3 {
				local pval = "`pval'" + "0"
			}
			outreg2 using "${mypath}Output/AT4/AT4-CAT.xls", dec(2) se par ctitle("`pollutant'") aster(coef) ///
				addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") drop(catconv tauCAT catconv_trend) nocons nor2 append
		local placeholder "append"
}

***********************************************************************************
* 3b. Two-stage regression analysis, SCAP policy, Wide Taus
***********************************************************************************
* SCAP policy *
local placeholder "replace" // we use this to control the outreg command
foreach pollutant in spm so2 no2 {
	
* Narrow event year range
	use "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_wide.dta", clear
		
* Two-Stage Regressions:
	* Recall that, for the purposes of the single-stage regressions, control cities were coded as event year 0. Revert them to 
	*	event year missing.
	replace tauCAT = . if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC = . if neveradoptSC == 1 & e_`pollutant'_mean < .
	replace tauCAT0 = 0 if neveradoptCAT == 1 & e_`pollutant'_mean < .
	replace tauSC0 = 0 if neveradoptSC == 1 & e_`pollutant'_mean < .	
	
* First stage (Event study)
	qui xi: reg e_`pollutant'_mean tauSCm14-tauSCm1 tauSC0-tauSC4 tauSCL tauSCR tauCATm9-tauCATm1 tauCAT0-tauCAT9 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]

	g taub = .
	g tause = .
	collapse (mean) taub tause tauSCm14-tauSC4, by(tauSC)
	drop if tauSC>4 | tauSC<-14
	foreach k of varlist tauSCm14-tauSCm1 tauSC0-tauSC4 {			
		replace taub = _b[`k'] if `k' == 1
		replace tause = _se[`k'] if `k' == 1
	}
	drop tauSCm14-tauSC4
	g scap = (tauSC>=0)
	g tau_trend = tauSC + 15
	g scap_trend = scap*tauSC
	replace scap_trend = scap_trend + 1 if tauSC>=0	
	
*	Second stage (mean shift and trendbreak regressions)	
	* Trendbreak regressions - Eqn (2a)
	display "Outcome: `pollutant'; Policy: SCAP; Sample: all city*years"
	regress taub scap [aw = 1/tause] 

	* Trendbreak regressions - Eqn (2b)
	reg taub tauSC scap [aw=1/tause]
	
	* Trendbreak regressions - Eqn (2c)
	reg taub tauSC scap scap_trend [aw=1/tause]
		lincom scap + 5*scap_trend
			local coef = r(estimate)
			local coef = round(`coef', .01)
			local coef = "`coef'"
			if length("`coef'") < 3 {
				local coef = "`coef'" + "0"
			}
			local coef = substr("`coef'", 1, 6)
			local tstat = r(estimate)/r(se)
			local pval = tprob(r(df), abs(`tstat'))
			local pval = round(`pval', .01)
			if `pval' <= .01 {
				local coef = "`coef'" + "***"
			}
			if `pval' > .01 & `pval' <= .05 {
				local coef = "`coef'" + "**"
			}
			if `pval' > .05 & `pval' <= .1 {
				local coef = "`coef'" + "*"
			}
			if length("`pval'") < 3 {
				local pval = "`pval'" + "0"
			}
			outreg2 using "${mypath}Output/AT4/AT4-SCAP.xls", dec(2) se par ctitle("`pollutant'") aster(coef) ///
				addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") drop(scap tauSC scap_trend) nocons nor2 append
		local placeholder "replace"
}

***********************************************************************************
* 4. Data prep: Generate policy event-years on water dataset
***********************************************************************************

* NRCP policy *

* Narrow tau range
foreach pollutant in bod lnfcoli do { 
	u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear
	cap egen cityriver = group(city river)
	foreach var of varlist month_* {
		replace `var' = 0 if year == 2005
	}

	* Give each observation an event year (aka "tau")
	cap drop temp*
	egen yap1city = max(yap1), by(cityriver)
	egen gap1city = max(gap1), by(cityriver)
	egen gap2city = max(gap2), by(cityriver)
	egen nrcpcity = max(nrcp), by(cityriver)
	egen dapcity = max(dap), by(cityriver)
	egen gomtiap1city = max(gomtiap1), by(cityriver)
	g temp2 = 1995 if nrcpcity==1
	replace temp2 = 1993 if yap1city==1 | gap2city==1 | dapcity==1 | gomtiap1city==1
	replace temp2 = 1985 if gap1city==1
	egen temp3 = min(year), by(cityriver)
	g tau = year - temp2 if temp2 > temp3 & `pollutant'<.
	g neveradopt = temp2 >= .
	replace tau = 0 if neveradopt == 1 & `pollutant' < . // We code the non-adopting cities so that they are always in event year 0
	g tempx = 1 if (yap1==1 | gap1==1 | gap2==1 | nrcp==1 | dap==1 | gomtiap1==1) & `pollutant'<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
	egen tempy = min(tempx) if temp2<., by(cityriver)
	ta tempy if temp2<., missing		// no cities fitting this description.

	* The following lines restrict the sample to only those cities with at an observation at least three years prior to and after
	*	policy adoption. We also want to estimate Eqns (1) and (2) with an unrestricted sample. For this reason, we'll save restricted
	*	and unrestricted versions of the dataset.
	g temp4 = tau >= 3 & tau < .
	g temp5 = tau <= -3 & tau < .
	egen Mtemp4 = max(temp4), by(cityriver) 
	egen Mtemp5 = max(temp5), by(cityriver) 
	bys state city: egen count = count(`pollutant')
	g use = (Mtemp4 == 1 & Mtemp5 == 1) | (neveradopt == 1 & count>1)
	cap g one = 1

	keep if use == 1
	drop if `pollutant' >= .
	ta tau
	preserve
		forv tau = 5(-1)1 {
			g taum`tau' = tau == -`tau'
			la var taum`tau' "This obs is `tau' years before problem area began"
		}
		forv tau = 0/5 {
			g tau`tau' = tau == `tau'
			la var tau`tau' "This obs is `tau' years after problem area began"
		}
		g tauL = tau<-5
		g tauR = tau>5 & tau<.
* Save pollutant specific dataset
		save "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_narrow.dta", replace
	restore
	
	preserve
		forv tau = 9(-1)1 {
			g taum`tau' = tau == -`tau'
			la var taum`tau' "This obs is `tau' years before problem area began"
		}
		forv tau = 0/12 {
			g tau`tau' = tau == `tau'
			la var tau`tau' "This obs is `tau' years after problem area began"
		}
		g tauL = tau<-9
		g tauR = tau>12 & tau<.
* Save pollutant specific dataset
		save "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_wide.dta", replace
	restore
}

***********************************************************************************
* 5a. Two-stage regression analysis, NRCP policy, Narrow Taus
***********************************************************************************
*NRCP policy *
local placeholder "replace" // we use this to control the outreg command
foreach pollutant in bod lnfcoli do {
	use "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_narrow.dta", clear

* Two-Stage Regressions:
	* Recall that, for the purposes of the single-stage regressions, control cities were coded as event year 0. Revert them to 
	*	event year missing.
	replace tau = . if neveradopt == 1 & `pollutant' < .
	replace tau0 = 0 if neveradopt == 1 & `pollutant' < .
*	First stage (Event study)
	qui xi: reg `pollutant' taum5-taum1 tau0-tau5 tauL tauR lit_urban pce i.cityriver i.year [aw = pop_urban]
	g taub = .
	g tause = .
	collapse (mean) taub tause taum5-tau5, by(tau)
	drop if tau>5 | tau<-5
	foreach k of varlist taum5-taum1 tau0-tau5 {			
		replace taub = _b[`k'] if `k' == 1
		replace tause = _se[`k'] if `k' == 1
	}
	drop taum5-tau5
	g nrcp = (tau>=0)
	g tau_trend = tau + 6
	g nrcp_trend = nrcp*tau
	replace nrcp_trend = nrcp_trend + 1 if tau>=0
		
	
*	Second stage (mean shift and trendbreak regressions)	
	* Trendbreak regressions - Eqn (2a)
	display "Outcome: `pollutant'; Policy: NRCP; Sample: all city*years"
	regress taub nrcp [aw = 1/tause]

	* Trendbreak regressions - Eqn (2b)
	reg taub tau nrcp [aw=1/tause]
	
	* Trendbreak regressions - Eqn (2c)
	reg taub tau nrcp nrcp_trend [aw=1/tause]
		lincom nrcp + 5*nrcp_trend
			local coef = r(estimate)
			local coef = round(`coef', .01)
			local coef = "`coef'"
			if length("`coef'") < 3 {
				local coef = "`coef'" + "0"
			}
			local coef = substr("`coef'", 1, 6)
			local tstat = r(estimate)/r(se)
			local pval = tprob(r(df), abs(`tstat'))
			local pval = round(`pval', .01)
			if `pval' <= .01 {
				local coef = "`coef'" + "***"
			}
			if `pval' > .01 & `pval' <= .05 {
				local coef = "`coef'" + "**"
			}
			if `pval' > .05 & `pval' <= .1 {
				local coef = "`coef'" + "*"
			}
			if length("`pval'") < 3 {
				local pval = "`pval'" + "0"
			}
			outreg2 using "${mypath}Output/AT4/AT4-NRCP.xls", dec(2) se par ctitle("`pollutant'") aster(coef) ///
				addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") drop(nrcp tau nrcp_trend) nocons nor2 `placeholder'
		local placeholder "append"
}

***********************************************************************************
* 5b. Two-stage regression analysis, NRCP policy, Wide Taus
***********************************************************************************
foreach pollutant in bod lnfcoli do {
	use "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_wide.dta", clear

* Two-Stage Regressions:
	* Recall that, for the purposes of the single-stage regressions, control cities were coded as event year 0. Revert them to 
	*	event year missing.
	replace tau = . if neveradopt == 1 & `pollutant' < .
	replace tau0 = 0 if neveradopt == 1 & `pollutant' < .
*	First stage (Event study)
	qui xi: reg `pollutant' taum9-taum1 tau0-tau12 tauL tauR lit_urban pce i.cityriver i.year [aw = pop_urban]
	g taub = .
	g tause = .
	collapse (mean) taub tause taum9-tau12, by(tau)
	drop if tau>12 | tau<-9
	foreach k of varlist taum9-taum1 tau0-tau12 {			
		replace taub = _b[`k'] if `k' == 1
		replace tause = _se[`k'] if `k' == 1
	}
	drop taum9-tau12
	g nrcp = (tau>=0)
	g tau_trend = tau + 10
	g nrcp_trend = nrcp*tau
	replace nrcp_trend = nrcp_trend + 1 if tau>=0
		
	
*	Second stage (mean shift and trendbreak regressions)	
	* Trendbreak regressions - Eqn (2a)
	display "Outcome: `pollutant'; Policy: NRCP; Sample: all city*years"
	regress taub nrcp [aw = 1/tause]

	* Trendbreak regressions - Eqn (2b)
	reg taub tau nrcp [aw=1/tause]
	
	* Trendbreak regressions - Eqn (2c)
	reg taub tau nrcp nrcp_trend [aw=1/tause]
		lincom nrcp + 5*nrcp_trend
			local coef = r(estimate)
			local coef = round(`coef', .01)
			local coef = "`coef'"
			if length("`coef'") < 3 {
				local coef = "`coef'" + "0"
			}
			local coef = substr("`coef'", 1, 6)
			local tstat = r(estimate)/r(se)
			local pval = tprob(r(df), abs(`tstat'))
			local pval = round(`pval', .01)
			if `pval' <= .01 {
				local coef = "`coef'" + "***"
			}
			if `pval' > .01 & `pval' <= .05 {
				local coef = "`coef'" + "**"
			}
			if `pval' > .05 & `pval' <= .1 {
				local coef = "`coef'" + "*"
			}
			if length("`pval'") < 3 {
				local pval = "`pval'" + "0"
			}
			outreg2 using "${mypath}Output/AT4/AT4-NRCP.xls", dec(2) se par ctitle("`pollutant'") aster(coef) ///
				addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") drop(nrcp tau nrcp_trend) nocons nor2 append
		local placeholder "append"
}
***********************************************************************************
* 6. Clean-up
***********************************************************************************
foreach pollutant in spm so2 no2 {
	erase "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_narrow.dta"
	erase "${mypath}Data/Air Data/Final Data/combined_taus_`pollutant'_wide.dta"
}
foreach pollutant in bod lnfcoli do { 
	erase "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_narrow.dta"	
	erase "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_wide.dta"
}

log close
