***********************************************************************************

* File: Figure1_01102014.do
* Author: Jon Petkun (jbpetkun@mit.edu)
* Modified: August 19, 2013
* Paper: Greenstone & Hanna 2013, Environmental Regulations & Pollution in India
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This program generates Figure 1 for the academic paper. Figure 1 compares existing pollution
	levels in India, the US, and China. 

Structure:
0. Stata Set-up
1. Generate Figure 1 for Air Data
2. Generate Figure 1 for Water Data
3. Generate Figure 1 for IM Data
4. Clean-up
*/

***********************************************************************************
* 0. Set-up
***********************************************************************************
* Reset memory options
clear all
set more off
set mem 500m
set matsize 10000

* Establish log
cap log close
log using "${mypath}Log/Figure1_01102014.txt", replace t

***********************************************************************************
* 1. Generate Figure 1 for Air Data
***********************************************************************************

*** Air ***
* INDIA: Use AP fixed sample data

use "${mypath}Data/Air Data/Intermediate Data/e_airpol_city.dta", clear

* Keep only five year period over which means will be taken, and id info + spm_means
drop if year > 1995 | year < 1991
keep state district city year e_spm_mean

* Count number of unique districts w/ pollution data
* Note: There were 466 districts in all of India as of 1991, as per 
*	http://www.censusindia.gov.in/2011census/maps/administrative_maps/Final%20Atlas%20India%202011.pdf
bys state district (city year): gen districtcount = 1 if _n == 1
count if districtcount == 1
local districtpct = r(N)/466

* Collapse to national mean, median, and p99 values over 1991-1995
rename e_spm_mean tsp_mean
g tsp_median = tsp_mean
g tsp_p99 = tsp_mean
g country = "India"
collapse (mean) tsp_mean (median) tsp_median (p99) tsp_p99, by(country)
tempfile indiaTSP
save `indiaTSP'

* U.S.A.: Use data from Joe Shapiro
use "${mypath}Data/Air Data/Raw Data/forbook.dta", clear

* Count number of unique counties w/ pollution data
* Note: There were 3,141 counties in the US as of 1990, as per http://www.census.gov/geo/maps-data/data/gazetteer1990.html
bys statecode countycode (siteid year): gen countycount = 1 if _n == 1
count if countycount == 1
local countycount = r(N)

* Change date variable to be a month indicator, and collapse to annual means (the raw form of India's TSP data)
replace date = substr(date, 5, 2)
collapse (mean) samplevalue, by(year statecode countycode siteid)

* Generate county-wide means (across all sites and all years), to be used to rank counties by pollution
egen countymean = mean(samplevalue), by(statecode countycode)
replace countymean = countymean * -1 // multiple by -1 so we can list in descending order

* Rank the counties by their average pollution
bys countymean statecode countycode (siteid year): gen uniquecounty = 1 if _n == 1
sort uniquecounty countymean statecode countycode siteid year
gen countyrank = _n if uniquecounty == 1
drop countymean uniquecounty
bys statecode countycode (countyrank): replace countyrank = countyrank[1] // Assign county rank to all observations from that county

* Create a second pollution variable for only those counties above the Xth percentile of pollution
rename samplevalue samplevalue1
local countycap = `districtpct' * 3141 // `districtpct' is the % of districts represented in the India dataset. 3141 is the total # of US counties.
local countycap = round(`countycap') // `countycap' is the number of US counties we want to have in our sample.
if `countycap' > `countycount' {
	local countycap = `countycount'
}
assert `countycap' <= `countycount' // Ensure that the overall sample is already over X percent of all US counties
gen samplevalue2 = samplevalue1 if countyrank <= `countycap'

* Collapse to national mean, median, and p99 values over 1991-1995
rename samplevalue1 tsp_mean1
g tsp_median1 = tsp_mean1
g tsp_p99_1 = tsp_mean1
rename samplevalue2 tsp_mean2
g tsp_median2 = tsp_mean2
g tsp_p99_2 = tsp_mean2
g country = "USA"

collapse (mean) tsp_mean1 tsp_mean2 (median) tsp_median1 tsp_median2 (p99) tsp_p99_1 tsp_p99_2, by(country)
set obs 2
replace tsp_mean1 = tsp_mean2[1] if tsp_mean1 == .
replace tsp_median1 = tsp_median2[1] if tsp_median1 == .
replace tsp_p99_1 = tsp_p99_2[1] if tsp_p99_1 == .
replace country = "USA1" if country == "USA"
replace country = "USA2" if country == ""
rename tsp_mean1 tsp_mean
rename tsp_median1 tsp_median
rename tsp_p99_1 tsp_p99
drop tsp_mean2 tsp_median2 tsp_p99_2
tempfile usaTSP
save `usaTSP'


* CHINA: Use data from Ilya Faibushevich
use "${mypath}Data/Air Data/Raw Data/amb-tsp.dta", clear
reshape long _, i(city) j(year)
rename _ tsp_mean
drop if year < 1991
g tsp_median = tsp_mean
g tsp_p99 = tsp_mean
g country = "China"
collapse (mean) tsp_mean (median) tsp_median (p99) tsp_p99, by(country)
tempfile chinaTSP
save `chinaTSP'

* APPEND: Append three countries together
append using `indiaTSP'
append using `usaTSP'

g one = 1
reshape wide tsp_mean tsp_median tsp_p99, i(one) j(country) string
rename tsp_meanChina chinamean
rename tsp_medianChina chinamedian
rename tsp_p99China chinap99
rename tsp_meanIndia indiamean
rename tsp_medianIndia indiamedian
rename tsp_p99India indiap99
rename tsp_meanUSA1 usa1mean
rename tsp_medianUSA1 usa1median
rename tsp_p99USA1 usa1p99
rename tsp_meanUSA usa2mean
rename tsp_medianUSA usa2median
rename tsp_p99USA2 usa2p99
reshape long china india usa1 usa2, i(one) j(stat) string
drop one

replace china = round(china, 1)
replace india = round(india, 1)
replace usa1 = round(usa1, 1)
replace usa2 = round(usa2, 1)

* Not using median for now, too similar to mean
drop if stat == "median"

generate order = 1 if stat=="mean"
replace order = 2 if stat=="median"
replace order = 3 if stat=="p99"
local cube = char(179)
* Note that we create two versions -- one where we use the full samples from India, the US, and China, and one where we limit the US
*	sample to be the same size (as a proportion of US counties) as the India sample (as a proportion of Indian districts). It turns out
*	that they are already the same relative size, so the results are identical, and we can just use the first version.
graph bar usa1 india china, over(stat, sort(order) relabel(1 `"Mean Particulate Matter"' 2 `"99th Percentile Particulate Matter"')) ///
	ytitle("Particulate Matter" "ug/m`cube'") blabel(bar) bargap(2) ///
	legend(label(1 "U.S.") label(2 "India") label(3 "China") rows(1)) scheme(s1color) ///
	bar(1, fcolor(gs5) lcolor(gs5)) bar(2, fcolor(black) lcolor(black)) bar(3, fcolor(white) lcolor(black))
graph export "${mypath}Output/F1/F1_air1.eps", replace 
graph export "${mypath}Output/F1/F1_air1.png", replace 
/*
graph bar usa2 india china, over(stat, sort(order) relabel(1 `"Mean Particulate Matter"' 2 `"99th Percentile Particulate Matter"')) ///
	ytitle("Particulate Matter" "ug/m`cube'") blabel(bar) bargap(2) ///
	legend(label(1 "Top `countycap' U.S. Counties of `countycount' available") label(2 "India") label(3 "China") rows(1)) scheme(s1color) ///
	bar(1, fcolor(gs5) lcolor(gs5)) bar(2, fcolor(black) lcolor(black)) bar(3, fcolor(white) lcolor(black))
graph export "${mypath}Output/F1/F1_air2.eps", replace 
*/
***********************************************************************************
* 2. Generate Figure 1 for Water Data
***********************************************************************************
* Data are means across city-rivers in US and India, from 1998-2002
insheet using "${mypath}Data/Water Data/Raw Data/water_usindia.csv", clear

* Replace with fixed sample numbers
replace india = 4.17 if stat == "BOD"
replace india = 5.44 if stat == "Fcoli"
replace india = 7.14 if stat == "DO"
replace india = round(india, .01)
replace us = round(us, .01)

tempfile temp
save `temp'

* China data 6.1.09
* Data from Avi Ebenstein at http://people.rwj.harvard.edu/~aebenste/data.html#water_pollution.

use "${mypath}Data/Water Data/Raw Data/waterpoints_data.dta", clear

g ones = 1
collapse (sum) ones, by(rsystem)
keep if rsystem == "Songhua R" | rsystem == "Liao R" | rsystem == "Yellow R" | rsystem == "Yangtze R" | rsystem == "Pearl R" | rsystem == "Huai R"

g bod = 0
replace bod = 2.78 if rsystem == "Songhua R"
replace bod = 6.25 if rsystem == "Liao R"
replace bod = 2.75 if rsystem == "Yellow R"
replace bod = 1.50 if rsystem == "Yangtze R"
replace bod = 2.70 if rsystem == "Pearl R"
replace bod = 6.05 if rsystem == "Huai R"

g do = 0
replace do = 7.98 if rsystem == "Songhua R"
replace do = 6.75 if rsystem == "Liao R"
replace do = 7.75 if rsystem == "Yellow R"
replace do = 7.95 if rsystem == "Yangtze R"
replace do = 4.65 if rsystem == "Pearl R"
replace do = 5.90 if rsystem == "Huai R"

g bod_weight = bod * ones
g do_weight = do * ones

collapse (sum) bod_weight do_weight ones
g bod = bod_weight / ones /* BOD = 3.48 */
g do = do_weight / ones /* DO = 6.99 */

use `temp', clear
g china = 3.48 if stat == "BOD"
replace china = 6.99 if stat == "DO"
outsheet using "${mypath}Output/F1/F1_water.txt", replace

* Graph BOD/Fcoli and DO separately because they have different directions (higher DO is actually better water quality)
graph bar us india china if stat != "DO", over(stat, relabel(1 `" "Biochemical Oxygen" "Demand" "' 2 `" "Logarithm of" "Fecal Coliforms" "') gap(*2)) ///
	legend(cols(1) label(1 "United States") label(2 "India") label(3 "China")) scheme(s1color) blabel(bar) yscale(range(0 6)) ylab(0 1 2 3 4 5 6) ///
	outergap(*4) bargap(5) ytitle("Mean Value", margin(small)) bar(1, fcolor(gs5) lcolor(gs5)) bar(2,fcolor(black) lcolor(black)) bar(3, fcolor(white) lcolor(black)) ///
	saving("${mypath}Output/F1/F1_bodfcoli.gph", replace)

graph bar us india china if stat == "DO", over(stat, relabel(1 "Dissolved Oxygen")) bargap(5) legend(cols(1) label(1 "United States") label(2 "India") label(3 "China")) ///
	ytitle("Mean Value", margin(small)) outergap(*13) bar(1, fcolor(gs5) lcolor(gs5)) blabel(bar) ///
	scheme(s1color) bar(2,fcolor(black) lcolor(black)) bar(3, fcolor(white) lcolor(black)) yscale(range(0 9)) ///
	saving("${mypath}Output/F1/F1_do.gph", replace)

graph combine "${mypath}Output/F1/F1_bodfcoli.gph" "${mypath}Output/F1/F1_do.gph", rows(1) scheme(s1color)	
graph export "${mypath}Output/F1/F1_water.eps", replace 
graph export "${mypath}Output/F1/F1_water.png", replace 

***********************************************************************************
* 3. Generate Figure 1 for Infant Mortality 
***********************************************************************************
u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear
joinby state city year using "${mypath}Data/Air Data/Final Data/Combined.dta", unmatched(both)
joinby state city year using "${mypath}Data/Infant Mortality/IM City/Intermediate Data/cityIMdata.dta", unmatched(both) _merge(_merge2)
bys state city: egen maxmerge = max(_merge2)
keep if maxmerge==3

collapse (sum) c_birth c_infantdeath, by(year)
g india_imr = c_infantdeath*1000 / c_birth

/* U.S. Annual means, taken from Joe Shapiro's program 'Estimate_IMpoll2.do' (original data source unknown) */
g us_imr = 10.4 if year == 1986
replace us_imr = 10.1 if year == 1987
replace us_imr = 10.0 if year == 1988
replace us_imr = 9.8 if year == 1989
replace us_imr = 9.2 if year == 1990
replace us_imr = 8.9 if year == 1991
replace us_imr = 8.5 if year == 1992
replace us_imr = 8.4 if year == 1993
replace us_imr = 8 if year == 1994
replace us_imr = 7.6 if year == 1995
replace us_imr = 7.3 if year == 1996
replace us_imr = 7.2 if year == 1997
replace us_imr = 7.2 if year == 1998
replace us_imr = 7.1 if year == 1999
replace us_imr = 6.9 if year == 2000
replace us_imr = 6.8 if year == 2001
replace us_imr = 7 if year == 2002
replace us_imr = 7 if year == 2003

drop if year>2003 & year<1999
collapse (mean) india_imr us_imr

replace india_imr = round(india_imr)
replace us_imr = round(us_imr)

graph bar us_imr india_imr, legend(cols(1) label(1 "United States") label(2 "India")) scheme(s1color) ///
	blabel(bar) yscale(range(0 26)) ylab(0 5 10 15 20 25) bargap(5) aspectratio(2) ///
	ytitle("Mean IMR" "(Deaths/1000 Births)", margin(small)) bar(1, fcolor(gs5) lcolor(gs5)) bar(2,fcolor(black) lcolor(black))
graph export "${mypath}Output/F1/F1_IM.eps", replace
graph export "${mypath}Output/F1/F1_IM.png", replace

***********************************************************************************
* 4. Clean-up
***********************************************************************************
log close
