***********************************************************************************

* File: Figure5_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Modified by: Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Figure 5 in the paper. Figure 5
	plots the air policy event-study estimates developed in the first stage of the two-stage
	regression analysis. 
	
Structure:
1. Figure 5. Air Pollution Event Study Figure

For each of the Air Pollution measures, the graphs are generated by:

1. Cleaning and generating necessary variables for analysis
2. Generating individual graphs
3. Combining graphs into one

Notes:
1. The policies considered are SCAP and Catalytic Converters
*/

***********************************************************************************

clear all
set more off
set mem 500m

* Establish log
cap log close
log using "${mypath}Log/Figure5_01102014.txt", replace t

*ssc install estout, replace

***********************************************
* Event Studies

*** Air Pollution ***

/* PM */
u "${mypath}Data/Air Data/Final Data/combined.dta", clear
cd "${mypath}Output/F5"

egen city_id = group(city)
bys state city: egen count = count(e_spm_mean)

* Preparing variables for analysis

cap drop temp*
g temp = year if actionplan_sc == 1
egen temp2 = min(temp), by(city_id) 
egen temp3 = min(year), by(city_id) 
g tauSC = year - temp2 if temp2 > temp3 & e_spm_mean<.
g neveradoptSC = temp2 >= .
g tempx = 1 if actionplan_sc==1 & e_spm_mean<.
egen tempy = min(tempx) if temp2<., by(city_id)
ta tempy if temp2<., missing

g temp4 = tauSC >= 3 & tauSC < .
g temp5 = tauSC <= -3 & tauSC < .
egen Mtemp4 = max(temp4), by(city_id) 
egen Mtemp5 = max(temp5), by(city_id) 
g useSC = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptSC == 1 & count > 1)

drop Mtemp* temp*
g temp = year if catconverter == 1
egen temp2 = min(temp), by(city_id) 
egen temp3 = min(year), by(city_id) 
g tauCAT = year - temp2 if temp2 > temp3 & e_spm_mean<.
g neveradoptCAT = temp2 >= .
g tempx = 1 if catconverter==1 & e_spm_mean<.
egen tempy = min(tempx) if temp2<., by(city_id)
ta tempy if temp2<., missing
replace neveradoptCAT = 1 if tempy>=. & temp2<.
replace tauCAT = . if tempy>=. & temp2<.

g temp4 = tauCAT >= 3 & tauCAT < .
g temp5 = tauCAT <= -3 & tauCAT < .
egen Mtemp4 = max(temp4), by(city_id) 
egen Mtemp5 = max(temp5), by(city_id)
g useCAT = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptCAT == 1 & count > 1)

drop if useSC==0 | useCAT==0
drop if e_spm_mean >= .
ta tauSC
ta tauCAT
g one = 1

forv tau = 7(-1)1 {
	g tauSCm`tau' = tauSC == -`tau'
	la var tauSCm`tau' "This obs is `tau' years before action plan began"
}
forv tau = 0/3 {
	g tauSC`tau' = tauSC == `tau'
	la var tauSC`tau' "This obs is `tau' years after action plan began"
}
g tauSCL = tauSC<-7
g tauSCR = tauSC>3 & tauSC<.
forv tau = 7(-1)1 {
	g tauCATm`tau' = tauCAT == -`tau'
	la var tauCATm`tau' "This obs is `tau' years before catalytic converters mandated"
}
forv tau = 0/9 {
	g tauCAT`tau' = tauCAT == `tau'
	la var tauCAT`tau' "This obs is `tau' years after catalytic converters mandated"
}
g tauCATL = tauCAT<-7
g tauCATR = tauCAT>9 & tauCAT<.

xi: reg e_spm_mean tauSCm7-tauSCm2 tauSC0-tauSC3 tauSCL tauSCR tauCATm7-tauCATm2 tauCAT0-tauCAT9 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]
mat M = e(b)'
svmat M
replace M1 = . if _n >= 11
g n = _n - 8 in 1/11
tsset one n 
g temp6 = L.M1
replace M1 = temp6 if _n >= 8
replace M1 = 0 if _n == 7
tw connected M1 n if _n <= 11, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on PM", margin(medsmall)) ///
	xline(0, lpattern(dash)) ///
	xtit("Years since Action Plan Mandate", margin(medsmall) size(small)) ///
	scheme(s1color) ///
	subtit("Policy:  Supreme Court Action Plan") ///
	xlab(-7 -6 -3 0 3) ///
	saving(taus_apPM, replace)
drop n temp6
mat N = e(b)'
svmat N
replace N1 = . if _n >= 29 | _n <= 12
g n = _n - 20 in 13/29
tsset one n 
g temp6 = L.N1
replace N1 = temp6 if _n >= 8
replace N1 = 0 if _n == 7
tw connected N1 n if _n <= 17, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on PM", margin(medsmall)) ///
	xline(0, lpattern(dash)) ///
	xtit("Years since Catalytic Converters Mandated", margin(medsmall) size(small)) ///
	scheme(s1color) ///
	subtit("Policy:  Catalytic Converters") ///
	xlab(-7 -6 -3 0 3 6 9) ///
	saving(taus_catconPM, replace)			
			
* Combine PM graphs
graph combine taus_apPM.gph taus_catconPM.gph, cols(1) scheme(s1color) ysize(5) xsize(3) iscale(*1.2)
graph export F5a.eps, replace	

/* SO2 */
u "${mypath}Data/Air Data/Final Data/combined.dta", clear

egen city_id = group(city)
bys state city: egen count = count(e_so2_mean)

cap drop temp*
g temp = year if actionplan_sc == 1
egen temp2 = min(temp), by(city_id) 
egen temp3 = min(year), by(city_id) 
g tauSC = year - temp2 if temp2 > temp3 & e_so2_mean<.
g neveradoptSC = temp2 >= .
g tempx = 1 if actionplan_sc==1 & e_so2_mean<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if temp2<., by(city_id)
ta tempy if temp2<., missing		// no cities fit this description, so no more changes need be made

g temp4 = tauSC >= 3 & tauSC < .
g temp5 = tauSC <= -3 & tauSC < .
egen Mtemp4 = max(temp4), by(city_id) 
egen Mtemp5 = max(temp5), by(city_id) 
g useSC = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptSC == 1 & count > 1)

drop Mtemp* temp*
g temp = year if catconverter == 1
egen temp2 = min(temp), by(city_id) 
egen temp3 = min(year), by(city_id) 
g tauCAT = year - temp2 if temp2 > temp3 & e_so2_mean<.
g neveradoptCAT = temp2 >= .
g tempx = 1 if catconverter==1 & e_so2_mean<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if temp2<., by(city_id)
ta tempy if temp2<., missing		// Silvassa again. Include it as a 'neveradopt'.
replace neveradoptCAT = 1 if tempy>=. & temp2<.
replace tauCAT = . if tempy>=. & temp2<.

g temp4 = tauCAT >= 3 & tauCAT < .
g temp5 = tauCAT <= -3 & tauCAT < .
egen Mtemp4 = max(temp4), by(city_id) 
egen Mtemp5 = max(temp5), by(city_id)
g useCAT = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptCAT == 1 & count > 1)

drop if useSC==0 | useCAT==0
drop if e_so2_mean >= .
ta tauSC
ta tauCAT
g one = 1

forv tau = 7(-1)1 {
	g tauSCm`tau' = tauSC == -`tau'
	la var tauSCm`tau' "This obs is `tau' years before action plan began"
}
forv tau = 0/3 {
	g tauSC`tau' = tauSC == `tau'
	la var tauSC`tau' "This obs is `tau' years after action plan began"
}
g tauSCL = tauSC<-7
g tauSCR = tauSC>3 & tauSC<.
forv tau = 7(-1)1 {
	g tauCATm`tau' = tauCAT == -`tau'
	la var tauCATm`tau' "This obs is `tau' years before catalytic converters made mandatory"
}
forv tau = 0/9 {
	g tauCAT`tau' = tauCAT == `tau'
	la var tauCAT`tau' "This obs is `tau' years after catalytic converters made mandatory"
}
g tauCATL = tauCAT<-7
g tauCATR = tauCAT>9 & tauCAT<.

xi: reg e_so2_mean tauSCm7-tauSCm2 tauSC0-tauSC3 tauSCL tauSCR tauCATm7-tauCATm2 tauCAT0-tauCAT9 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]
mat M = e(b)'
svmat M
replace M1 = . if _n >= 11
g n = _n - 8 in 1/11
tsset one n 
g temp6 = L.M1
replace M1 = temp6 if _n >= 8
replace M1 = 0 if _n == 7
tw connected M1 n if _n <= 11, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on SO2", margin(medsmall)) ///
	xline(0, lpattern(dash)) ///
	xtit("Years since Action Plan Mandate", margin(medsmall) size(small)) ///
	scheme(s1color) ///
	subtit("Policy:  Supreme Court Action Plan") ///
	xlab(-7 -6 -3 0 3) ///
	saving(taus_apSO, replace)
drop n temp6
mat N = e(b)'
svmat N
replace N1 = . if _n >= 29 | _n <= 12
g n = _n - 20 in 13/29
tsset one n 
g temp6 = L.N1
replace N1 = temp6 if _n >= 8
replace N1 = 0 if _n == 7
tw connected N1 n if _n <= 17, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on SO2", margin(medsmall)) ///
	xline(0, lpattern(dash)) ///
	xtit("Years since Catalytic Converters Mandated", margin(medsmall) size(small)) ///
	scheme(s1color) ///
	subtit("Policy:  Catalytic Converters") ///
	xlab(-7 -6 -3 0 3 6 9) ///
	saving(taus_catconSO, replace)			

* Combine so2 graphs
graph combine taus_apSO.gph taus_catconSO.gph, cols(1) scheme(s1color) ysize(5) xsize(3) iscale(*1.2)
graph export F5b.eps, replace	

/* NO2 */
u "${mypath}Data/Air Data/Final Data/combined.dta", clear

egen city_id = group(city)
bys state city: egen count = count(e_no2_mean)

cap drop temp*
g temp = year if actionplan_sc == 1
egen temp2 = min(temp), by(city_id) 
egen temp3 = min(year), by(city_id) 
g tauSC = year - temp2 if temp2 > temp3 & e_no2_mean<.
g neveradoptSC = temp2 >= .
g tempx = 1 if actionplan_sc==1 & e_no2_mean<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if temp2<., by(city_id)
ta tempy if temp2<., missing		// no cities fit this description, so no more changes need be made

g temp4 = tauSC >= 3 & tauSC < .
g temp5 = tauSC <= -3 & tauSC < .
egen Mtemp4 = max(temp4), by(city_id) 
egen Mtemp5 = max(temp5), by(city_id) 
g useSC = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptSC == 1 & count > 1)
	
drop Mtemp* temp*
g temp = year if catconverter == 1
egen temp2 = min(temp), by(city_id) 
egen temp3 = min(year), by(city_id) 
g tauCAT = year - temp2 if temp2 > temp3 & e_no2_mean<.
g neveradoptCAT = temp2 >= .
g tempx = 1 if catconverter==1 & e_no2_mean<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if temp2<., by(city_id)
ta tempy if temp2<., missing		// Silvassa.
replace neveradoptCAT = 1 if tempy>=. & temp2<.
replace tauCAT = . if tempy>=. & temp2<.

g temp4 = tauCAT >= 3 & tauCAT < .
g temp5 = tauCAT <= -3 & tauCAT < .
egen Mtemp4 = max(temp4), by(city_id) 
egen Mtemp5 = max(temp5), by(city_id)
g useCAT = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptCAT == 1 & count > 1)

drop if useSC==0 | useCAT==0
drop if e_no2_mean >= .
ta tauSC
ta tauCAT
g one = 1

forv tau = 7(-1)1 {
	g tauSCm`tau' = tauSC == -`tau'
	la var tauSCm`tau' "This obs is `tau' years before action plan began"
}
forv tau = 0/3 {
	g tauSC`tau' = tauSC == `tau'
	la var tauSC`tau' "This obs is `tau' years after action plan began"
}
g tauSCL = tauSC<-7
g tauSCR = tauSC>3 & tauSC<.
forv tau = 7(-1)1 {
	g tauCATm`tau' = tauCAT == -`tau'
	la var tauCATm`tau' "This obs is `tau' years before catalytic converters made mandatory"
}
forv tau = 0/9 {
	g tauCAT`tau' = tauCAT == `tau'
	la var tauCAT`tau' "This obs is `tau' years after catalytic converters made mandatory"
}
g tauCATL = tauCAT<-7
g tauCATR = tauCAT>9 & tauCAT<.

xi: reg e_no2_mean tauSCm7-tauSCm2 tauSC0-tauSC3 tauSCL tauSCR tauCATm7-tauCATm2 tauCAT0-tauCAT9 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]
mat M = e(b)'
svmat M
replace M1 = . if _n >= 11
g n = _n - 8 in 1/11
tsset one n 
g temp6 = L.M1
replace M1 = temp6 if _n >= 8
replace M1 = 0 if _n == 7
tw connected M1 n if _n <= 11, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on NO2", margin(medsmall)) ///
	xline(0, lpattern(dash)) ///
	xtit("Years since Action Plan Mandate", margin(medsmall) size(small)) ///
	scheme(s1color) ///
	subtit("Policy:  Supreme Court Action Plan") ///
	xlab(-7 -6 -3 0 3) ///
	saving(taus_apNO, replace)
drop n temp6
mat N = e(b)'
svmat N
replace N1 = . if _n >= 29 | _n <= 12
g n = _n - 20 in 13/29
tsset one n 
g temp6 = L.N1
replace N1 = temp6 if _n >= 8
replace N1 = 0 if _n == 7
tw connected N1 n if _n <= 17, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on NO2", margin(medsmall)) ///
	xline(0, lpattern(dash)) ///
	xtit("Years since Catalytic Converters Mandated", margin(medsmall) size(small)) ///
	scheme(s1color) ///
	subtit("Policy:  Catalytic Converters") ///
	xlab(-7 -6 -3 0 3 6 9) ///
	saving(taus_catconNO, replace)			

* Combine no2 graphs
graph combine taus_apNO.gph taus_catconNO.gph, cols(1) scheme(s1color) ysize(5) xsize(3) iscale(*1.2)
graph export F5c.eps, replace	

log close
