***********************************************************************************

* File: Table4_01102014.do
* Author: Jon Petkun (jbpetkun@mit.edu)
* Date: January 10, 2014
* Paper: Greenstone & Hanna 2014, Environmental Regulations & Pollution in India
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: The objective of this program is to generate Table 4 of the paper. This program
	performs mean shift and trend break analysis of water pollution policies using both a 
	single-stage standard DiD approach as well as a two-stage event study and trend break
	approach. 


Structure:
0. Stata Setup
1. Data prep: Generate policy event-years on water dataset
2. Run single-stage and two-stage regressions 
	a. NRCP policy
3. Clean-up

Specifications:
1. Single-stage approach (standard difference-in-differences regressions):
	a. Mean shift (includes post*treatment only)
	b. Mean shift (includes post*treatment and city-year time trends)
	c. Trendbreak (included post*treatment, city-year time trends, and post*treatment*time-trend)
2. Two-stage approach (event study followed by mean-shift or trend-break regressions)
	a. Mean shift: reg taub post*treatment [aw=1/tause]
	b. Mean shift w/ time trend: reg taub post*treatment timetrend [aw=1/tause]
	c. Trend break: reg taub post*treatment timetrend post*treatment*timetrend [1/tause]
*/

***********************************************************************************
***********************************************************************************
* 0. Setup
***********************************************************************************

* Reset memory options
clear all
set more off
set mem 500m
set matsize 10000

* Establish log
cap log close
log using "${mypath}Log/Table4_01102014.txt", replace t

***********************************************************************************
* 1. Data prep: Generate policy event-years on water dataset
***********************************************************************************

* NRCP policy *
foreach pollutant in bod lnfcoli do { 
	u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear
	cap egen cityriver = group(city river)
	foreach var of varlist month_* {
		replace `var' = 0 if year == 2005
	}

	* Give each observation an event year (aka "tau")
	cap drop temp*
	egen yap1city = max(yap1), by(cityriver)
	egen gap1city = max(gap1), by(cityriver)
	egen gap2city = max(gap2), by(cityriver)
	egen nrcpcity = max(nrcp), by(cityriver)
	egen dapcity = max(dap), by(cityriver)
	egen gomtiap1city = max(gomtiap1), by(cityriver)
	g temp2 = 1995 if nrcpcity==1
	replace temp2 = 1993 if yap1city==1 | gap2city==1 | dapcity==1 | gomtiap1city==1
	replace temp2 = 1985 if gap1city==1
	egen temp3 = min(year), by(cityriver)
	g tau = year - temp2 if temp2 > temp3 & `pollutant'<.
	g neveradopt = temp2 >= .
	replace tau = 0 if neveradopt == 1 & `pollutant' < . // We code the non-adopting cities so that they are always in event year 0
	g tempx = 1 if (yap1==1 | gap1==1 | gap2==1 | nrcp==1 | dap==1 | gomtiap1==1) & `pollutant'<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
	egen tempy = min(tempx) if temp2<., by(cityriver)
	ta tempy if temp2<., missing		// no cities fitting this description.

	* The following lines restrict the sample to only those cities with at an observation at least three years prior to and after
	*	policy adoption. We also want to estimate Eqns (1) and (2) with an unrestricted sample. For this reason, we'll save restricted
	*	and unrestricted versions of the dataset.
	g temp4 = tau >= 3 & tau < .
	g temp5 = tau <= -3 & tau < .
	egen Mtemp4 = max(temp4), by(cityriver) 
	egen Mtemp5 = max(temp5), by(cityriver) 
	bys state city: egen count = count(`pollutant')
	g use = (Mtemp4 == 1 & Mtemp5 == 1) | (neveradopt == 1 & count>1)
	cap g one = 1

	keep if use == 1
	drop if `pollutant' >= .
	ta tau

	* Generate individual event year dummies
	forv tau = 7(-1)1 {
		g taum`tau' = tau == -`tau'
		la var taum`tau' "This obs is `tau' years before problem area began"
	}
	forv tau = 0/10 {
		g tau`tau' = tau == `tau'
		la var tau`tau' "This obs is `tau' years after problem area began"
	}
	g tauL = tau<-7
	g tauR = tau>10 & tau<.

	* Save pollutant specific dataset
	save "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_stddid.dta", replace
}

***********************************************************************************
* 2. Run single-stage and two-stage regressions
***********************************************************************************

*NRCP policy *
local placeholder "replace" // we use this to control the outreg command
foreach pollutant in bod lnfcoli do {
	use "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_stddid.dta", clear
* Single-Stage Regressions:
	drop nrcp // We already have a variable by this name, so we have to drop it
	gen nrcprange = (tau >= -7 & tau <= 10) // the two-stage regressions only include SC event year between -7 & 10
	gen nrcp = (tau >= 0) & (neveradopt == 0)
	gen nrcppolicy = nrcp*nrcprange
	gen nrcptau = tau*nrcprange
	gen nrcp_trend = nrcp*nrcprange*tau
	replace nrcp_trend = nrcp_trend + 1 if (tau >= 0 & tau <= 10)
		
	
*	Mean shift (includes post*policy plus the usual controls)
	xi: reg `pollutant' nrcprange nrcppolicy tauL tauR lit_urban pce i.city i.year [aw = pop_urban], cluster(city) 
		outreg2 nrcppolicy using "${mypath}Output/T4/Table4-NRCP-`pollutant'.xls", dec(2) se par ctitle("Eqn 3a") aster(coef) replace
*	Mean shift (includes post*policy and city-year time trend, plus the usual controls)
	xi: reg `pollutant' nrcprange nrcppolicy tauL tauR nrcptau lit_urban pce i.city i.year [aw = pop_urban], cluster(city) 
		outreg2 nrcppolicy nrcptau using "${mypath}Output/T4/Table4-NRCP-`pollutant'.xls", dec(2) se par ctitle("Eqn 3b") aster(coef) append
*	Trendbreak (includes post*treated, city-year time trend, and post*treated*time-trend, plus the usual controls)
	xi: reg `pollutant' nrcprange nrcppolicy tauL tauR nrcptau nrcp_trend lit_urban pce i.city i.year [aw = pop_urban], cluster(city) 
		lincom nrcppolicy + 5*nrcp_trend
		local coef = r(estimate)
		local coef = round(`coef', .01)
		local coef = "`coef'"
		if length("`coef'") < 3 {
			local coef = "`coef'" + "0"
		}
		local coef = substr("`coef'", 1, 6)
		local se = r(se)
		local tstat = r(estimate)/r(se)
		local pval = tprob(r(df), abs(`tstat'))
		local pval = round(`pval', .01)
		if `pval' <= .01 {
			local coef = "`coef'" + "***"
		}
		if `pval' > .01 & `pval' <= .05 {
			local coef = "`coef'" + "**"
		}
		if `pval' > .05 & `pval' <= .1 {
			local coef = "`coef'" + "*"
		}
		if length("`pval'") < 3 {
			local pval = "`pval'" + "0"
		}
		outreg2 nrcppolicy nrcptau nrcp_trend using "${mypath}Output/T4/Table4-NRCP-`pollutant'.xls", dec(2) se par ctitle("Eqn 3c") aster(coef) addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") append
		
* Two-Stage Regressions:
	* Recall that, for the purposes of the single-stage regressions, control cities were coded as event year 0. Revert them to 
	*	event year missing.
	replace tau = . if neveradopt == 1 & `pollutant' < .
	replace tau0 = 0 if neveradopt == 1 & `pollutant' < .
*	First stage (Event study)
	qui xi: reg `pollutant' taum7-taum1 tau0-tau10 tauL tauR lit_urban pce i.cityriver i.year [aw = pop_urban]

	* Prepare sigmat-hats
	gen taub = .
	gen tause = .
	collapse (mean) taub tause taum7-tau10, by(tau)
	drop if tau > 10 | tau < -7
	foreach k of varlist taum7-taum1 tau0-tau10 {
		replace taub = _b[`k'] if `k' == 1
		replace tause = _se[`k'] if `k' == 1
	}
	drop taum7-tau10
	gen nrcp = (tau >= 0)
	gen tau_trend = tau + 8
	gen nrcp_trend = nrcp*tau
	replace nrcp_trend = nrcp_trend + 1 if tau >= 0
	
* Save the dataset of sigma-hats (for use with breakpoint tests)
	save "${mypath}Data/Water Data/Final Data/sigmas_`pollutant'.dta", replace		
	
*	Second stage (mean shift and trendbreak regressions)	
	* Trendbreak regressions - Eqn (2a)
	display "Outcome: `pollutant'; Policy: NRCP; Sample: all city*years"
	regress taub nrcp [aw = 1/tause]
		outreg2 nrcp using "${mypath}Output/T4/Table4-NRCP-`pollutant'.xls", dec(2) se par ctitle("Eqn 2a") aster(coef) append	

	* Trendbreak regressions - Eqn (2b)
	reg taub tau nrcp [aw=1/tause]
		outreg2 nrcp tau using "${mypath}Output/T4/Table4-NRCP-`pollutant'.xls", dec(2) se par ctitle("Eqn 2b") aster(coef) append
	
	* Trendbreak regressions - Eqn (2c)
	reg taub tau nrcp nrcp_trend [aw=1/tause]
		lincom nrcp + 5*nrcp_trend
			local coef = r(estimate)
			local coef = round(`coef', .01)
			local coef = "`coef'"
			if length("`coef'") < 3 {
				local coef = "`coef'" + "0"
			}
			local coef = substr("`coef'", 1, 6)
			local tstat = r(estimate)/r(se)
			local pval = tprob(r(df), abs(`tstat'))
			local pval = round(`pval', .01)
			if `pval' <= .01 {
				local coef = "`coef'" + "***"
			}
			if `pval' > .01 & `pval' <= .05 {
				local coef = "`coef'" + "**"
			}
			if `pval' > .05 & `pval' <= .1 {
				local coef = "`coef'" + "*"
			}
			if length("`pval'") < 3 {
				local pval = "`pval'" + "0"
			}
			outreg2 nrcp tau nrcp_trend using "${mypath}Output/T4/Table4-NRCP-`pollutant'.xls", dec(2) se par ctitle("Eqn 2c") aster(coef) addtext("5-Year Effect", "`coef'", "p-value", "[`pval']") append
}


***********************************************************************************
* 3. Clean-up
***********************************************************************************

* Erase intermediate datasets
foreach pollutant in bod lnfcoli do {
	erase "${mypath}Data/Water Data/Final Data/india_waters_cityyears_taus_`pollutant'_stddid.dta"
}

log close
