***********************************************************************************

* File: Table7_01102014.do
* Contact: Jon Petkun - petkunj@nber.org
* Date created: 7/5/2013
* Project: Greenstone/Hanna (2011)

/*

Objective: The objective of this program is to generate Table 7 for the paper. This program
	performs the standard two-stage analysis from Greenstone and Hanna, however in this case, 
	the event years have been interacted with "high" and "low" categories formed on the basis 
	of two control variables: urban literacy rate and annual # of references to air pollution 
	in the Times of India.
	
0. Setup
1. Generate "high" vs. "low" dummy variables
2. Generate policy event-years (taus)
3. Run first and second stage regressions (Event study and trend break analysis)
4. Clean-up

Notes:
1. Only the Catalytic Converter and National River Conservation Plan policies are considered in 
	this program.
*/
***********************************************************************************
* 0. Setup
***********************************************************************************

clear all
set more off
set mem 500m
set matsize 10000

cap log close
log using "${mypath}Log/Table7_01102014.txt", replace t

***********************************************************************************
* 1. Generate "high" vs. "low" dummy variables
***********************************************************************************
* Catalytic Converter policy *
u "${mypath}Data/Air Data/Final Data/combined.dta", clear

* Define "treatment" vs. "control" cities. Treatment cities are those cities that received the 
*	catalytic converter policy at some point in our timeframe.
bys state city: egen policyadoption = max(catconverter) 

* Generate percentage of urban population that is literate
gen pct_urban_literacy = lit_urban / pop_urban

* We will define the medians based off of the first year of available data (for literacy) or the avg. of all years of available data (for air pollution
*	and corruption references).
*	Note that the median is based only on the treatment cities (i.e. policyadoption == 1), and the "high"/"low" categories are only
*	assigned for treatment cities.
bys city: gen urban_literacy = pct_urban_literacy if year == 1987 & policyadoption == 1
bys city (urban_literacy): replace urban_literacy = urban_literacy[1] if urban_literacy >= .
bys city: egen airpoll_references = mean(air_references) if policyadoption == 1



* Generate dummies for above-median factor scores
foreach var of varlist urban_literacy airpoll_references {
	egen `var'_med = median(`var') if policyadoption == 1
	gen `var'_hi = `var' > `var'_med if (policyadoption == 1 & `var' < .)
	lab var `var'_hi "Dummy for above median `var'."
	drop `var' `var'_med
}

order state city year e_spm_mean e_so2_mean e_no2_mean catconverter pop_urban pct_urban_literacy urban_literacy_hi ///
	air_references airpoll_references_hi
sort state city year

save "${mypath}Data/Air Data/Final Data/combined_taus_T7.dta", replace

***********************************************************************************
* 2. Generate policy event-years (taus)
***********************************************************************************

* Supreme Court Action Plan and Catalytic Converter policies *
foreach pollutant in spm so2 no2 { 
	local placeholder = "replace"
	foreach var of varlist urban_literacy_hi airpoll_references_hi {

		use "${mypath}Data/Air Data/Final Data/combined_taus_T7.dta", clear
		gen high = `var' // dummy for cities with above median values of "`var'"
		egen city_id = group(city)
		bys state city: egen count = count(e_`pollutant'_mean)

		* Generate Supreme Court Action Plan taus
		cap drop temp*
		g temp = year if actionplan_sc == 1
		egen temp2 = min(temp), by(city_id) 
		egen temp3 = min(year), by(city_id) 
		g tauSC = year - temp2 if temp2 > temp3 & e_`pollutant'_mean<.
		g neveradoptSC = temp2 >= .
		g tempx = 1 if actionplan_sc==1 & e_`pollutant'_mean<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
		egen tempy = min(tempx) if temp2<., by(city_id)
		ta tempy if temp2<., missing		// no cities fit this description, so no more changes need be made

		g temp4 = tauSC >= 3 & tauSC < .
		g temp5 = tauSC <= -3 & tauSC < .
		egen Mtemp4 = max(temp4), by(city_id) 
		egen Mtemp5 = max(temp5), by(city_id) 
		g useSC = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptSC == 1 & count > 1)

		* Generate Catalytic Converter Policy taus
		cap drop Mtemp* temp*
		g temp = year if catconverter == 1
		egen temp2 = min(temp), by(city_id) 
		egen temp3 = min(year), by(city_id) 
		g tauCAT = year - temp2 if temp2 > temp3 & e_`pollutant'_mean<.
		g neveradoptCAT = temp2 >= .
		g tempx = 1 if catconverter==1 & e_`pollutant'_mean<.
		egen tempy = min(tempx) if temp2<., by(city_id)
		ta tempy if temp2<., missing
		replace neveradoptCAT = 1 if tempy>=. & temp2<.
		replace tauCAT = . if tempy>=. & temp2<.

		* The following lines restrict the sample to only those cities with at an observation at least three years prior to and after
		*	policy adoption.		
		g temp4 = tauCAT >= 3 & tauCAT < .
		g temp5 = tauCAT <= -3 & tauCAT < .
		egen Mtemp4 = max(temp4), by(city_id) 
		egen Mtemp5 = max(temp5), by(city_id)
		g useCAT = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptCAT == 1 & count > 1)
		drop if useSC==0 | useCAT==0
		drop if e_`pollutant'_mean >= .
		ta tauSC
		ta tauCAT
		g one = 1
		
		* Generate individual event-year dummies for Supreme Court Action Plans
		forv tau = 7(-1)1 {
			g tauSCm`tau' = (tauSC == -`tau')
			la var tauSCm`tau' "This obs is `tau' yrs before SCAP"
			g tauSCm`tau'_hi = (tauSC == -`tau' & high == 1)
			la var tauSCm`tau'_hi "This obs is `tau' yrs before SCAP & `var' is above med."
			g tauSCm`tau'_lo = (tauSC == -`tau' & high == 0)
			la var tauSCm`tau'_lo "This obs is `tau' yrs before SCAP & `var' is below med."
		}
		forv tau = 0/3 {
			g tauSC`tau' = (tauSC == `tau')
			la var tauSC`tau' "This obs is `tau' yrs after SCAP"
			g tauSC`tau'_hi = (tauSC == `tau' & high == 1)
			la var tauSC`tau'_hi "This obs is `tau' yrs after SCAP & `var' is above med."
			g tauSC`tau'_lo = (tauSC == `tau' & high == 0)
			la var tauSC`tau'_lo "This obs is `tau' yrs after SCAP & `var' is below med."
		}
		g tauSCL = (tauSC<-7)
		g tauSCL_hi = (tauSC<-7 & high == 1)
		g tauSCL_lo = (tauSC<-7 & high == 0)
		g tauSCR = (tauSC>3 & tauSC<.)
		g tauSCR_hi = (tauSC>3 & tauSC<. & high == 1)
		g tauSCR_lo = (tauSC>3 & tauSC<. & high == 0)

		* Generate individual event-year dummies for Catalytic Converter Policy
		forv tau = 7(-1)1 {
			g tauCATm`tau' = (tauCAT == -`tau')
			la var tauCATm`tau' "This obs is `tau' yrs before CAT"
			g tauCATm`tau'_hi = (tauCAT == -`tau' & high == 1)
			la var tauCATm`tau'_hi "This obs is `tau' yrs before CAT & `var' is above med."
			g tauCATm`tau'_lo = (tauCAT == -`tau' & high == 0)
			la var tauCATm`tau'_lo "This obs is `tau' yrs before CAT & `var' is below med."
		}
		forv tau = 0/9 {
			g tauCAT`tau' = (tauCAT == `tau')
			la var tauCAT`tau' "This obs is `tau' yrs after CAT"		
			g tauCAT`tau'_hi = (tauCAT == `tau' & high == 1)
			la var tauCAT`tau'_hi "This obs is `tau' yrs after CAT & `var' is above med."
			g tauCAT`tau'_lo = (tauCAT == `tau' & high == 0)
			la var tauCAT`tau'_lo "This obs is `tau' yrs after CAT & `var' is below med."			
		}
		g tauCATL = (tauCAT<-7)
		g tauCATL_hi = (tauCAT<-7 & high == 1)
		g tauCATL_lo = (tauCAT<-7 & high == 0)
		g tauCATR = (tauCAT>9 & tauCAT<.)
		g tauCATR_hi = (tauCAT>9 & tauCAT<. & high == 1)
		g tauCATR_lo = (tauCAT>9 & tauCAT<. & high == 0)		

***********************************************************************************
* 3. Run first and second stage regressions
***********************************************************************************

* Catalytic Converter policy *
* Original version of Table 7 (w high and low categories)
	* First stage (Event study)
		preserve
			if "`placeholder'" == "replace" {
				keep if policyadoption == 0 | high == 1
				xi: reg e_`pollutant'_mean tauSCm7 tauSCm6 tauSCm5 tauSCm4 tauSCm3 tauSCm2 tauSCm1 tauSC0 tauSC1 tauSC2 tauSC3 tauSCL tauSCR ///
					tauCATm7 tauCATm6 tauCATm5 tauCATm4 tauCATm3 tauCATm2 tauCATm1 tauCAT0 tauCAT1 tauCAT2 tauCAT3 tauCAT4 tauCAT5 tauCAT6 tauCAT7 ///
					tauCAT8 tauCAT9 tauCATL tauCATR lit_urban mean i.city i.year [aw = pop_urban]

				* Prepare sigmat-hats
				gen taub = .
				gen tause = .
				collapse (mean) taub tause tauCATm7 tauCATm6 tauCATm5 tauCATm4 tauCATm3 tauCATm2 tauCATm1 tauCAT0 tauCAT1 tauCAT2 tauCAT3 tauCAT4 ///
					tauCAT5 tauCAT6 tauCAT7 tauCAT8 tauCAT9, by(tauCAT)		
				drop if tauCAT > 9 | tauCAT < -7
				foreach k of varlist tauCATm7-tauCATm1 tauCAT0-tauCAT9 {
					replace taub = _b[`k'] if `k' == 1
					replace tause = _se[`k'] if `k' == 1
				}
				drop tauCATm7-tauCAT9
				
				* Generate policy variables
				gen catconv = (tauCAT >= 0)
				gen catconv_trend = catconv*tauCAT
				replace catconv_trend = catconv_trend + 1 if tauCAT >= 0

				* Trendbreak regressions - Eqn (2a)
				display "Outcome: `pollutant'; Policy: Catalytic Converters; Table 7 Heterogeneity Test"
				regress taub catconv  [aw = 1/tause]
					outreg2 using "${mypath}Output/T7/T7_`pollutant'.xls", nocons nor2 dec(2) se par ctitle("Eqn 2a") aster(coef) `placeholder'	
			
				* Trendbreak regressions - Eqn (2b)
				reg taub catconv tauCAT [aw=1/tause]
					outreg2 using "${mypath}Output/T7/T7_`pollutant'.xls", nocons nor2 dec(2) se par ctitle("Eqn 2b") aster(coef) append
				
				* Trendbreak regressions - Eqn (2c)
				reg taub catconv tauCAT catconv_trend [aw=1/tause]
					lincom catconv + 5*catconv_trend
						local coef1 = r(estimate)
						local coef1 = round(`coef1', .01)
						local coef1 = "`coef1'"
						if length("`coef1'") < 3 {
							local coef1 = "`coef1'" + "0"
						}
						local coef1 = substr("`coef1'", 1, 6)
						local tstat1 = r(estimate)/r(se)
						local pval1 = tprob(r(df), abs(`tstat1'))
						local pval1 = round(`pval1', .01)
						if `pval1' <= .01 {
							local coef1 = "`coef1'" + "***"
						}
						if `pval1' > .01 & `pval1' <= .05 {
							local coef1 = "`coef1'" + "**"
						}
						if `pval1' > .05 & `pval1' <= .1 {
							local coef1 = "`coef1'" + "*"
						}
						if length("`pval1'") < 3 {
							local pval1 = "`pval1'" + "0"
						}
						outreg2 using "${mypath}Output/T7/T7_`pollutant'.xls", nocons nor2 dec(2) se par ctitle("Eqn 2c") ///
							aster(coef) addtext("5-Year Effect - Overall", "`coef1'", "p-value - Overall", "[`pval1']") append
			}
		restore		
		
* First and second stage regressions with High and Low Categories
	* First stage (Event study)
		preserve
			xi: reg e_`pollutant'_mean tauSCm7_hi tauSCm7_lo tauSCm6_hi tauSCm6_lo tauSCm5_hi tauSCm5_lo tauSCm4_hi tauSCm4_lo ///
			tauSCm3_hi tauSCm3_lo tauSCm2_hi tauSCm2_lo tauSCm1_hi tauSCm1_lo tauSC0_hi tauSC0_lo tauSC1_hi tauSC1_lo ///
			tauSC2_hi tauSC2_lo tauSC3_hi tauSC3_lo tauSCL_hi tauSCL_lo tauSCR_hi tauSCR_lo tauCATm7_hi tauCATm7_lo tauCATm6_hi ///
			tauCATm6_lo tauCATm5_hi tauCATm5_lo tauCATm4_hi tauCATm4_lo tauCATm3_hi tauCATm3_lo tauCATm2_hi tauCATm2_lo tauCATm1_hi ///
			tauCATm1_lo tauCAT0_hi tauCAT0_lo tauCAT1_hi tauCAT1_lo tauCAT2_hi tauCAT2_lo tauCAT3_hi tauCAT3_lo tauCAT4_hi tauCAT4_lo ///
			tauCAT5_hi tauCAT5_lo tauCAT6_hi tauCAT6_lo tauCAT7_hi tauCAT7_lo tauCAT8_hi tauCAT8_lo tauCAT9_hi tauCAT9_lo tauCATL_hi ///
			tauCATL_lo tauCATR_hi tauCATR_lo lit_urban mean i.city i.year [aw = pop_urban]

			* Prepare sigmat-hats
			gen taub = .
			gen tause = .
			collapse (mean) taub tause tauCATm7_hi tauCATm7_lo tauCATm6_hi tauCATm6_lo tauCATm5_hi tauCATm5_lo tauCATm4_hi tauCATm4_lo ///
				tauCATm3_hi tauCATm3_lo tauCATm2_hi tauCATm2_lo tauCATm1_hi tauCATm1_lo tauCAT0_hi tauCAT0_lo tauCAT1_hi tauCAT1_lo ///
				tauCAT2_hi tauCAT2_lo tauCAT3_hi tauCAT3_lo tauCAT4_hi tauCAT4_lo tauCAT5_hi tauCAT5_lo tauCAT6_hi tauCAT6_lo ///
				tauCAT7_hi tauCAT7_lo tauCAT8_hi tauCAT8_lo tauCAT9_hi tauCAT9_lo, by(tauCAT high)		
			drop if tauCAT > 9 | tauCAT < -7
			foreach k of varlist tauCATm7_hi-tauCATm1_lo tauCAT0_hi-tauCAT9_lo {
				replace taub = _b[`k'] if `k' == 1
				replace tause = _se[`k'] if `k' == 1
			}
			drop tauCAT*hi tauCAT*lo
			
			* Generate policy variables
			gen catconv = (tauCAT >= 0)
			gen catconv_high = catconv*high
			gen tauCAT_high = tauCAT*high
			gen catconv_trend = catconv*tauCAT
			replace catconv_trend = catconv_trend + 1 if tauCAT >= 0
			gen catconv_trend_high = catconv*tauCAT*high
			replace catconv_trend_high = catconv_trend_high + 1 if (tauCAT >= 0 & high == 1)

			* Trendbreak regressions - Eqn (2a)
			display "Outcome: `pollutant'; Policy: Catalytic Converters; Table 7 Heterogeneity Test"
			reg taub high catconv catconv_high [aw = 1/tause]
				outreg2 using "${mypath}Output/T7/T7_`pollutant'.xls", nocons nor2 dec(2) se par ctitle("Eqn 2a - High/Low by `var'") aster(coef) append	
		
			* Trendbreak regressions - Eqn (2b)
			reg taub high catconv catconv_high tauCAT tauCAT_high [aw=1/tause]
				outreg2 using "${mypath}Output/T7/T7_`pollutant'.xls", nocons nor2 dec(2) se par ctitle("Eqn 2b - High/Low by `var'") aster(coef) append
			
			* Trendbreak regressions - Eqn (2c)
			reg taub high catconv catconv_high tauCAT tauCAT_high catconv_trend catconv_trend_high [aw=1/tause]
				lincom catconv + 5*catconv_trend
					local coef1 = r(estimate)
					local coef1 = round(`coef1', .01)
					local coef1 = "`coef1'"
					if length("`coef1'") < 3 {
						local coef1 = "`coef1'" + "0"
					}
					local coef1 = substr("`coef1'", 1, 6)
					local tstat1 = r(estimate)/r(se)
					local pval1 = tprob(r(df), abs(`tstat1'))
					local pval1 = round(`pval1', .01)
					if `pval1' <= .01 {
						local coef1 = "`coef1'" + "***"
					}
					if `pval1' > .01 & `pval1' <= .05 {
						local coef1 = "`coef1'" + "**"
					}
					if `pval1' > .05 & `pval1' <= .1 {
						local coef1 = "`coef1'" + "*"
					}
					if length("`pval1'") < 3 {
						local pval1 = "`pval1'" + "0"
					}
				lincom catconv_high + 5*catconv_trend_high
					local coef2 = r(estimate)
					local coef2 = round(`coef2', .01)
					local coef2 = "`coef2'"
					if length("`coef2'") < 3 {
						local coef2 = "`coef2'" + "0"
					}
					local coef2 = substr("`coef2'", 1, 6)
					local tstat2 = r(estimate)/r(se)
					local pval2 = tprob(r(df), abs(`tstat2'))
					local pval2 = round(`pval2', .01)
					if `pval2' <= .01 {
						local coef2 = "`coef2'" + "***"
					}
					if `pval2' > .01 & `pval2' <= .05 {
						local coef2 = "`coef2'" + "**"
					}
					if `pval2' > .05 & `pval2' <= .1 {
						local coef2 = "`coef2'" + "*"
					}
					if length("`pval2'") < 3 {
						local pval2 = "`pval2'" + "0"
					}
					outreg2 using "${mypath}Output/T7/T7_`pollutant'.xls", nocons nor2 dec(2) se par ctitle("Eqn 2c - High/Low by `var'") ///
						aster(coef) addtext("5-Year Effect - Overall", "`coef1'", "p-value - Overall", "[`pval1']", "5-Year Effect - High", "`coef2'", ///
						"p-value - High", "[`pval2']") append			
		restore
		local placeholder = "append"
	}
}
	
***********************************************************************************
* 4. Clean-up
***********************************************************************************

* Erase intermediate datasets
erase "${mypath}Data/Air Data/Final Data/combined_taus_T7.dta"

log close
